function [] = IBD_fs_compareClassificationMethods(datasetName)
%==========================================================================
% IBD_fs_compareClassificationMethods(datasetName)
%==========================================================================
% Comparison of classification methods for given dataset
% 14 October 2020
%--------------------------------------------------------------------------
%-- input
% datasetName:    	name of the data to compare
%                   'par' | 'ss0' | any treatment name
%--------------------------------------------------------------------------
%-- output         
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

%--------------------------------------------------------------------------
modelTypes          = {'decisionTree','randomForest','knn','LDA','SVM','GPR'};
if license('test','Neural_Network_Toolbox')
    modelTypes      = [modelTypes,{'ANN'}];
end
compTable           = struct;
measName            = {'all','measurable'};
excludeName         = {'all','excludeCDEIS'};

for measurable = [true false]
    for excludeCDEIS = [true false]
        if excludeCDEIS && sum(strcmp(datasetName,{'par','ss0','par_ss0'}))==0
            continue        % excludeCDEIS does only apply to 'par' and 'ss0' 
        end
        if measurable && sum(strcmp(datasetName,{'par','par_ss0'}))==1
            continue        % measurable states do not apply to 'par'
        end
        fprintf('Comparison of classification methods for %s (%s / %s)\n',datasetName,measName{measurable+1},excludeName{excludeCDEIS+1})
        dataTable   = IBD_fs_makeDataset(datasetName,measurable,excludeCDEIS);
        % Default model
        model = IBD_fs_defaultModel(dataTable);
        % Compare methods
        compTable.(measName{measurable+1}).(excludeName{excludeCDEIS+1}) = IBD_fs_compareMethods(model,modelTypes,10);
    end
end

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',datasetName,'_',date,'.mat'];
save(fullFileName,'compTable')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile).(datasetName) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
end


