function [] = IBD_fs_LDAfeatureSelection(datasetName)
%==========================================================================
% IBD_fs_LDAfeatureSelection(datasetName)
%==========================================================================
% Feature selection using linear discriminant analysis
% 14 October 2020
%--------------------------------------------------------------------------
%-- input
% datasetName:    	name of the dataset
%                   'par' | 'ss0' | 'par_ss0' | any treatment name
%--------------------------------------------------------------------------
%-- output         
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

%--------------------------------------------------------------------------
featureSelection    = struct;
measName            = {'all','measurable'};
excludeName         = {'all','excludeCDEIS'};

for measurable = [true false]
    for excludeCDEIS = [true false]
        if excludeCDEIS && sum(strcmp(datasetName,{'par','ss0','par_ss0'}))==0
            continue        % excludeCDEIS does only apply to 'par' and 'preIBD' 
        end
        if measurable && sum(strcmp(datasetName,{'par'}))==1
            continue        % measurable states do not apply to 'par'
        end
        fprintf('Feature selection for %s (%s / %s)\n',datasetName,measName{measurable+1},excludeName{excludeCDEIS+1})
        [dataTable,ref]	= IBD_fs_makeDataset(datasetName,measurable,excludeCDEIS);
        model           = IBD_fs_defaultModel(dataTable);
        model.ref       = ref;
        fsTable         = IBD_fs_regularisedLDA(model);
        featureSelection.(measName{measurable+1}).(excludeName{excludeCDEIS+1}) = fsTable;
    end
end

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',datasetName,'_',date,'.mat'];
save(fullFileName,'featureSelection','ref')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile).(datasetName) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------