function [] = IBD_fs_LDAfeatureSelection_relapse
%==========================================================================
% IBD_fs_LDAfeatureSelection_relapse
%==========================================================================
% Feature selection using linear discriminant analysis for the prediction
% of relapse
% 11 March 2021        
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

%--------------------------------------------------------------------------
featureSelection    = struct;
measName            = {'all','measurable'};
excludeName         = {'all','excludeCDEIS'};

singleTreatments = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
        'phosphatidylcholine','FMT','methotrexate','azathioprine'};     % without antibiotics
for measurable = [true false]
    for excludeCDEIS = false
        dataTable = [];
        for i = 1:length(singleTreatments)
            [dataTable2,ref]	= IBD_fs_makeDataset([singleTreatments{i},'_relapse'],measurable,excludeCDEIS);
            dataTable = [dataTable;dataTable2];
        end
        model           = IBD_fs_defaultModel(dataTable);
        model.ref       = ref;
        fsTable         = IBD_fs_regularisedLDA(model);
        featureSelection.(measName{measurable+1}).(excludeName{excludeCDEIS+1}) = fsTable;
    end
end

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'featureSelection','ref')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.fs_LDAfeatureSelection.relapse = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------