%==========================================================================
% IBD_fs_TestRelapseModel
%==========================================================================
% Test performance of overall relapse prediction model for the single
% treatment datasets
% 17 March 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine'};     % without antibiotics
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine'};

%--------------------------------------------------------------------------
% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load comparison result
load(fileNameList.fs_LDAfeatureSelection.relapse);
fs = featureSelection;

for i = 1:length(scenarios)
    % all
    [dataTable,~]	= IBD_fs_makeDataset([scenarios{i},'_relapse'],false,false);
    fs.all.all.(scenarios{i}) = nan(size(fs.all.all,1),1);
    for j = 1:size(fs.all.all,1)
        fs.all.all.(scenarios{i})(j) = linearModel(fs.all.all.constCoeff(j),fs.all.all.linearCoeff{j},dataTable);
    end
        
    % measurable
    [dataTable,~]	= IBD_fs_makeDataset([scenarios{i},'_relapse'],true,false);
    fs.measurable.all.(scenarios{i}) = nan(size(fs.measurable.all,1),1);
    for j = 1:size(fs.measurable.all,1)
        fs.measurable.all.(scenarios{i})(j) = linearModel(fs.measurable.all.constCoeff(j),fs.measurable.all.linearCoeff{j},dataTable);
    end
end

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'fs')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%==========================================================================
% LOCAL FUNTIONS
function correct = linearModel(constCoeff,linearCoeff,dataTable)
    pred = (constCoeff+linearCoeff'*dataTable{:,1:end-1}')';
    pred(pred>0) = 1;
    pred(pred<0) = -1;
    obs  = dataTable{:,end};
    correct = sum(pred==obs)/length(pred);
end
%--------------------------------------------------------------------------
