function compTable = IBD_fs_compareMethods(model,modelTypes,k)
%==========================================================================
% compTable = IBD_fs_compareMethods(model,modelTypes)
%==========================================================================
% Compare different classification methods on a given dataset
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% model:            model struct for feature selection
% modelTypes:      	list of names of classification methods
% k:                number of training/testing rounds (cross-validation)
%--------------------------------------------------------------------------
%-- output
% compTable:        table of performance values per classification method
%==========================================================================

performance.correct         = nan(length(modelTypes),k);
performance.sensitivity     = nan(length(modelTypes),k);
performance.specificity     = nan(length(modelTypes),k);
performance.trainingTime    = nan(length(modelTypes),k);
performance.testingTime     = nan(length(modelTypes),k);

modelk(1:k)     = model;
for j = 1:k
    fprintf('Comparison of methods - round %i/%i\n',j,k)
    [modelk(j).dataTable_train,modelk(j).dataTable_test] = IBD_fs_splitDataTable(model.dataTable,model.N_test);
    for i = 1:length(modelTypes)
        modelTmp = modelk(j);
        modelTmp.type = modelTypes{i};
        modelTmp = IBD_fs_trainModel(modelTmp);
        modelTmp = IBD_fs_testModel(modelTmp);
        performance.correct(i,j)      = modelTmp.correct;
        performance.sensitivity(i,j)  = modelTmp.sensitivity;
        performance.specificity(i,j)  = modelTmp.specificity;
        performance.trainingTime(i,j) = modelTmp.trainingTime;
        performance.testingTime(i,j)  = modelTmp.testingTime;
    end
end

compTable       = array2table(nan(length(modelTypes),5),'VariableNames',{'sensitivity','specificity','correct','trainingTime','testingTime'},'RowNames',modelTypes);
for i = 1:length(modelTypes)
    compTable.correct(i)        = mean(performance.correct(i,:));
    compTable.sensitivity(i)    = mean(performance.sensitivity(i,:));
    compTable.specificity(i)    = mean(performance.specificity(i,:));
    compTable.trainingTime(i)   = mean(performance.trainingTime(i,:));
    compTable.testingTime(i)    = mean(performance.testingTime(i,:));
end

%--------------------------------------------------------------------------
end

