function [correct,sensitivity,specificity] = IBD_fs_crossValidation(model,k,suppressCommandLineOutput)
%==========================================================================
% [correct,sensitivity,specificity] = IBD_fs_crossValidation(model,k,suppressCommandLineOutput)
%==========================================================================
% Train and test a model using cross-validation
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% model:            model struct for feature selection
% k:                nr of training/testing rounds
%--------------------------------------------------------------------------
%-- output
% correct:          average fraction correctly identified
% sensitivity:      average sensitivity
% specificity:      average specificity
%==========================================================================

if ~exist('suppressCommandLineOutput','var')
    suppressCommandLineOutput = false;
end
performance = array2table(nan(k,3),'VariableNames',{'sensitivity','specificity','correct'});
modelk(1:k) = model;
for i = 1:k
    [modelk(i).dataTable_train,modelk(i).dataTable_test] = IBD_fs_splitDataTable(model.dataTable,model.N_test);
    modelk(i) = IBD_trainModel(modelk(i),suppressCommandLineOutput);
    modelk(i) = IBD_testModel(modelk(i),suppressCommandLineOutput);
    performance{i,'correct'}        = modelk(i).correct;
    performance{i,'sensitivity'}    = modelk(i).sensitivity;
    performance{i,'specificity'}    = modelk(i).specificity;
end
correct     = mean(performance.correct);
sensitivity = mean(performance.sensitivity);
specificity = mean(performance.specificity);

%--------------------------------------------------------------------------
end

