function model = IBD_fs_defaultModel(dataTable)
%==========================================================================
% model = IBD_fs_defaultModel(dataTable)
%==========================================================================
% Prepare feature selection model struct using default parameters
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% dataTable:    	dataset
%--------------------------------------------------------------------------
%-- output
% model:            model struct for feature selection
%==========================================================================

model.type      = 'LDA';
model.N_test    = 1000;
model.dataTable = dataTable;
if size(model.dataTable,1)<model.N_test*2
    warning('The size of the dataset is too small!')
end
[model.dataTable_train,model.dataTable_test] = IBD_fs_splitDataTable(model.dataTable,model.N_test);

% Options for specific classifiers
model.options.ANN.hiddenLayerSize   = 10;
model.options.ANN.trainRatio        = 70/100;
model.options.ANN.valRatio          = 15/100;
model.options.ANN.testRatio         = 15/100;
model.options.knn.NumNeighbours   	= 20;
model.options.knn.Distance          = 'euclidean';
model.options.randomForest.NumTrees = 100;
model.options.GPR.Sigma             = 0.7; 	% = std(model.dataTable.class)/sqrt(2)  (by definition)  (gprfit default)
%model.options.GPR.KernelParameters  = [mean(std(model.dataTable{:,1:end-1}))*10 1];
model.options.GPR.KernelParameters  = [5 1];
model.options.LDA.Delta             = 0;
model.options.LDA.Gamma             = 0;

%--------------------------------------------------------------------------
end

