function dataTableNew = IBD_fs_measurableStates(dataTable,individual_ref)
%==========================================================================
% dataTable = IBD_fs_measurableStates(dataTable,individual_ref)
%==========================================================================
% Condense dataset to measurable (sums of) state variables
% 24 January 2020
%--------------------------------------------------------------------------
%-- input
% dataTable:    	full dataset
% individual_ref:   reference individual
%--------------------------------------------------------------------------
%-- output
% dataTableNew:    	condensed dataset of measurable state variables
%==========================================================================

% Check that variable names are state names
assert(sum(ismember(dataTable.Properties.VariableNames(1:end-1),individual_ref.I.stateName))/individual_ref.I.nrOfStatesAdd>0.1,...
    'This function can only be used on a dataset of state variables.')

dataTableNew = table;

% LP:
% mucus, epi, tissue
dataTableNew.mucus      = dataTable.mucus;
dataTableNew.epi        = dataTable.epi;
dataTableNew.tissue     = dataTable.tissue;
% Bact
dataTableNew.Bact_LP  	= dataTable.Bact_LP;
% Neut
dataTableNew.Neut_LP  	= dataTable.Neut_LP;
% DCtot
dataTableNew.DC_tot_LP  = dataTable.DC_tot_LP;
% Mtot, Mpro, Manti
dataTableNew.M_tot_LP  	= dataTable.M_tot_LP;
dataTableNew.Mpro_LP    = dataTable.MP1_tot_LP + dataTable.MP2_tot_LP + dataTable.MP3_tot_LP;
dataTableNew.Manti_LP   = dataTable.MP4_tot_LP + dataTable.Meffero_tot_LP;
% Tem
dataTableNew.Tem_LP     = dataTable.Tm_tot_LP;
dataTableNew.Temprol_LN = sum(dataTable{:,[reshape(individual_ref.I.Tem2Th1_LP,1,[]),reshape(individual_ref.I.Tem2Th2_LP,1,[]),reshape(individual_ref.I.Tem2Th17_LP,1,[]),reshape(individual_ref.I.Tem2Treg_LP,1,[])]},2);
% Th1, Th2, Th17, iTreg
dataTableNew.Th1_eff_LP = dataTable.Th1_eff_LP;
dataTableNew.Th2_eff_LP = dataTable.Th2_eff_LP;
dataTableNew.Th17_eff_LP= dataTable.Th17_eff_LP;
dataTableNew.iTreg_eff_LP=dataTable.iTreg_eff_LP;

% LN:
% DCtot
dataTableNew.DC_tot_LN  = dataTable.DC_tot_LN;
% Tn
dataTableNew.Tn_LN      = dataTable.Tn_LN;
% Tcm
dataTableNew.Tcm_LN     = dataTable.Tcm_LN;
% Tnprol = effector
dataTableNew.Tnprol_LN  = sum(dataTable{:,[reshape(individual_ref.I.Tn2Th1_LN,1,[]),reshape(individual_ref.I.Tn2Th2_LN,1,[]),reshape(individual_ref.I.Tn2Th17_LN,1,[]),reshape(individual_ref.I.Tn2Treg_LN,1,[])]},2);
% Tcmprol = Tem
dataTableNew.Tcmprol_LN	= sum(dataTable{:,[reshape(individual_ref.I.Tcm2Tem1_LN,1,[]),reshape(individual_ref.I.Tcm2Tem2_LN,1,[]),reshape(individual_ref.I.Tcm2Tem17_LN,1,[]),reshape(individual_ref.I.Tcm2Temreg_LN,1,[])]},2);

% Class
if ismember('class',dataTable.Properties.VariableNames)
    dataTableNew.class      = dataTable.class;
end

%--------------------------------------------------------------------------
end

