function model = IBD_fs_testModel(model,suppressCommandLineOutput)
%==========================================================================
% model = IBD_fs_trainModel(model,suppressCommandLineOutput)
%==========================================================================
% Test a model
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% model:            model struct for feature selection
% suppressCommandLineOutput
%--------------------------------------------------------------------------
%-- output
% model:            model struct for feature selection         
%==========================================================================

if ~exist('suppressCommandLineOutput','var')
    suppressCommandLineOutput = false;
end

if ~suppressCommandLineOutput
    fprintf('Testing the %s model...',model.type)
end
tic_testing                 = tic;
switch model.type
    case 'ANN'
        net = model.classifier;
        [inputs_test,targets_test]  = IBD_fs_dataTable2ANN(model.dataTable_test);
        outputs_test        = net(inputs_test);
        model.output     	= array2table([(round(outputs_test(1,:))-round(outputs_test(2,:)))',(targets_test(1,:)-targets_test(2,:))'],'VariableNames',{'predicted','true'});
    case 'randomForest'
        [X_test,Y_test]     = IBD_fs_dataTable2XY(model.dataTable_test);
        label               = predict(model.classifier,X_test);
        label = cellfun(@(x) str2double(x),label);
        model.output     	= array2table([label,Y_test],'VariableNames',{'predicted','true'});
    case 'GPR'
        [X_test,Y_test]     = IBD_fs_dataTable2XY(model.dataTable_test);
        label0              = predict(model.classifier,X_test);
        label = zeros(size(label0));
        label(label0>0)     = 1;
        label(label0<0)     = -1;
        model.output     	= array2table([label,Y_test],'VariableNames',{'predicted','true'});
    otherwise
        [X_test,Y_test]     = IBD_fs_dataTable2XY(model.dataTable_test);
        label               = predict(model.classifier,X_test);
        model.output     	= array2table([label,Y_test],'VariableNames',{'predicted','true'});
end
model.testingTime           = toc(tic_testing);
if ~suppressCommandLineOutput
    fprintf(' took %.1f s.\n',model.testingTime);
end

% Sensitivity, specificity and fraction correctly identified
model.specificity	= sum(model.output.predicted==1  & model.output.true==1 )/sum(model.output.true==1 );
model.sensitivity   = sum(model.output.predicted==-1 & model.output.true==-1)/sum(model.output.true==-1);
model.correct       = sum(model.output.predicted==model.output.true)/model.N_test;
if ~suppressCommandLineOutput
    fprintf('Fraction correctly identified by the %s model: %.2f\n',model.type,model.correct);
end

%--------------------------------------------------------------------------
end
