function cmap = IBD_colourMap(name,nr)
%==========================================================================
% cmap = IBD_colourMap(name,nr)
%==========================================================================
% Definition of colour map
%--------------------------------------------------------------------------
%-- input
% name:       	name of colour scheme
% nr:           nr of colours to be returned
%--------------------------------------------------------------------------
%-- output
% cmap:       	colour map
%==========================================================================

% Colour schemes
switch name
    
    case 'violet-green'
        colTable    = [ 0.6     0.0     0.6;... % violet
                        0.0     0.2     0.5;...	% blue
                        0.0     0.5     0.0];	% green
        
    case 'green-red'
        colTable    = [ 0.0     0.45    0.0;...	% green
                        0.8     0.8     0.0;...	% yellow
                        0.9     0.0     0.0]; 	% red
        
    case 'rainbow'
        colTable    = [ 1.0     0.0     0.0;... % red
                        1.0     0.5     0.0;... % orange
                        1.0     1.0     0.0;... % yellow
                        0.0     1.0     0.0;... % green
                        0.0     0.0     1.0;... % blue
                        1.0     0.0     1.0;... % violet
                        1.0     0.0     0.0];  	% red
                    
	case 'dark rainbow'
        colTable    = [ 1.0     0.0     0.0;... % red
                        1.0     0.5     0.0;... % orange
                        1.0     1.0     0.0;... % yellow
                        0.0     1.0     0.0;... % green
                        0.0     0.0     1.0;... % blue
                        1.0     0.0     1.0;... % violet
                        1.0     0.0     0.0];  	% red
        colTable = colTable *0.7;
    otherwise
        fprintf(2,'The colourmap %s is not defined.\n',name);
        colTable    = [ 1.0     1.0     1.0;...
                        0.0     0.0     0.0];
end

% Generate colourmap
cmap                = zeros(nr,3);
nrOfSpecifiedCols   = size(colTable,1);

for i = 1:3
    for j = 1:nrOfSpecifiedCols-1
        startI  = max(1,ceil(nr/(nrOfSpecifiedCols-1)*(j-1)));
        endI    = ceil(nr/(nrOfSpecifiedCols-1)*j);
        cmap(startI:endI,i)	= linspace(colTable(j,i),colTable(j+1,i),endI-startI+1);
    end
end

%--------------------------------------------------------------------------

end