function [CDEIS,details] = IBD_CDEIS(ss,I)
%==========================================================================
% CDEIS = IBD_CDEIS(ss,individual_ref)
%==========================================================================
% Calculation of Crohn's disease endoscopic index of severity
%--------------------------------------------------------------------------
%-- input
% ss:        	steady state (pxn matrix, p = nr of states, n = nr of ind)
% I:            index struct
%--------------------------------------------------------------------------
%-- output
% CDEIS:       	row vector of CDEIS values per individual
%==========================================================================

% Deep ulcerations
% --> based on tissue
% 0 - 12
thresholdTissue.upper   = 0.90;
thresholdTissue.lower   = 0.61;
maxScoreTissue         	= 12;
deepUlcerations         = maxScoreTissue*(ss(I.tissue,:)-thresholdTissue.upper)/(thresholdTissue.lower-thresholdTissue.upper);
deepUlcerations(deepUlcerations<0)              = 0;
deepUlcerations(deepUlcerations>maxScoreTissue)	= maxScoreTissue;

% Superficial ulcerations
% --> based on epi
% 0 - 6
thresholdEpi.upper      = 0.80;
thresholdEpi.lower      = 0.37;
maxScoreEpi             = 6;
superficialUlcerations  = maxScoreEpi*(ss(I.epi,:)-thresholdEpi.upper)/(thresholdEpi.lower-thresholdEpi.upper);
superficialUlcerations(superficialUlcerations<0)            = 0;
superficialUlcerations(superficialUlcerations>maxScoreEpi)  = maxScoreEpi;

% Suface involved by disease
% --> based on neutrophils
% 0 - 10
KmNeut                  = 4.74e7;
hNeut                   = 2;
surfaceDisease          = 10*ss(I.Neut_LP,:).^hNeut./(KmNeut.^hNeut+ss(I.Neut_LP,:).^hNeut);

% Ulcerated surface
% --> based on tissue and epi
% 0 - 10
surfaceUlcerations      = (1-(1-deepUlcerations/maxScoreTissue).*(1-superficialUlcerations/maxScoreEpi))*10;

% Stenosis
thresholdStenosis       = 1.10;
thresholdUlcer          = 5;
% Non-ulcerated stenosis
nonUlceratedStenosis    = (ss(I.tissue,:)>thresholdStenosis)*3;

% Ulcerated stenosis
ulceratedStenosis       = (nonUlceratedStenosis & surfaceUlcerations>thresholdUlcer)*3;

% Add up to CDEIS
CDEIS = deepUlcerations + superficialUlcerations + surfaceDisease + surfaceUlcerations + ulceratedStenosis + nonUlceratedStenosis;

% Save the single summands in table
deepUlcerations         = deepUlcerations';
superficialUlcerations  = superficialUlcerations';
surfaceDisease          = surfaceDisease';
surfaceUlcerations      = surfaceUlcerations';
ulceratedStenosis       = ulceratedStenosis';
nonUlceratedStenosis    = nonUlceratedStenosis';
CDEIS                   = CDEIS';
details = table(deepUlcerations,superficialUlcerations,surfaceDisease,surfaceUlcerations,ulceratedStenosis,nonUlceratedStenosis,CDEIS);

end

