function [parAnnot,colour] = IBD_annotatePars(parNames)
%==========================================================================
% [parAnnot,colour] = IBD_annotatePars(parNames)
%==========================================================================
% Annotation of parameters
%--------------------------------------------------------------------------
%-- input
% parNames:  	cell array of parameter names
%--------------------------------------------------------------------------
%-- output
% parAnnot:   	cell array of processes
% colour:       struct of colours for each process
%==========================================================================

% Processes (caution: the order is important!)
annot.Neut  = {'Neut','neut'};
annot.barrier = {'mucus','Mucus','epi','Epi','tis','Tis','Affinity','affinity'};
annot.B     = {'Affinity','affinity'};
annot.Phago = {'phago','Phago'};
annot.Bact  = {'Bact','STm','nutrients','Nutrients'};
annot.DC    = {'DC'};
annot.T     = {'T','ACAD','AICD','IL2','Apo','apo','alpha','beta'};
annot.M     = {'M'};
annot.other = {'.'};
processes   = fieldnames(annot)';

for i = 1:length(processes)
    I.(processes{i}) = i;
end

idx = zeros(length(processes),length(parNames));

for i = 1:length(processes)
    process = processes{i};
    searchStrings = annot.(char(process));
    for j = 1:length(searchStrings)
        idx(I.(process),:) = any([idx(I.(process),:);contains(parNames,searchStrings{j})],1);
    end
end
idx(I.other,:) = 1;

parAnnot = cell(1,length(parNames));
for i = 1:length(parNames)
    parAnnot{i} = processes{find(idx(:,i),1)};
end

%--------------------------------------------------------------------------
% Colours
colour = IBD_myColours('annotatePars');

%--------------------------------------------------------------------------
end

