function [stateAnnot] = IBD_annotateStates(stateNames)
%==========================================================================
% [stateAnnot] = IBD_annotateStates(stateNames)
%==========================================================================
% Annotation of state variables
%--------------------------------------------------------------------------
%-- input
% stateNames:  	cell array of parameter names
%--------------------------------------------------------------------------
%-- output
% parAnnot:   	cell array of processes
% colour:       struct of colours for each process
%==========================================================================

% Processes (caution: the order is important!)
annot.Neut  = {'Neut','neut'};
annot.barrier = {'mucus','Mucus','epi','Epi','tis','Tis','Affinity','affinity'};
annot.Phago = {'phago','Phago'};
annot.Bact  = {'Bact','STm','nutrients','Nutrients'};
annot.cyto  = {'SPM','PRO','ANTI','IL'};
annot.DC    = {'DC'};
annot.Tn    = {'Tn'};
annot.Tm    = {'Tem','Tcm'};
annot.Th    = {'Th'};
annot.Treg  = {'Treg'};
annot.Mpro = {'MP1','MP2','MP3'};
annot.Manti  = {'MP4','Meffero'};
annot.other = {'.'};
processes   = fieldnames(annot)';

for i = 1:length(processes)
    I.(processes{i}) = i;
end

idx = zeros(length(processes),length(stateNames));

for i = 1:length(processes)
    process = processes{i};
    searchStrings = annot.(char(process));
    for j = 1:length(searchStrings)
        idx(I.(process),:) = any([idx(I.(process),:);contains(stateNames,searchStrings{j})],1);
    end
end
idx(I.other,:) = 1;

stateAnnot = cell(1,length(stateNames));
for i = 1:length(stateNames)
    stateAnnot{i} = processes{find(idx(:,i),1)};
end

%--------------------------------------------------------------------------

end

