function auxPar = IBD_auxParameters(primPar,model)
%==========================================================================
% auxPar = IBD_auxParameters(primPar,model)
%==========================================================================
% Auxiliary parameters (calculated from primary, needed for secondary)
%--------------------------------------------------------------------------
%-- input
% primPar:  	primary parameter vector
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% auxPar:     	auxiliary parameter vector
%==========================================================================

fprintf('Assigning auxiliary parameters...\n')
primI   = model.I.prim;
auxI    = model.I.aux;
auxPar  = nan(1,length(model.auxParNames));

%--------------------------------------------------------------------------

auxPar(auxI.concCD4_LN)             = primPar(primI.concCD4_totLN)/primPar(primI.fractionTzoneLN);          % [1/mL] concentration of CD4+ T cells in MLN T cell zone
auxPar(auxI.concTn_LN)              = auxPar(auxI.concCD4_LN)*primPar(primI.fractionTnCD4_LN);              % [1/mL] concentration of naive CD4+ T cells in MLN T cell zone
auxPar(auxI.concTcm_LN)             = auxPar(auxI.concCD4_LN)*primPar(primI.fractionTcmCD4_LN);             % [1/mL] concentration of central memory T cells in MLN T cell zone
auxPar(auxI.concTem_LN)             = auxPar(auxI.concCD4_LN)*primPar(primI.fractionTemCD4_LN);             % [1/mL] concentration of effector memory T cells in MLN T cell zone
auxPar(auxI.concTreg_LN)            = primPar(primI.fractionTregLy_LN)*auxPar(auxI.concCD4_LN)*...
    (1+1/primPar(primI.ratioTB_LN))*(1+1/primPar(primI.ratioCD4CD8_LN));                                    % [1/mL] concentration of regulatory T cells in MLN T cell zone
auxPar(auxI.concNTreg_LN)           = auxPar(auxI.concTreg_LN)*primPar(primI.fractionNTregTreg_LN);         % [1/mL] concentration of natural regulatory T cells in MLN T cell zone
auxPar(auxI.concITreg_LN)           = auxPar(auxI.concTreg_LN)*(1-primPar(primI.fractionNTregTreg_LN));    	% [1/mL] concentration of induced regulatory T cells in MLN T cell zone
auxPar(auxI.concCD4_LP)             = primPar(primI.concT_LP)/(1+1/primPar(primI.ratioCD4CD8_LP));         	% [1/mL] concentration of CD4+ T cells in colon lamina propria
auxPar(auxI.concTreg_LP)            = primPar(primI.fractionTregLy_LP)*primPar(primI.concT_LP)*...
    (1+1/primPar(primI.ratioTB_LP));                                                                      	% [1/mL] concentration of regulatory T cells in colon lamina propria
auxPar(auxI.concNTreg_LP)           = auxPar(auxI.concTreg_LP)*primPar(primI.fractionNTregTreg_LP);        	% [1/mL] concentration of natural regulatory T cells in colon lamina propria
auxPar(auxI.concITreg_LP)           = auxPar(auxI.concTreg_LP)*(1-primPar(primI.fractionNTregTreg_LP));   	% [1/mL] concentration of induced regulatory T cells in colon lamina propria
auxPar(auxI.concTem_LP)             = auxPar(auxI.concCD4_LP)*primPar(primI.fractionTmCD4_LP);           	% [1/mL] concentration of effector memory T cells in colon lamina propria
auxPar(auxI.concDC_LP)              = primPar(primI.concT_LP)/primPar(primI.fractionTLPMC)*...
    primPar(primI.fractionDCLPMC);                                                                          % [1/mL] concentration of dendritic cells in colon lamina propria
auxPar(auxI.concM_LP)               = primPar(primI.concT_LP)/primPar(primI.fractionTLPMC)*...
    primPar(primI.fractionDCLPMC)*primPar(primI.ratioMDC);                                                  % [1/mL] concentration of macrophages in colon lamina propria
auxPar(auxI.concBact_LP)            = primPar(primI.concBact_LP);                                           % [1/mL] concentration of commensal bacteria in colon lamina propria
auxPar(auxI.concNeut_LP)            = primPar(primI.concNeut_LP);                                           % [1/mL] concentration of neutrophils in colon lamina propria
auxPar(auxI.fractionTregCD4_bl) 	= primPar(primI.fractionTregLy_bl)*(1+1/primPar(primI.ratioTB_bl))*...
    (1+1/primPar(primI.ratioCD4CD8_bl));                                                                 	% [] fraction of regulatory T cells from CD4+ T cells in blood
auxPar(auxI.fractionNTregCD4_bl) 	= auxPar(auxI.fractionTregCD4_bl)*primPar(primI.fractionNTregTreg_bl);	% [] fraction of natural regulatory T cells from CD4+ T cells in blood

% (general assumption: CD4 + CD8 = total T)

%--------------------------------------------------------------------------
% Test if all parameters assigned
if any(isnan(auxPar))
    fprintf(2,'The following auxiliary parameters are not assigned: %s.\n',strjoin(model.auxParNames(isnan(auxPar)),' '));
end

%--------------------------------------------------------------------------

end