function [t,x] = IBD_biomarkerSamples(T,Xi,ts)
%==========================================================================
% [] = IBD_biomarkerSamples(T,Xi,ts)
%==========================================================================
% Samples of biomarkers as average last sampling time point
%--------------------------------------------------------------------------
%-- input
% T:            time points of simulation
% Xi:           simulated time course of the biomarker
% ts:          	sampling time points (incl. 
%--------------------------------------------------------------------------
%-- output
% t:            sampling time points
% x:            sampling biomarker values
%==========================================================================

x = nan(size(ts));

% Check if sampling time points are inside simulated time points
assert(sum(T>=ts(end))>0,'Biomarker sampling time points are outside the simulation times.')

% If first sampling time point before start of simulation, use x value at time point 0
if ts(1)<T(1)
    T = [ts(1);T];
    Xi = [Xi(1);Xi];
end

% Add the sampling time points (approximated)
for i = 1:length(ts)
    if sum(T==ts(i)) == 0
        T           = [T;ts(i)];
        idx_last    = find(T<ts(i),1,'last');
        idx_next    = find(T>ts(i),1,'first');
        m           = (Xi(idx_next)-Xi(idx_last))/(T(idx_next)-T(idx_last));
        Xi          = [Xi;Xi(idx_last) + m*(ts(i)-T(idx_last))];
    end
end
[T,idx]	= sort(T);
Xi   	= Xi(idx);

% Average since last sampling for all sampling time points except first
for i = 2:length(ts)
    idx         = find(T>=ts(i-1) & T<=ts(i));
    
    x(i)        = 0;
    for j = 2:length(idx)
        x(i)    = x(i) + (Xi(idx(j-1))+Xi(idx(j)))/2*(T(idx(j))-T(idx(j-1)));
    end
    
    x(i)        = x(i)/(ts(i)-ts(i-1));
    
end

t = ts(2:end);
x = x(2:end);

end