function classDefinition = IBD_centroids(individual_ref)
%==========================================================================
% classDefinition = IBD_centroids(individual_ref)
%==========================================================================
% Options for classification of individuals according to inflammation time 
% course
%--------------------------------------------------------------------------
%-- input
% individual_ref
%--------------------------------------------------------------------------
%-- output
% classDef:     struct defining the classes, with fields:
%               centroids
%               data: function handle
%               I: index and class name
%               Distance (for pdist2)
%==========================================================================

className                       = {'healthy','IBD','chronic_inflammation','chronic_infection'};
classDefinition                 = struct;
classDefinition.I               = struct;
classDefinition.I.className     = className;
for i = 1:length(className)
    classDefinition.I.(className{i}) = i;
end
classDefinition.I.nrOfClasses	= i;
classDefinition.I.allClasses    = 1:i;

classDefinition.Distance       	= 'squaredeuclidean';   % for pdist2

if exist('individual_ref','var')
    % Centroids for classification (relative to reference individual):
    %                                                                           steady state before     ss after/before       	Bact after
    %                                                                           Th      Neut    M       Th      Neut    M       
    classDefinition.centroids(classDefinition.I.healthy,:)                = [	1       1       1       1       1   	1    	1   	];
    classDefinition.centroids(classDefinition.I.IBD,:)                    = [	1       1       1       2       2       2    	1    	];
    classDefinition.centroids(classDefinition.I.chronic_inflammation,:)   = [  10      10      10       1       1       1   	1    	];
    classDefinition.centroids(classDefinition.I.chronic_infection,:)      = [   1       1       1       1       1       1    	individual_ref.par(individual_ref.I.NmaxBact)/individual_ref.Xadd_ss_after(individual_ref.I.Bact_LP)/10];
else
    classDefinition.centroids = nan;
end

classDefinition.data = @(ssBefore,ssAfter,I) fh_classData(ssBefore,ssAfter,I);

end


%==========================================================================
% LOCAL FUNCTIONS
function X = fh_classData(ssBefore,ssAfter,I)
X = [ssBefore([I.Th_tot_LP,I.Neut_LP,I.M_tot_LP],:)',...
    (ssAfter([I.Th_tot_LP,I.Neut_LP,I.M_tot_LP],:)'./ssBefore([I.Th_tot_LP,I.Neut_LP,I.M_tot_LP],:)'),...
  	 ssAfter( I.Bact_LP,:)'];
end




%--------------------------------------------------------------------------

