function [class] = IBD_classifyInflammation(ssBefore,ssAfter,classDefinition,individual_ref)
%==========================================================================
% [class] = IBD_classifyInflammation(ssBefore,ssAfter,classDefinition,individual_ref)
%==========================================================================
% Classification of individuals according to inflammation time course
%--------------------------------------------------------------------------
%-- input
% ssBefore:     steady state before inflammation scenario
% ssAfter:      steady state after inflammation scenario
% classDefinition
% individual_ref:reference individual
%--------------------------------------------------------------------------
%-- output
% class:        vector of class per individual
%==========================================================================

I = individual_ref.I;

% Prepare X for classification
X_cluster   = classDefinition.data(ssBefore,ssAfter,I);
X_ref       = classDefinition.data(individual_ref.Xadd_ss',individual_ref.Xadd_ss_after',I);           
           
% Normalise X by reference individual
X_cluster   = X_cluster./X_ref;

% Classification by distance to centroids
if any(~isreal(X_cluster))
    class = 0;
else
    [~,class] 	= pdist2(classDefinition.centroids,X_cluster,classDefinition.Distance,'Smallest',1);
end

%--------------------------------------------------------------------------

end

