function [parTable,primParTable,auxParTable] = IBD_definePars()
%==========================================================================
% [parTable,primParTable,auxParTable] = IBD_definePars()
%==========================================================================
% Define parameter names, characteristics and description
%--------------------------------------------------------------------------
%-- output
% stateTable:  	table of state names, characteristics and description
%==========================================================================

i = 1;
name            = {}; 	% parameter name
order           = [];   % 0 = zero; 1 = first; 2 = second order; 3 = none
comp            = [];  	% compartment: 1 = LP; 2 = LN; 3 = bl; 0 = not defined (e.g. both) (only relevant for 1st and 2nd order processes)
BactSpecific 	= [];   % true/false
unit            = {};   % unit
description     = {};   % description of parameter

%--------------------------------------------------------------------------
%% Secondary parameters

% Volumes
name{i} = 'VLP';                order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'total mesenteric lymph node volume'; i=i+1;
name{i} = 'VLN';                order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'total lamina propria volume'; i=i+1;
name{i} = 'maxConc';            order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/mL';       description{i} = 'maximal reasonable concentration'; i=i+1;

% T cells
name{i} = 'muT_LN';             order(i) = 1;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'outflow of T cells from MLN'; i=i+1;
name{i} = 'muT_LP';             order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'outflow of natural regulatory T cells and effector memory T cells from LP'; i=i+1;
name{i} = 'lambdaT_LN';         order(i) = 0;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';   description{i} = 'rate constant (inflow rate constant * volume correction coefficient * concentration of CD4+ T cells in blood) for inflow of T cells into MLN'; i=i+1;
name{i} = 'muTeff';             order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'effector T cell death rate constant'; i=i+1;
name{i} = 'fractionTnCD4_bl'; 	order(i) = 3;	comp(i) = 3;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of naive CD4+ T cells from CD4+ T cells (blood)'; i=i+1;
name{i} = 'fractionTcmCD4_bl'; 	order(i) = 3;	comp(i) = 3;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of central memory CD4+ T cells from CD4+ (blood)'; i=i+1;

% T cell proliferation (transit compartments)
name{i} = 'nTn';                order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal number of transit compartments for naive T cells'; i=i+1;
name{i} = 'nTm';                order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of transit compartments for differentiation/proliferation of memory T cells'; i=i+1;
name{i} = 'muTprol';          	order(i) = 1;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/h';     	description{i} = 'death rate constant of proliferating T cells'; i=i+1;
name{i} = 'suscApoLow';         order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th)'; i=i+1;
name{i} = 'pTn1';             	order(i) = 1;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'proliferation rate constant of activated naive T cells (first division)'; i=i+1;
name{i} = 'pTni';             	order(i) = 1;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'proliferation rate constant of activated naive T cells (subsequent divisions)'; i=i+1;
name{i} = 'egressPerDivision'; 	order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'increase in egress rate per division (starting at threshold)'; i=i+1;
name{i} = 'egressThreshold'; 	order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'minimal division number for egress'; i=i+1;
name{i} = 'egressThresholdm'; 	order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'minimal division number for egress (memory T cells)'; i=i+1;

% Effector T cells
name{i} = 'theta1host';         order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th1 cells elicited by this host'; i=i+1;
name{i} = 'theta2host';         order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th2 cells elicited by this host'; i=i+1;
name{i} = 'theta17host';      	order(i) = 3;	comp(i) = 2;	BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th17 cells elicited by this host'; i=i+1;
name{i} = 'theta1bact';         order(i) = 3;	comp(i) = 2;	BactSpecific(i) = true;   	unit{i} = '';           description{i} = 'fraction of Th1 cells elicited by this bacterial species'; i=i+1;
name{i} = 'theta2bact';         order(i) = 3;	comp(i) = 2;	BactSpecific(i) = true;   	unit{i} = '';           description{i} = 'fraction of Th2 cells elicited by this bacterial species'; i=i+1;
name{i} = 'theta17bact';     	order(i) = 3;	comp(i) = 2;	BactSpecific(i) = true;   	unit{i} = '';           description{i} = 'fraction of Th17 cells elicited by this bacterial species'; i=i+1;

% Antigen specificities
name{i} = 'alphaTn';            order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'frequency of antigen specificity in naive T cells'; i=i+1;
name{i} = 'alphaTh';            order(i) = 3;	comp(i) = 0;	BactSpecific(i) = true;     unit{i} = '';           description{i} = 'frequency of antigen specificity in effector T cells'; i=i+1;
name{i} = 'alphaTm';            order(i) = 3;	comp(i) = 0;	BactSpecific(i) = true;     unit{i} = '';           description{i} = 'frequency of antigen specificity in memory T cells'; i=i+1;
name{i} = 'beta';               order(i) = 3;   comp(i) = 0;   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of antigens per bacterium/presented per dendritic cell'; i=i+1;
name{i} = 'Tcontact';           order(i) = 3;   comp(i) = 0;    BactSpecific(i) = false;    unit{i} = 'h';          description{i} = 'mean contact duration between DC and Tn/Tm'; i=i+1;

% Dendritic cells
name{i} = 'muDC';               order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'death rate constant of dendritic cells'; i=i+1;
name{i} = 'muDC_LN';         	order(i) = 1;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'migration rate of dendritic cells out of LN'; i=i+1;
name{i} = 'nuDCa';              order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'conversion rate constant from antigen-unexperienced to antigen-experienced dendritic cells (LP)'; i=i+1;
name{i} = 'epsilonDC';          order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'migration of dendritic cells from LP to MLN'; i=i+1;
name{i} = 'cRecDC';             order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';	description{i} = 'constant inflow of quiescent dendritic cells into LP'; i=i+1;
name{i} = 'nuDCsMax';           order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'maximal dendritic cell activation'; i=i+1;
name{i} = 'HillProActDC';      	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for dendritic cell activation stimulation by pro-inflammatory cytokines'; i=i+1;
name{i} = 'HillAntiActDC';     	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for dendritic cell activation inhibition by anti-inflammatory cytokines'; i=i+1;

% Contact rates
name{i} = 'kTDC_LN';            order(i) = 2;	comp(i) = 2;	BactSpecific(i) = false;	unit{i} = 'mL/h';       description{i} = 'contact rate constant for T and DC in LN'; i=i+1;
name{i} = 'kTDC_LP';            order(i) = 2;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = 'mL/h';       description{i} = 'contact rate constant for T and DC in LP'; i=i+1;
name{i} = 'bsPerDC';         	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'T cell binding sites per DC'; i=i+1;
name{i} = 'bsPerT';         	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'DC binding sites per T cell'; i=i+1;
name{i} = 'bsPerM';         	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'T cell binding sites per macrophage'; i=i+1;

% Macrophages
name{i} = 'muM';                order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'death of macrophages'; i=i+1;
name{i} = 'nuMP12ss';           order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'transition from macrophage compartment 1 to 2 in steady state'; i=i+1;
name{i} = 'nuMP23ss';           order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'transition from macrophage compartment 2 to 3 in steady state'; i=i+1;
name{i} = 'nuMP34ss';           order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'transition from macrophage compartment 3 to 4 in steady state'; i=i+1;
name{i} = 'phagoMP1';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P1 macrophages, relative to dendritic cells'; i=i+1;
name{i} = 'phagoMP2';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P2 macrophages, relative to dendritic cells'; i=i+1;
name{i} = 'phagoMP3';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P3 macrophages, relative to dendritic cells'; i=i+1;
name{i} = 'phagoMP4';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P4 macrophages, relative to dendritic cells'; i=i+1;
name{i} = 'lambdaMmax';         order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';	description{i} = 'maximal macrophage inflow into LP'; i=i+1;
name{i} = 'HillRecM';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for macrophage recruitment by stimulated cells'; i=i+1;
name{i} = 'cRecM';              order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';	description{i} = 'constant macrophage inflow into LP'; i=i+1;
name{i} = 'nuMphago';           order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of macrophages that move to next state after phagocytosis of one apoptotic neutrophil'; i=i+1;
name{i} = 'HillProActM';      	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for macrophage transition inhibition by pro-inflammatory cytokines'; i=i+1;
name{i} = 'HillAntiActM';      	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for macrophage transition stimulation by anti-inflammatory cytokines'; i=i+1;

% Pathogenic bacteria in LP
name{i} = 'pBact';              order(i) = 1;	comp(i) = 1;	BactSpecific(i) = true;     unit{i} = '1/h';        description{i} = 'growth of bacteria in tissue'; i=i+1;
name{i} = 'NmaxBact';           order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;  	unit{i} = '1/mL';       description{i} = 'maximal concentration of bacteria in LP'; i=i+1;
name{i} = 'VmaxPhago';          order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;   	unit{i} = '1/h';        description{i} = 'maximal phagocytosis rate of bacteria per neutrophil (/phagocytic cell)'; i=i+1;
name{i} = 'KmPhago';            order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;  	unit{i} = '1/mL';       description{i} = 'bacteria concentration for half-maximal phagocytosis rate per neutrophil (/phagocytic cell)'; i=i+1;
name{i} = 'phagoRec';        	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = true;  	unit{i} = '';           description{i} = 'probability of recognition of bacteria by phagocytic cells'; i=i+1;
name{i} = 'pSTmInt';            order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';     	description{i} = 'intracellular growth rate of S.Tm'; i=i+1;
name{i} = 'Nburst';             order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'burst threshold: maximal number of bacteria per macrophage'; i=i+1;

% Neutrophils
name{i} = 'lambdaNeutMax';      order(i) = 0;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';	description{i} = 'maximal neutrophil inflow into LP'; i=i+1;
name{i} = 'HillRecNeut';        order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for neutrophil recruitment'; i=i+1;
name{i} = 'muNeutc';            order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'constitutive/spontaneous neutrophil apoptosis'; i=i+1;
name{i} = 'muNeutPhago';      	order(i) = 3;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell'; i=i+1;
name{i} = 'muNeutMax';          order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'maximal neutrophil apoptosis, stimulated by SPM'; i=i+1;
name{i} = 'muAponeut';          order(i) = 1;	comp(i) = 1;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'necrosis of apoptotic neutrophils'; i=i+1;

% Bacteria in lumen
name{i} = 'pBactLu';            order(i) = 2;	comp(i) = 0;	BactSpecific(i) = true;     unit{i} = '1/h';        description{i} = 'proliferation of bacteria in lumen'; i=i+1;
name{i} = 'muBactLu';           order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'death of bacteria in lumen'; i=i+1;
name{i} = 'lambdaNutrients';  	order(i) = 0;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'inflow of nutrients'; i=i+1;

% Mucus & epithelial barrier
name{i} = 'epsilonBact1';     	order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/(mL*h)';	description{i} = 'inflow of bacteria without toxin'; i=i+1;
name{i} = 'epsilonBact2';     	order(i) = 1;	comp(i) = 0;	BactSpecific(i) = true;     unit{i} = '1/(mL*h)'; 	description{i} = 'inflow of bacteria with toxin'; i=i+1;
name{i} = 'muEpi';              order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'degradation of epithelium'; i=i+1;
name{i} = 'ssEpi';              order(i) = 0;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of epithelium'; i=i+1;
name{i} = 'muEpiBact';       	order(i) = 2;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = 'mL';         description{i} = 'destruction of epithelium by bacteria with toxin'; i=i+1;
name{i} = 'muEpiFac';        	order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal relative increase of epithelium degradation'; i=i+1;
name{i} = 'muMucus';            order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'degradation of mucus layer'; i=i+1;
name{i} = 'ssMucus';         	order(i) = 0;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of mucus'; i=i+1;
name{i} = 'muTis';              order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'degradation of tissue'; i=i+1;
name{i} = 'ssTis';              order(i) = 0;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of tissue'; i=i+1;
name{i} = 'muTisFac';           order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal relative increase of tissue degradation'; i=i+1;
name{i} = 'epsilonFCP';     	order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;   	unit{i} = 'mL*ug/(h*g)';description{i} = 'outflow of neutrophils (FCP) into lumen'; i=i+1;
name{i} = 'muFCP';              order(i) = 1;	comp(i) = 0;	BactSpecific(i) = false;   	unit{i} = '1/h';        description{i} = 'outflow of FCP from lumen'; i=i+1;

% Weights for phagocytosis
% --> relative to neutrophils (weight Neut = 1)
name{i} = 'wPhagoLPqDC';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPrDC';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPtDC';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPsDC';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPMP1';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPMP2';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPMP3';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPMP4';        order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;
name{i} = 'wPhagoLPNeut';       order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; i=i+1;

% Weights for cytokine production
name{i} = 'wcyto_RecNeut_Th1';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecNeut_Th17';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecNeut_Neut';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecNeut_M';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecM_Th1';     order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecM_Th17';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecM_Neut';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_RecM_M';       order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActM_Th1';     order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActM_Th17';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActM_Neut';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActM_M';       order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActDC_Th1';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActDC_Th17';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActDC_Neut';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_ActDC_M';      order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactM_Treg';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactM_Th2';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactM_M';     order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactDC_Treg';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactDC_Th2';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DeactDC_M';	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageEpi_Th1';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageEpi_Th17';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageEpi_Th2';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageEpi_Neut';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageEpi_M'; 	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageTis_Th1';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageTis_Th17';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageTis_Th2';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageTis_Neut';order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_DamageTis_M'; 	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_TisRemod_Th2'; order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wcyto_TisRemod_M'; 	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; i=i+1;
name{i} = 'wProLPBact';      	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight of stimulatory cytokine production --> relative to neutrophils (only for neutrophil recruitment)'; i=i+1;     

% Weights of specialised pro-resolving mediator production
% --> relative to neutrophils (weight Neut = 1)
name{i} = 'wSPMLPNeut';         order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for SPM production --> relative to neutrophils'; i=i+1;
name{i} = 'wSPMLPMeffero';     	order(i) = 3;	comp(i) = 0;	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for SPM production --> relative to neutrophils'; i=i+1;

parTable = table(name',order',comp',BactSpecific',unit',description','VariableNames',{'name','order','comp','BactSpecific','unit','description'},'RowNames',name);

%--------------------------------------------------------------------------
%% Primary parameters
i = 1;
name            = {}; 	% parameter name
BactSpecific 	= [];   % true/false
unit            = {};   % unit
description     = {};   % description of parameter
reference       = {};   % reference

% Volumes
name{i} = 'VLN';                    BactSpecific(i) = false;	unit{i} = 'mL';         description{i} = 'volume of one mesenteric lymph node'; reference{i} = '[ICRP1975]'; i=i+1;
name{i} = 'VLN_tot';                BactSpecific(i) = false;	unit{i} = 'mL';     	description{i} = 'total mesenteric lymph node volume'; reference{i} = '[ICRP1975]'; i=i+1;
name{i} = 'VLP_tot';                BactSpecific(i) = false;	unit{i} = 'mL';     	description{i} = 'total lamina propria volume (small + large intestine)'; reference{i} = '[Helander2014],[Dhesi1984]'; i=i+1;
name{i} = 'Vcell';                  BactSpecific(i) = false;	unit{i} = 'mL';       	description{i} = 'mean cell volume'; reference{i} = '[Chapman1981]'; i=i+1;

% Steady state concentrations in healthy colon lamina propria
name{i} = 'concT_LP';               BactSpecific(i) = false;	unit{i} = '1/mL';     	description{i} = 'T cells (sigmoid colon)'; reference{i} = '[Preza2015]'; i=i+1;
name{i} = 'ratioTB_LP';             BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio T:B (colon)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'ratioCD4CD8_LP';      	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio CD4:CD8 (colon)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTmCD4_LP';      	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of CD4+ memory T cells from CD4+ T cells (colon, age 30-50)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTregLy_LP';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of regulatory T cells from LP lymphocytes (colon)'; reference{i} = '[Saruta2007]'; i=i+1;
name{i} = 'fractionNTregTreg_LP';	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of Helios+ from FOXP3+ T cells in colon'; reference{i} = '[Lord2015a]'; i=i+1;
name{i} = 'fractionTLPMC';        	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of T cells from colon LPMC'; reference{i} = '[Junker2009]'; i=i+1;
name{i} = 'fractionDCLPMC';        	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of dendritic cells from colon LPMC'; reference{i} = '[Bernardo2016]'; i=i+1;
name{i} = 'ratioMDC';               BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio of macrophages to dendritic cells (small intestine, mouse)'; reference{i} = '[Schulz2009]'; i=i+1;
name{i} = 'concBact_LP';         	BactSpecific(i) = false;	unit{i} = '1/mL';     	description{i} = 'commensal bacteria (sigmoid colon)'; reference{i} = '[Swidsinski2010]'; i=i+1;
name{i} = 'concNeut_LP';         	BactSpecific(i) = false;	unit{i} = '1/mL';     	description{i} = 'neutrpphil concentration in healthy tissue (gaster)'; reference{i} = '[Fu2016]'; i=i+1;

% Steady state concentrations in mesenteric lymph node
name{i} = 'concCD4_totLN';        	BactSpecific(i) = false;	unit{i} = '1/mL';    	description{i} = 'concentration of CD4+ T cells in lymphoid tissue'; reference{i} = '[Zhang1998]'; i=i+1;
name{i} = 'ratioTB_LN';           	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio T:B (MLN)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'ratioCD4CD8_LN';        	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio CD4:CD8 (MLN)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTnCD4_LN';     	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of naive CD4+ T cells from CD4+ T cells'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTcmCD4_LN';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of central memory CD4+ T cells from CD4+ T cells'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTemCD4_LN';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of effector memory CD4+ T cells from CD4+ T cells'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTzoneLN';      	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of T cell zone in lymph node'; reference{i} = ''; i=i+1;
name{i} = 'fractionTregLy_LN';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of regulatory T cells from MLN lymphocytes'; reference{i} = '[Saruta2007]'; i=i+1;
name{i} = 'fractionNTregTreg_LN'; 	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of Helios+ from FOXP3+ T cells in MLN, assumed to be similar to blood'; reference{i} = '[Lord2015a]'; i=i+1;

% Steady state concentrations in blood
name{i} = 'fractionTnCD4_bl';     	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of naive CD4+ T cells from CD4+ T cells (blood)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTmCD4_bl';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of memory CD4+ T cells from CD4+ T cells (blood, age 30-50)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTemCD4_bl';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of effector memory CD4+ T cells from CD4+ T cells (blood)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTcmCD4_bl';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of central memory CD4+ T cells from CD4+ (blood)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionTregLy_bl';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of regulatory T cells from peripheral blood lymphocytes'; reference{i} = '[Saruta2007]'; i=i+1;
name{i} = 'ratioTB_bl';             BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio T:B (blood)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'ratioCD4CD8_bl';      	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'ratio CD4:CD8 (blood)'; reference{i} = '[Sathaliyawala2013]'; i=i+1;
name{i} = 'fractionNTregTreg_bl';	BactSpecific(i) = false;	unit{i} = '';         	description{i} = 'fraction of Helios+ from FOXP3+ T cells in blood'; reference{i} = '[Lord2015a]'; i=i+1;

% T cells
name{i} = 'mrtTn_LN';               BactSpecific(i) = false;	unit{i} = 'h';        	description{i} = 'mean residence time of naive CD4 T cell in mesenteric lymph node'; reference{i} = '[Mandl2012]'; i=i+1;
name{i} = 'lifespanT_LP';         	BactSpecific(i) = false;	unit{i} = 'd';      	description{i} = 'lifespan of effector memory T cells'; reference{i} = '[Westera2013]'; i=i+1;
name{i} = 'muTeff';                 BactSpecific(i) = false;	unit{i} = '1/d';      	description{i} = 'effector T cell death rate constant'; reference{i} = '[DeBoer2001]'; i=i+1;

% T cell proliferation
name{i} = 'nTm';                    BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of divisions of Tcm until differentiated to Tem/ of Tem until differentiated to Th'; reference{i} = '[MacLeod2008]'; i=i+1;
name{i} = 'nTn';                    BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal number of transit compartments for naive T cells'; reference{i} = '[Pham2008]'; i=i+1;
name{i} = 'muTprol';                BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'death rate constant of proliferating T cells'; reference{i} = '[Gett2000]'; i=i+1;
name{i} = 'suscApoLow';             BactSpecific(i) = false;	unit{i} = '';           description{i} = 'susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th)'; reference{i} = ''; i=i+1;
name{i} = 'TfirstDivision';         BactSpecific(i) = false;	unit{i} = 'h';      	description{i} = 'time to first division of activated naive T cells'; reference{i} = '[Hawkins2007/Gett2000]'; i=i+1;
name{i} = 'TsubseqDivision';       	BactSpecific(i) = false;	unit{i} = 'h';      	description{i} = 'time for subsequent divisions of activated naive T cells'; reference{i} = '[Hawkins2007/Gett2000]'; i=i+1;
name{i} = 'egressPerDivision';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'increase in egress rate per division (starting at threshold)'; reference{i} = '[Pham2008]'; i=i+1;
name{i} = 'egressThreshold';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'minimal division number for egress'; reference{i} = '[Pham2008]'; i=i+1;
name{i} = 'egressThresholdm';    	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'minimal division number for egress (memory T cells)'; reference{i} = ''; i=i+1;

% Effector T cells
name{i} = 'theta1host';             BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th1 cells elicited in this host'; reference{i} = ''; i=i+1;
name{i} = 'theta2host';             BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th2 cells elicited in this host'; reference{i} = ''; i=i+1;
name{i} = 'theta17host';           	BactSpecific(i) = false;   	unit{i} = '';           description{i} = 'fraction of Th17 cells elicited in this host'; reference{i} = ''; i=i+1;
name{i} = 'theta1bact';             BactSpecific(i) = true;     unit{i} = '';           description{i} = 'fraction of Th1 cells elicited by this bacterial species'; reference{i} = ''; i=i+1;
name{i} = 'theta2bact';             BactSpecific(i) = true;     unit{i} = '';           description{i} = 'fraction of Th2 cells elicited by this bacterial species'; reference{i} = ''; i=i+1;
name{i} = 'theta17bact';            BactSpecific(i) = true;     unit{i} = '';           description{i} = 'fraction of Th17 cells elicited by this bacterial species'; reference{i} = ''; i=i+1;

% Antigen specificities
name{i} = 'nTCRn';                  BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of TCR specificities of naive CD4 T cells'; reference{i} = '[Beltman2007,Zhang1995,Geiger2009]'; i=i+1;
name{i} = 'nBact';                  BactSpecific(i) = true;     unit{i} = '';           description{i} = 'number of different bacteria in this bacterial subgroup'; reference{i} = '[Janeway]'; i=i+1;
name{i} = 'nTCRm';                  BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of TCR specificities in memory T cells'; reference{i} = '[Arstila1999]'; i=i+1;
name{i} = 'beta';                   BactSpecific(i) = false;	unit{i} = '';           description{i} = 'number of antigens per bacterium/presented per dendritic cell'; reference{i} = ''; i=i+1;
name{i} = 'TmRecognition';       	BactSpecific(i) = true;     unit{i} = '';           description{i} = '(partial) recognition by memory T cells (due to conserved structures)'; reference{i} = ''; i=i+1;
name{i} = 'Tcontact';               BactSpecific(i) = false;    unit{i} = 'min';        description{i} = 'mean contact duration between DC and Tn/Tm'; reference{i} = '[Cai2017,Beltman2007,Mandl2012,Miller2004a]'; i=i+1;

% Dendritic cells
name{i} = 'hlDC';                   BactSpecific(i) = false;	unit{i} = 'd';        	description{i} = 'half-life of DC'; reference{i} = '[Merad2009,Lanzavecchia2001,Liu2007]'; i=i+1;
name{i} = 'hlDCantigen';            BactSpecific(i) = false;	unit{i} = 'd';         	description{i} = 'time (as half-life) from antigen-unexperienced to antigen-experienced DC'; reference{i} = ''; i=i+1;
name{i} = 'percentDCtoLN';       	BactSpecific(i) = false;	unit{i} = '%/d';       	description{i} = 'percent of LP DC that migrate to LN per day'; reference{i} = '[Vuk Cerovic, unpublished]'; i=i+1;
name{i} = 'percentFromLN';       	BactSpecific(i) = false;	unit{i} = '%/d';       	description{i} = 'percent of LN DC that leave the LN per day'; reference{i} = '[Vuk Verovic, unpublished]'; i=i+1;
name{i} = 'nuDCsMax';               BactSpecific(i) = false;	unit{i} = '1/h';       	description{i} = 'maximal dendritic cell activation'; reference{i} = ''; i=i+1;

% Contact rates
name{i} = 'kTDC_LN';                BactSpecific(i) = false;	unit{i} = 'mL/h';      	description{i} = 'contact rate constant between T cells and dendritic cells in lymph node'; reference{i} = '[Beltman2007,Miller2004a,Mandl2012]'; i=i+1;
name{i} = 'kTDC_LP';                BactSpecific(i) = false;	unit{i} = 'mL/h';     	description{i} = 'ontact rate constant between T cells and dendritic cells in lamina propria, set equal to lymph node'; reference{i} = ''; i=i+1;
name{i} = 'bsPerDC';              	BactSpecific(i) = false;	unit{i} = '';    		description{i} = 'T cell binding sites per DC'; reference{i} = '[Miller2004a]'; i=i+1;
name{i} = 'bsPerT';             	BactSpecific(i) = false;	unit{i} = '';    		description{i} = 'DC binding sites per T cell'; reference{i} = '[Miller2004a]'; i=i+1;
name{i} = 'bsPerM';              	BactSpecific(i) = false;	unit{i} = '';    		description{i} = 'T cell binding sites per macrophage'; reference{i} = ''; i=i+1;

% Macrophages
name{i} = 'muM';                    BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'death of macrophages'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'nuMP12ss';               BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'transition from macrophage compartment 1 to 2 in steady state'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'nuMP23ss';               BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'transition from macrophage compartment 2 to 3 in steady state'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'nuMP34ss';               BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'transition from macrophage compartment 3 to 4 in steady state'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'foldPhagoMP1';          	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P1 macrophages, relative to P4 macrophages'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'foldPhagoMP2';          	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P2 macrophages, relative to P4 macrophages'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'foldPhagoMP3';        	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P3 macrophages, relative to P4 macrophages'; reference{i} = '[Bain2013]'; i=i+1;
name{i} = 'phagoMP4';               BactSpecific(i) = false;	unit{i} = '';           description{i} = 'phagocytic activity of P1 macrophages, relative to dendritic cells (assumed to equal dendritic cells)'; reference{i} = ''; i=i+1;
name{i} = 'nuMphago';               BactSpecific(i) = false;	unit{i} = '';           description{i} = 'fraction of macrophages that move to next state after phagocytosis of one apoptotic neutrophil (<=1)'; reference{i} = ''; i=i+1;
name{i} = 'facNuM';                 BactSpecific(i) = false;	unit{i} = '';           description{i} = 'factor for nuM to ensure correct steady state fractions'; reference{i} = ''; i=i+1;
name{i} = 'facRecM';             	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'factor for cRecM to ensure correct steady state concentration'; reference{i} = ''; i=i+1;

% Bacteria
name{i} = 'pBact';                  BactSpecific(i) = true;     unit{i} = '1/h';       	description{i} = 'growth of bacteria in tissue'; reference{i} = '[Li2004]'; i=i+1;
name{i} = 'NmaxBact';               BactSpecific(i) = false;   	unit{i} = '1/mL';   	description{i} = 'maximal concentration of bacteria in LP'; reference{i} = ''; i=i+1;

% Neutrophils
name{i} = 'VmaxPhago';              BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'maximal phagocytosis rate per neutrophil'; reference{i} = '[Li2004]'; i=i+1;
name{i} = 'KmPhago';                BactSpecific(i) = false;	unit{i} = '1/mL';      	description{i} = 'bacteria concentration of half-maximal phagocytosis rate per neutrophil'; reference{i} = '[Li2004]'; i=i+1;
name{i} = 'phagoRec';            	BactSpecific(i) = true;     unit{i} = '';           description{i} = 'probability of recognition of bacteria by phagocytic cells'; reference{i} = ''; i=i+1;
name{i} = 'muNeutc';                BactSpecific(i) = false;	unit{i} = '1/h';      	description{i} = 'constitutive/spontaneous neutrophil apoptosis'; reference{i} = ''; i=i+1;
name{i} = 'muNeutPhago';         	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell'; reference{i} = ''; i=i+1;
name{i} = 'muNeutMax';              BactSpecific(i) = false;	unit{i} = '1/h';        description{i} = 'maximal neutrphil apoptosis, stimulated by SPM'; reference{i} = ''; i=i+1;
name{i} = 'muAponeut';              BactSpecific(i) = false;	unit{i} = '1/h';       	description{i} = 'necrosis of apoptotic neutrophils'; reference{i} = ''; i=i+1;

% S. typhimurium infection
name{i} = 'pSTmInt';                BactSpecific(i) = false;	unit{i} = '1/s';       	description{i} = 'intracellular growth rate of S.Tm'; reference{i} = '[Gog2012]'; i=i+1;
name{i} = 'Nburst';                 BactSpecific(i) = false;	unit{i} = '';       	description{i} = 'burst threshold: maximal number of bacteria per macrophage'; reference{i} = '[Brown2006]'; i=i+1;

% Recruitment, activation, inhibition
name{i} = 'lambdaMax';              BactSpecific(i) = false;	unit{i} = '1/(mL*h)';  	description{i} = 'maximal cell inflow rate into LP (assumed equal for macrophages, dendritic cells)'; reference{i} = ''; i=i+1;
name{i} = 'lambdaNeutMax';          BactSpecific(i) = false;	unit{i} = '1/(mL*h)';  	description{i} = 'maximal neutrophil inflow into LP'; reference{i} = ''; i=i+1;
name{i} = 'HillRec';             	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for recruitment'; reference{i} = ''; i=i+1;
name{i} = 'HillAct';             	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'Hill factor for activation/de-activation'; reference{i} = ''; i=i+1;

% Bacteria in lumen
name{i} = 'kBact';                  BactSpecific(i) = false;	unit{i} = '1/h';     	description{i} = 'nutrients inflow, bacterial proliferation and death rate constant in lumen'; reference{i} = ''; i=i+1;
name{i} = 'foldpBactLu';          	BactSpecific(i) = true;     unit{i} = '';           description{i} = 'relative proliferation to commensal bacteria'; reference{i} = ''; i=i+1;

% Mucus & epithelial barrier
name{i} = 'epsilonBact1';        	BactSpecific(i) = false;	unit{i} = '1/(mL*h)'; 	description{i} = 'inflow of bacteria without toxin'; reference{i} = ''; i=i+1;
name{i} = 'epsilonBact2';        	BactSpecific(i) = true;     unit{i} = '1/(mL*h)';  	description{i} = 'inflow of bacteria with toxin'; reference{i} = ''; i=i+1;
name{i} = 'hlEpi';                  BactSpecific(i) = false;	unit{i} = 'd';          description{i} = 'half-life of epithelium'; reference{i} = '[ICRP1975]'; i=i+1;
name{i} = 'ssEpi';                  BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of epithelium'; reference{i} = ''; i=i+1;
name{i} = 'muEpiBact';              BactSpecific(i) = false;	unit{i} = 'mL';     	description{i} = 'destruction of epithelium by bacteria with toxin'; reference{i} = ''; i=i+1;
name{i} = 'muEpiFac';            	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal relative increase of epithelium degradation'; reference{i} = ''; i=i+1;
name{i} = 'hlMucus';              	BactSpecific(i) = false;	unit{i} = 'h';          description{i} = 'half-life of mucus layer'; reference{i} = '[Faderl2015]'; i=i+1;
name{i} = 'ssMucus';                BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of mucus'; reference{i} = ''; i=i+1;
name{i} = 'hlTis';                  BactSpecific(i) = false;	unit{i} = 'd';          description{i} = 'half-life of tissue'; reference{i} = ''; i=i+1;
name{i} = 'ssTis';                  BactSpecific(i) = false;	unit{i} = '';           description{i} = 'steady state value of tissue'; reference{i} = ''; i=i+1;
name{i} = 'muTisFac';               BactSpecific(i) = false;	unit{i} = '';           description{i} = 'maximal relative increase of tissue degradation'; reference{i} = ''; i=i+1;
name{i} = 'epsilonFCP';             BactSpecific(i) = false;	unit{i} = 'mL*ug/(h*g)';description{i} = 'outflow of neutrophils (FCP) into lumen'; reference{i} = ''; i=i+1;
name{i} = 'ctt';                    BactSpecific(i) = false;	unit{i} = 'h';          description{i} = 'colorectal transit time'; reference{i} = '[Haase2016]'; i=i+1;

% Weights for phagocytosis
% --> relative to neutrophils (weight Neut = 1)
name{i} = 'wPhagoLPqDC';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPrDC';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPtDC';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPsDC';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPMP1';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPMP2';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPMP3';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPMP4';            BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wPhagoLPNeut';           BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for phagocytosis --> relative to neutrophils'; reference{i} = ''; i=i+1;

% Weights for cytokine production
% --> relative to Neut/iTreg
name{i} = 'wcyto_RecNeut_Th1';      BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecNeut_Th17';     BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecNeut_Neut';     BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecNeut_M';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecM_Th1';         BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecM_Th17';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecM_Neut';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_RecM_M';           BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActM_Th1';         BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActM_Th17';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActM_Neut';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActM_M';           BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActDC_Th1';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActDC_Th17';       BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActDC_Neut';       BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_ActDC_M';          BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactM_Treg';      BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactM_Th2';       BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactM_M';         BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactDC_Treg';     BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactDC_Th2';      BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DeactDC_M';        BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageEpi_Th1';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageEpi_Th17';  	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageEpi_Th2';  	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageEpi_Neut'; 	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageEpi_M';     	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageTis_Th1';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageTis_Th17';  	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageTis_Th2';  	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageTis_Neut'; 	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_DamageTis_M';     	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_TisRemod_Th2';   	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wcyto_TisRemod_M';     	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for cytokine production'; reference{i} = ''; i=i+1;
name{i} = 'wProLPBact';          	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight of stimulatory cytokine production --> relative to neutrophils (only for neutrophil recruitment)'; reference{i} = ''; i=i+1;     

% Weights of specialised pro-resolving mediator production
% --> relative to neutrophils (weight Neut = 1)
name{i} = 'wSPMLPNeut';          	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for SPM production --> relative to neutrophils'; reference{i} = ''; i=i+1;
name{i} = 'wSPMLPMeffero';       	BactSpecific(i) = false;	unit{i} = '';           description{i} = 'weight for SPM production --> relative to neutrophils'; reference{i} = ''; i=i+1;

primParTable = table(name',BactSpecific',unit',description',reference','VariableNames',{'name','BactSpecific','unit','description','reference'},'RowNames',name);

%--------------------------------------------------------------------------
% Auxiliary parameters
i = 1;
name            = {}; 	% parameter name
BactSpecific 	= [];   % true/false
unit            = {};   % unit
description     = {};   % description of parameter

name{i} = 'concCD4_LN';         BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of CD4+ T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concTn_LN';         	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of naive CD4+ T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concTcm_LN';      	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of central memory T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concTem_LN';      	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of effector memory T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concTreg_LN';       	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of regulatory T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concNTreg_LN';      	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of natural regulatory T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concITreg_LN';    	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of induced regulatory T cells in MLN T cell zone'; i=i+1;     
name{i} = 'concCD4_LP';        	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of CD4+ T cells in colon lamina propria'; i=i+1;     
name{i} = 'concTreg_LP';       	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of regulatory T cells in colon lamina propria'; i=i+1;     
name{i} = 'concNTreg_LP';     	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of natural regulatory T cells in colon lamina propria'; i=i+1;     
name{i} = 'concITreg_LP';     	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of induced regulatory T cells in colon lamina propria'; i=i+1;     
name{i} = 'concTem_LP';        	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of effector memory T cells in colon lamina propria'; i=i+1;     
name{i} = 'concDC_LP';         	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of dendritic cells in colon lamina propria'; i=i+1;     
name{i} = 'concM_LP';           BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of macrophages in colon lamina propria'; i=i+1;     
name{i} = 'concBact_LP';      	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of commensal bacteria in colon lamina propria'; i=i+1;     
name{i} = 'concNeut_LP';      	BactSpecific(i) = false;	unit{i} = '1/mL';           description{i} = 'concentration of neutrophils in colon lamina propria'; i=i+1;     
name{i} = 'fractionTregCD4_bl';	BactSpecific(i) = false;	unit{i} = '';               description{i} = 'fraction of regulatory T cells from CD4+ T cells in blood'; i=i+1;     
name{i} = 'fractionNTregCD4_bl';BactSpecific(i) = false;	unit{i} = '';               description{i} = 'fraction of natural regulatory T cells from CD4+ T cells in blood'; i=i+1;     

auxParTable = table(name',BactSpecific',unit',description','VariableNames',{'name','BactSpecific','unit','description'},'RowNames',name);


%--------------------------------------------------------------------------

end