function I = IBD_indexing(model)
%==========================================================================
% I = IBD_indexing(model)
%==========================================================================
% Indices for species and parameters
% For indexing of species, transit compartment numbers (model.transit) are 
% required. If not yet specified, only indices for parameters are returned.
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% I:            index struct
%==========================================================================

BactNames = model.BactNames;

% Indices for bacteria
I.nrOfBact	= length(BactNames);
I.allBact  	= 1:I.nrOfBact;

for i = 1:I.nrOfBact
    I.bactName{i}        	= BactNames{i};
    I.(BactNames{i})        = i;
end
if ~ismember('STm',BactNames)
    I.STm = [];
end

%--------------------------------------------------------------------------
% Indices for states
if isfield(model,'transit')     % nr of transit compartments required
    fprintf('Generating indices for states...\n')
    i = 1;
    for state = model.stateNames
        State = char(state);
        I.(State) = [];
        for j = 1:max(1,I.nrOfBact*model.stateTable{State,'BactSpecific'})
            if ismember(State,fieldnames(model.transit.nr))
                I.stateName(i:i+model.transit.nr.(State)-1) = {State};
                I.stateBact(i:i+model.transit.nr.(State)-1)	= j;
                I.(State) = [I.(State); i:i+model.transit.nr.(State)-1];
                i = i+model.transit.nr.(State);
            else
                I.stateName{i} 	= State;
                I.stateBact(i)	= j;
                I.(State)     	= [I.(State); i];
                i = i+1;
            end
        end
    end
    I.nrOfStates 	= i-1;
    I.allStates   	= 1:I.nrOfStates;
    
    % Additional states (calculated after simulation)
    for state = model.addStateNames
        State = char(state);
        I.(State) = [];
        for j = 1:max(1,I.nrOfBact*model.stateTable{State,'BactSpecific'})
            if ismember(State,fieldnames(model.transit.nr))
                I.stateName(i:i+model.transit.nr.(State)-1) = {State};
                I.stateBact(i:i+model.transit.nr.(State)-1)	= j;
                I.(State) = [I.(State); i:i+model.transit.nr.(State)-1];
                i = i+model.transit.nr.(State);
            else
                I.stateName{i} 	= State;
                I.stateBact(i)	= j;
                I.(State)     	= [I.(State); i];
                i = i+1;
            end
        end
    end
    
    I.nrOfStatesAdd     = i-1;
    I.allStatesAdd      = 1:I.nrOfStatesAdd;
end

%--------------------------------------------------------------------------
% Indices for parameters
fprintf('Generating indices for parameters...\n')

i = 1;
for p = model.parNames
	P = char(p);
	I.(P) = [];
    for j = 1:max(1,I.nrOfBact*model.parTable{P,'BactSpecific'})
        I.parName{i} 	= P;
        I.parBact(i)    = j;
     	I.(P)           = [I.(P); i];
     	i = i+1;
    end
end
I.nrOfPar 	= i-1;
I.allPar   	= 1:I.nrOfPar;

% Indices for primary parameters
i = 1;
for p = model.primParNames
	P = char(p);
	I.prim.(P) = [];
    for j = 1:max(1,I.nrOfBact*model.primParTable{P,'BactSpecific'})
        I.prim.parName{i} 	= P;
     	I.prim.(P)        	= [I.prim.(P); i];
     	i = i+1;
    end
end
I.prim.nrOfPar  = i-1;
I.prim.allPar   = 1:I.prim.nrOfPar;

% Indices for auxiliary parameters
i = 1;
for p = model.auxParNames
	P = char(p);
	I.aux.(P) = [];
    for j = 1:max(1,I.nrOfBact*model.auxParTable{P,'BactSpecific'})
        I.aux.parName{i} 	= P;
     	I.aux.(P)        	= [I.aux.(P); i];
     	i = i+1;
    end
end
I.aux.nrOfPar   = i-1;
I.aux.allPar    = 1:I.aux.nrOfPar;

%--------------------------------------------------------------------------

end

