function dX = IBD_ode(~,X,par,model)
%==========================================================================
% dX = IBD_ode(t,X,par,model)
%==========================================================================
% ODEs
%--------------------------------------------------------------------------
%-- input
% t:            time point
% X:            current values of state variables
% par:          parameters
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% dX:           dX/dt
%==========================================================================

I 	= model.I;

%--------------------------------------------------------------------------
%% SPECIES
% LP = lamina propria; LN = mesenteric lymph node
% [1/mL]
qDC_LP          = X(I.qDC_LP);          % quiescent dendritic cells
tDC_LP          = X(I.tDC_LP);          % tolerogenic dendritic cells
rDC_LP          = X(I.rDC_LP);          % responsive dendritic cells
sDC_LP          = X(I.sDC_LP);          % stimulatory dendritic cells
tDCi_LP         = X(I.tDCi_LP);         % tolerogenic dendritic cells (inhibited antigen presentation)
sDCi_LP         = X(I.sDCi_LP);         % stimulatory dendritic cells (inhibited antigen presentation)
tDC_LN  		= X(I.tDC_LN);          % tolerogenic dendritic cells
sDC_LN          = X(I.sDC_LN);          % stimulatory dendritic cells
tDCi_LN         = X(I.tDCi_LN);         % tolerogenic dendritic cells (inhibited antigen presentation)
sDCi_LN         = X(I.sDCi_LN);         % stimulatory dendritic cells (inhibited antigen presentation)
Tn_LN           = X(I.Tn_LN);           % naive CD4+ T cells
Tcm_LN          = X(I.Tcm_LN);          % central memory T cells
Tn2Treg_LN 		= reshape(X(I.Tn2Treg_LN),size(I.Tn2Treg_LN));     	% naive T cells stimulated by tolerogenic dendritic cells, proliferating and differentiating to Treg
Tn2Th1_LN     	= reshape(X(I.Tn2Th1_LN),size(I.Tn2Th1_LN));     	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th1
Tn2Th2_LN     	= reshape(X(I.Tn2Th2_LN),size(I.Tn2Th2_LN));      	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th2
Tn2Th17_LN     	= reshape(X(I.Tn2Th17_LN),size(I.Tn2Th17_LN));   	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th17
Tcm2Temreg_LN   = reshape(X(I.Tcm2Temreg_LN),size(I.Tcm2Temreg_LN));% central memory T cells stimulated by tolerogenic dendritic cells, proliferating and differentiating (regulatory type)
Tcm2Tem1_LN     = reshape(X(I.Tcm2Tem1_LN),size(I.Tcm2Tem1_LN));	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 1)
Tcm2Tem2_LN     = reshape(X(I.Tcm2Tem2_LN),size(I.Tcm2Tem2_LN));   	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 2)
Tcm2Tem17_LN    = reshape(X(I.Tcm2Tem17_LN),size(I.Tcm2Tem17_LN)); 	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 17)
Tem2Treg_LP     = reshape(X(I.Tem2Treg_LP),size(I.Tem2Treg_LP));  	% effector memory T cells, proliferating and differentiating to Treg
Tem2Th1_LP      = reshape(X(I.Tem2Th1_LP),size(I.Tem2Th1_LP));      % effector memory T cells, proliferating and differentiating to Th1
Tem2Th2_LP      = reshape(X(I.Tem2Th2_LP),size(I.Tem2Th2_LP));      % effector memory T cells, proliferating and differentiating to Th2
Tem2Th17_LP   	= reshape(X(I.Tem2Th17_LP),size(I.Tem2Th17_LP)); 	% effector memory T cells, proliferating and differentiating to Th17
Temreg_LP       = X(I.Temreg_LP);       % effector memory T cells (regulatory type)
Tem1_LP       	= X(I.Tem1_LP);         % effector memory T cells (type 1)
Tem2_LP       	= X(I.Tem2_LP);         % effector memory T cells (type 2)
Tem17_LP       	= X(I.Tem17_LP);    	% effector memory T cells (type 17)
iTreg_LP 		= X(I.iTreg_LP);        % induced regulatory T cells
Th1_LP       	= X(I.Th1_LP);       	% type 1 T helper cells
Th2_LP       	= X(I.Th2_LP);       	% type 2 T helper cells
Th17_LP       	= X(I.Th17_LP);       	% type 17 T helper cells
MP1_LP        	= X(I.MP1_LP);         	% macrophages (P1)
MP1a_LP         = X(I.MP1a_LP);        	% antigen-experienced macrophages (P1)
MP1ai_LP        = X(I.MP1ai_LP);        % antigen-experienced macrophages (P1) (inhibited antigen presentation)
MP2_LP        	= X(I.MP2_LP);         	% macrophages (P2)
MP2a_LP       	= X(I.MP2a_LP);        	% antigen-experienced macrophages (P2)
MP2ai_LP        = X(I.MP2ai_LP);        % antigen-experienced macrophages (P2) (inhibited antigen presentation)
MP3_LP         	= X(I.MP3_LP);       	% macrophages (P3)
MP3a_LP       	= X(I.MP3a_LP);       	% antigen-experienced macrophages (P3)
MP3ai_LP        = X(I.MP3ai_LP);        % antigen-experienced macrophages (P3) (inhibited antigen presentation)
MP4_LP         	= X(I.MP4_LP);        	% macrophages (P4)
MP4a_LP        	= X(I.MP4a_LP);      	% antigen-experienced macrophages (P4)
MP4ai_LP        = X(I.MP4ai_LP);        % antigen-experienced macrophages (P4) (inhibited antigen presentation)
Meffero_LP      = X(I.Meffero_LP);      % efferocytosis-type macrophages
Mefferoa_LP     = X(I.Mefferoa_LP);     % antigen-experienced efferocytosis-type macrophages
Mefferoai_LP   	= X(I.Mefferoai_LP);  	% antigen-experienced efferocytosis-type (P1) (inhibited antigen presentation)
MP1inf_LP    	= X(I.MP1inf_LP);       % infected macrophages (P1)
MP2inf_LP     	= X(I.MP2inf_LP);      	% infected macrophages (P2)
MP3inf_LP     	= X(I.MP3inf_LP);     	% infected macrophages (P3)
MP4inf_LP     	= X(I.MP4inf_LP);      	% infected macrophages (P4)
Mefferoinf_LP	= X(I.Mefferoinf_LP); 	% infected efferocytosis-type macrophages
Bact_LP         = X(I.Bact_LP);         % extracellular bacteria
Neut_LP         = X(I.Neut_LP);         % neutrophil granulocytes
apoNeut_LP      = X(I.apoNeut_LP);      % apoptotitc neutrophil granulocytes
Bact_Lu         = X(I.Bact_Lu);         % bacteria
nutrients       = X(I.nutrients);       % nutrients for bacteria
epi           	= X(I.epi);             % epithelial barrier
mucus           = X(I.mucus);           % mucus layer
tissue          = X(I.tissue);          % tissue/ECM
FCP             = X(I.FCP);             % fecal calprotectin

%--------------------------------------------------------------------------
%% PARAMETERS
par = par';
VLP                 = par(I.VLP);                   % [mL] volume of total lamina propria (small + large intestine)
VLP_VLN             = par(I.VLP)/par(I.VLN);       	% [] volume correction coefficient V_LP/V_LN
VLN_VLP             = par(I.VLN)/par(I.VLP);      	% [] volume correction coefficient V_LN/V_LP
muT_LN              = par(I.muT_LN);                % [1/h] outflow of T cells from MLN
muT_LP              = par(I.muT_LP);                % [1/h] death of effector memory T cells
lambdaT_LN          = par(I.lambdaT_LN);            % [1/(mL*h)] rate constant (inflow rate constant * volume correction coefficient * concentration of CD4+ T cells in blood) for inflow of T cells into MLN
muTeff              = par(I.muTeff);                % [1/h] effector T cell death rate constant
fractionTnCD4_bl    = par(I.fractionTnCD4_bl);      % [] fraction of naive CD4+ T cells from CD4+ T cells (blood)
fractionTcmCD4_bl   = par(I.fractionTcmCD4_bl);     % [] fraction of central memory CD4+ T cells from CD4+ (blood)
nTn                 = par(I.nTn);                   % [] maximal number of transit compartments for naive T cells
nTm                 = par(I.nTm);                   % [] number of transit compartments for differentiation/proliferation of memory T cells
muTprol             = par(I.muTprol);             	% [1/h] death rate constant of proliferating T cells
suscApoLow          = par(I.suscApoLow);            % [] susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th)
pTn1                = par(I.pTn1);                  % [1/h] proliferation rate constant of activated naive T cells (first division)
pTni                = par(I.pTni);                  % [1/h] proliferation rate constant of activated naive T cells (subsequent divisions)
egressPerDivision   = par(I.egressPerDivision); 	% [] increase in egress rate per division (starting at division 4)
egressThreshold     = par(I.egressThreshold);       % [] minimal division number for egress
egressThresholdm    = par(I.egressThresholdm);      % [] minimal division number for egress (memory T cells)
fractionTh1         = par(I.theta1host)*par(I.theta1bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));  % [] fraction of Th1 cells elicited by this bacterial species
fractionTh2         = par(I.theta2host)*par(I.theta2bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));  % [] fraction of Th2 cells elicited by this bacterial species
fractionTh17        = par(I.theta17host)*par(I.theta17bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));% [] fraction of Th17 cells elicited by this bacterial species
alphaTn             = par(I.alphaTn);               % [] frequency of antigen specificity in naive T cells
alphaTh             = par(I.alphaTh);             	% [] frequency of antigen specificity in effector T cells
alphaTm             = par(I.alphaTm);               % [] frequency of antigen specificity in memory T cells
beta                = par(I.beta);                	% [] number of antigens per bacterium/presented per dendritic cell
Tcontact            = par(I.Tcontact);           	% [h] mean contact duration between DC and Tn/Tm
muDC                = par(I.muDC);                  % [1/h] death rate constant of dendritic cells
muDC_LN             = par(I.muDC_LN);               % [1/h] migration rate of dendritic cells out of LN
nuDCa               = par(I.nuDCa);                 % [1/h] conversion rate constant from antigen-unexperienced to antigen-experienced dendritic cells (LP)
epsilonDC           = par(I.epsilonDC);             % [1/h] migration of dendritic cells from LP to MLN
cRecDC              = par(I.cRecDC);                % [1/(mL*h)] constant inflow of quiescent dendritic cells into LP
nuDCsMax            = par(I.nuDCsMax);              % [1/h] maximal dendritic cell activation
HillProActDC      	= par(I.HillProActDC);        	% [] Hill factor for dendritic cell activation stimulation by pro-inflammatory cytokines
HillAntiActDC    	= par(I.HillAntiActDC);     	% [] Hill factor for dendritic cell activation inhibition by anti-inflammatory cytokines
kTDC_LN             = par(I.kTDC_LN);               % [mL/h] contact rate constant for T and DC in LN
kTDC_LP             = par(I.kTDC_LP);               % [mL/h] contact rate constant for T and DC in LP
bsPerDC           	= par(I.bsPerDC);               % [] T cell binding sites per DC
bsPerT           	= par(I.bsPerT);            	% [] DC binding sites per T cell
bsPerM           	= par(I.bsPerM);            	% [] T cell binding sites per macrophage
muM                 = par(I.muM);                   % [1/h] death of macrophages
nuMP12ss            = par(I.nuMP12ss);              % [1/h] transition from macrophage compartment 1 to 2 in steady state
nuMP23ss            = par(I.nuMP23ss);              % [1/h] transition from macrophage compartment 2 to 3 in steady state
nuMP34ss            = par(I.nuMP34ss);              % [1/h] transition from macrophage compartment 3 to 4 in steady state
phagoMP1            = par(I.phagoMP1);              % [] phagocytic activity of P1 macrophages, relative to dendritic cells
phagoMP2            = par(I.phagoMP2);              % [] phagocytic activity of P2 macrophages, relative to dendritic cells
phagoMP3            = par(I.phagoMP3);              % [] phagocytic activity of P3 macrophages, relative to dendritic cells
phagoMP4            = par(I.phagoMP4);              % [] phagocytic activity of P4 macrophages, relative to dendritic cells
lambdaMmax          = par(I.lambdaMmax);            % [1/(mL*h)] maximal macrophage inflow into LP
HillRecM            = par(I.HillRecM);              % [] Hill factor for macrophage recruitment by stimulated cells
cRecM               = par(I.cRecM);                 % [1/(mL*h)] constant macrophage inflow into LP
nuMphago            = par(I.nuMphago);              % [] fraction of macrophages that move to next state after phagocytosis of one apoptotic neutrophil
HillProActM      	= par(I.HillProActM);        	% [] Hill factor for macrophage transition inhibition by pro-inflammatory cytokines
HillAntiActM      	= par(I.HillAntiActM);      	% [] Hill factor for macrophage transition stimulation by anti-inflammatory cytokines
pBact               = par(I.pBact);                 % [1/h] growth of bacteria in tissue
NmaxBact            = par(I.NmaxBact);              % [1/mL] maximal concentration of bacteria in LP
VmaxPhago           = par(I.VmaxPhago);             % [1/h] maximal phagocytosis rate of bacteria per neutrophil (/phagocytic cell)
KmPhago             = par(I.KmPhago);               % [1/mL] bacteria concentration for half-maximal phagocytosis rate per neutrophil (/phagocytic cell)
phagoRec            = par(I.phagoRec);              % [] probability of recognition of bacteria by phagocytic cells
pSTmInt             = par(I.pSTmInt);               % [1/h] intracellular growth rate of S.Tm [Gog2012]
Nburst              = par(I.Nburst);                % [] burst threshold: maximal number of bacteria per macrophage [Brown2006]
lambdaNeutMax       = par(I.lambdaNeutMax);         % [1/(mL*h)] maximal neutrophil inflow into LP
HillRecNeut         = par(I.HillRecNeut);           % [] Hill factor for neutrophil recruitment
muNeutc             = par(I.muNeutc);               % [1/h] constitutive/spontaneous neutrophil apoptosis
muNeutPhago     	= par(I.muNeutPhago);       	% [] proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell
muNeutMax           = par(I.muNeutMax);             % [1/h] maximal neutrophil apoptosis, stimulated by SPM
muAponeut           = par(I.muAponeut);             % [1/h] necrosis of apoptotic neutrophils
pBactLu             = par(I.pBactLu);               % [1/h] proliferation of bacteria in lumen
muBactLu            = par(I.muBactLu);              % [1/h] death of bacteria in lumen
lambdaNutrients     = par(I.lambdaNutrients);       % [1/h] inflow of nutrients
epsilonBact1        = par(I.epsilonBact1);       	% [1/(mL*h)] inflow of bacteria without toxin
epsilonBact2        = par(I.epsilonBact2);          % [1/(mL*h)] inflow of bacteria with toxin
muEpi               = par(I.muEpi);                 % [1/h] degradation of epithelium
ssEpi           	= par(I.ssEpi);                 % [] steady state value of epithelium
muEpiBact           = par(I.muEpiBact);           	% [mL] destruction of epithelium by bacteria with toxin
muEpiFac            = par(I.muEpiFac);              % [] maximal relative increase of epithelium degradation
muMucus             = par(I.muMucus);            	% [1/h] degradation of mucus layer
ssMucus             = par(I.ssMucus);        		% [] steady state value of mucus
muTis               = par(I.muTis);                 % [1/h] degradation of tissue
ssTis           	= par(I.ssTis);                 % [] steady state value of tissue
muTisFac            = par(I.muTisFac);              % [] maximal relative increase of tissue degradation
epsilonFCP          = par(I.epsilonFCP);            % [mL*ug/(h*g)] outflow of neutrophils (FCP) into lumen
muFCP               = par(I.muFCP);                 % [1/h] outflow of FCP from lumen

% Weights:
wPhagoLPqDC         = par(I.wPhagoLPqDC);
wPhagoLPrDC         = par(I.wPhagoLPrDC);
wPhagoLPtDC         = par(I.wPhagoLPtDC);
wPhagoLPsDC         = par(I.wPhagoLPsDC);
wPhagoLPMP1         = par(I.wPhagoLPMP1);
wPhagoLPMP2         = par(I.wPhagoLPMP2);
wPhagoLPMP3         = par(I.wPhagoLPMP3);
wPhagoLPMP4         = par(I.wPhagoLPMP4);
wPhagoLPNeut        = par(I.wPhagoLPNeut);
wcyto_RecNeut_Th1   = par(I.wcyto_RecNeut_Th1);
wcyto_RecNeut_Th17  = par(I.wcyto_RecNeut_Th17);
wcyto_RecNeut_Neut  = par(I.wcyto_RecNeut_Neut);
wcyto_RecNeut_M     = par(I.wcyto_RecNeut_M);
wcyto_RecM_Th1      = par(I.wcyto_RecM_Th1);
wcyto_RecM_Th17     = par(I.wcyto_RecM_Th17);
wcyto_RecM_Neut     = par(I.wcyto_RecM_Neut);
wcyto_RecM_M        = par(I.wcyto_RecM_M);
wcyto_ActM_Th1      = par(I.wcyto_ActM_Th1);
wcyto_ActM_Th17     = par(I.wcyto_ActM_Th17);
wcyto_ActM_Neut     = par(I.wcyto_ActM_Neut);
wcyto_ActM_M        = par(I.wcyto_ActM_M);
wcyto_ActDC_Th1     = par(I.wcyto_ActDC_Th1);
wcyto_ActDC_Th17    = par(I.wcyto_ActDC_Th17);
wcyto_ActDC_Neut    = par(I.wcyto_ActDC_Neut);
wcyto_ActDC_M       = par(I.wcyto_ActDC_M);
wcyto_DeactM_Treg   = par(I.wcyto_DeactM_Treg);
wcyto_DeactM_Th2    = par(I.wcyto_DeactM_Th2);
wcyto_DeactM_M      = par(I.wcyto_DeactM_M);
wcyto_DeactDC_Treg  = par(I.wcyto_DeactDC_Treg);
wcyto_DeactDC_Th2   = par(I.wcyto_DeactDC_Th2);
wcyto_DeactDC_M     = par(I.wcyto_DeactDC_M);
wcyto_DamageEpi_Th1	= par(I.wcyto_DamageEpi_Th1);
wcyto_DamageEpi_Th17= par(I.wcyto_DamageEpi_Th17);
wcyto_DamageEpi_Th2 = par(I.wcyto_DamageEpi_Th2);
wcyto_DamageEpi_Neut= par(I.wcyto_DamageEpi_Neut);
wcyto_DamageEpi_M  	= par(I.wcyto_DamageEpi_M);
wcyto_DamageTis_Th1	= par(I.wcyto_DamageTis_Th1);
wcyto_DamageTis_Th17= par(I.wcyto_DamageTis_Th17);
wcyto_DamageTis_Th2 = par(I.wcyto_DamageTis_Th2);
wcyto_DamageTis_Neut= par(I.wcyto_DamageTis_Neut);
wcyto_DamageTis_M  	= par(I.wcyto_DamageTis_M);
wcyto_TisRemod_Th2  = par(I.wcyto_TisRemod_Th2);
wcyto_TisRemod_M  	= par(I.wcyto_TisRemod_M);
wProLPBact         	= par(I.wProLPBact);
wSPMLPNeut          = par(I.wSPMLPNeut);
wSPMLPMeffero       = par(I.wSPMLPMeffero);

%--------------------------------------------------------------------------
%% Calculations of combined species and rates for multiple use

% Effector T cells
iTreg_eff_LN	= sum(Tn2Treg_LN(:,2:end),2);
iTreg_eff_LP    = sum(Tem2Treg_LP(:,2:end),2)+iTreg_LP+Temreg_LP;
Th1_eff_LP     	= sum(Tem2Th1_LP(:,2:end),2)+Th1_LP+Tem1_LP;
Th2_eff_LP     	= sum(Tem2Th2_LP(:,2:end),2)+Th2_LP+Tem2_LP;
Th17_eff_LP   	= sum(Tem2Th17_LP(:,2:end),2)+Th17_LP+Tem17_LP;

% T cell - dendritic cell contacts
% LN:
Ttot_LN     = Tn_LN + Tcm_LN...
    + sum(sum(Tn2Th1_LN(:,2:end)))   + sum(sum(Tn2Th2_LN(:,2:end)))   + sum(sum(Tn2Th17_LN(:,2:end)))   + sum(sum(Tn2Treg_LN(:,2:end)))...
    + sum(sum(Tcm2Tem1_LN(:,2:end))) + sum(sum(Tcm2Tem2_LN(:,2:end))) + sum(sum(Tcm2Tem17_LN(:,2:end))) + sum(sum(Tcm2Temreg_LN(:,2:end)));
BST_LN              = Ttot_LN*bsPerT;                                            	% T cell binding sites
BSantiAPC_LN        = tDC_LN*bsPerDC - (Tn2Treg_LN(:,1) + Tcm2Temreg_LN(:,1));    	% tDC binding sites (Bact-specific)
BSproAPC_LN         = sDC_LN*bsPerDC - (Tn2Th1_LN(:,1) + Tn2Th2_LN(:,1) + Tn2Th17_LN(:,1) + Tcm2Tem1_LN(:,1) + Tcm2Tem2_LN(:,1) + Tcm2Tem17_LN(:,1)); % sDC binding sites (Bact-specific)
BSneutralAPC_LN     = (tDCi_LN + sDCi_LN)*bsPerDC;
BSAPC_LN            = sum(BSantiAPC_LN) + sum(BSproAPC_LN) + BSneutralAPC_LN;   	% DC binding sites (total, all Bact)
contacts_LN         = (BST_LN+BSAPC_LN+(bsPerT*bsPerDC/(Tcontact*kTDC_LN))-sqrt((BST_LN+BSAPC_LN+(bsPerT*bsPerDC/(Tcontact*kTDC_LN)))^2-4*BST_LN*BSAPC_LN))/2;
if Ttot_LN == 0
    Ttot_LN = 1;    % to avoid division by zero
end
if BSAPC_LN == 0
    BSAPC_LN = 1;   % to avoid division by zero
end

% LP:
Ttot_LP             = sum(iTreg_eff_LP) + sum(Th1_eff_LP) + sum(Th2_eff_LP) + sum(Th17_eff_LP);
BST_LP              = Ttot_LP*bsPerT;                                           	% T cell binding sites
BSantiAPC_LP_cells  = tDC_LP+bsPerM/bsPerDC*(MP4a_LP+Mefferoa_LP);
BSantiAPC_LP_cells(I.STm) = BSantiAPC_LP_cells(I.STm) + bsPerM/bsPerDC*(MP4inf_LP + Mefferoinf_LP);
BSantiAPC_LP        = BSantiAPC_LP_cells*bsPerDC - (Tem2Treg_LP(:,1));              % tDC + Manti binding sites (Bact-specific)
BSproAPC_LP_cells   = sDC_LP+bsPerM/bsPerDC*(MP1a_LP+MP2a_LP+MP3a_LP);
BSproAPC_LP_cells(I.STm) = BSproAPC_LP_cells(I.STm) + bsPerM/bsPerDC*(MP1inf_LP + MP2inf_LP + MP3inf_LP);
BSproAPC_LP         = BSproAPC_LP_cells*bsPerDC - (Tem2Th1_LP(:,1) + Tem2Th2_LP(:,1) + Tem2Th17_LP(:,1));	% sDC + Mpro binding sites (Bact-specific)
BSneutralAPC_LP     = (tDCi_LP + sDCi_LP + bsPerM/bsPerDC*(MP1ai_LP + MP2ai_LP + MP3ai_LP + MP4ai_LP + Mefferoai_LP))*bsPerDC;
BSAPC_LP            = sum(BSantiAPC_LP) + sum(BSproAPC_LP) + BSneutralAPC_LP;       % APC binding sites (total, all Bact)
contacts_LP         = (BST_LP+BSAPC_LP+(bsPerT*bsPerDC/(Tcontact*kTDC_LP))-sqrt((BST_LP+BSAPC_LP+(bsPerT*bsPerDC/(Tcontact*kTDC_LP)))^2-4*BST_LP*BSAPC_LP))/2;
if Ttot_LP == 0
    Ttot_LP = 1;    % to avoid division by zero
end
if BSAPC_LP == 0
    BSAPC_LP = 1;   % to avoid division by zero
end
for k = 1:length(BSantiAPC_LP_cells)
    if BSantiAPC_LP_cells(k) == 0
        BSantiAPC_LP_cells(k) = 1;  % to avoid division by zero
    end
end
for k = 1:length(BSproAPC_LP_cells)
    if BSproAPC_LP_cells(k) == 0
        BSproAPC_LP_cells(k) = 1;   % to avoid division by zero
    end
end

% Cytokine-producing cells
cyto_Th1        = sum((Th1_eff_LP/Ttot_LP) .*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
cyto_Th2        = sum((Th2_eff_LP/Ttot_LP) .*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
cyto_Th17      	= sum((Th17_eff_LP/Ttot_LP).*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
Mpro            = sum(MP1a_LP)+sum(MP2a_LP)+sum(MP3a_LP)+sum(MP1ai_LP)+sum(MP2ai_LP)+sum(MP3ai_LP)+sum(MP1inf_LP)+sum(MP2inf_LP)+sum(MP3inf_LP);
Manti           = sum(MP4a_LP)+sum(Mefferoa_LP)+sum(MP4ai_LP)+sum(Mefferoai_LP)+sum(MP4inf_LP)+sum(Mefferoinf_LP);
cyto_RecNeut    = wcyto_RecNeut_Th1*cyto_Th1    + wcyto_RecNeut_Th17*cyto_Th17  + wcyto_RecNeut_Neut*Neut_LP    + wcyto_RecNeut_M*Mpro;
cyto_RecM       = wcyto_RecM_Th1*cyto_Th1       + wcyto_RecM_Th17*cyto_Th17     + wcyto_RecM_Neut*Neut_LP       + wcyto_RecM_M*Mpro;
cyto_ActM       = wcyto_ActM_Th1*cyto_Th1       + wcyto_ActM_Th17*cyto_Th17     + wcyto_ActM_Neut*Neut_LP       + wcyto_ActM_M*Mpro;
cyto_ActDC      = wcyto_ActDC_Th1*cyto_Th1      + wcyto_ActDC_Th17*cyto_Th17 	+ wcyto_ActDC_Neut*Neut_LP     	+ wcyto_ActDC_M*Mpro;
cyto_DeactM     = wcyto_DeactM_Treg*sum(iTreg_LP)   + wcyto_DeactM_Th2*cyto_Th2     + wcyto_DeactM_M*Manti;
cyto_DeactDC    = wcyto_DeactDC_Treg*sum(iTreg_LP)  + wcyto_DeactDC_Th2*cyto_Th2    + wcyto_DeactDC_M*Manti;
cyto_DamageEpi  = wcyto_DamageEpi_Th1*cyto_Th1      + wcyto_DamageEpi_Th17*cyto_Th17 + wcyto_DamageEpi_Th2*cyto_Th2 + wcyto_DamageEpi_Neut*Neut_LP + wcyto_DamageEpi_M*Mpro;
cyto_DamageTis  = wcyto_DamageTis_Th1*cyto_Th1      + wcyto_DamageTis_Th17*cyto_Th17 + wcyto_DamageTis_Th2*cyto_Th2 + wcyto_DamageTis_Neut*Neut_LP + wcyto_DamageTis_M*Mpro;
cyto_TisRemod   = wcyto_TisRemod_Th2*cyto_Th2       + wcyto_TisRemod_M*Manti;

% Specialised pro-resolving mediators (SPM)-producing cells
SPM_LP    	= apoNeut_LP*wSPMLPNeut + (Meffero_LP + sum(Mefferoa_LP) + Mefferoai_LP + Mefferoinf_LP)*wSPMLPMeffero;

% Phagocytosing cells
MPhago_LP 	=   (sum(MP1_LP) + sum(MP1a_LP) + sum(MP1ai_LP) + sum(MP1inf_LP))*wPhagoLPMP1...
              + (sum(MP2_LP) + sum(MP2a_LP) + sum(MP2ai_LP) + sum(MP2inf_LP))*wPhagoLPMP2...
              + (sum(MP3_LP) + sum(MP3a_LP) + sum(MP3ai_LP) + sum(MP3inf_LP))*wPhagoLPMP3...
              + (sum(MP4_LP) + sum(MP4a_LP) + sum(MP4ai_LP) + sum(MP4inf_LP))*wPhagoLPMP4...
              + (sum(Meffero_LP) + sum(Mefferoa_LP) + sum(Mefferoai_LP) + sum(Mefferoinf_LP))*wPhagoLPMP4; % phagocytosing macrophages in LP
Phago_LP    = MPhago_LP...
              + sum(qDC_LP)*wPhagoLPqDC + sum(rDC_LP)*wPhagoLPrDC...
              + sum(tDC_LP)*wPhagoLPtDC + sum(sDC_LP)*wPhagoLPsDC...
              + sum(Neut_LP)*wPhagoLPNeut;                                  % phagocytosing cells in LP

% Phagocytosis of bacteria
phagoElim  	= (VmaxPhago*Bact_LP)./(KmPhago./phagoRec+sum(Bact_LP));        % elimination of bacteria per phagocytic cell
phagoUptake = (VmaxPhago*Bact_LP)./(KmPhago./phagoRec+sum(Bact_LP));      	% antigen uptake per antigen-unexperienced cell

% No infection if absolute number of bacteria or infected cell type < 1
if Bact_LP(I.STm) < 1/VLP
    phagoUptake(I.STm) = 0;
end
if all([MP1inf_LP,MP2inf_LP,MP3inf_LP,MP4inf_LP,Mefferoinf_LP] < 1/VLP)
    pSTmInt = 0;
end

% Activation/deactivation of dendritic cells and macrophages
ActDC       = nuDCsMax*cyto_ActDC^HillProActDC/((1+cyto_DeactDC^HillAntiActDC)+cyto_ActDC^HillProActDC);   	% activation rate per DC (qDC/tDC)
nuMP12      = nuMP12ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP1 macrophage
nuMP23      = nuMP23ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP2 macrophage
nuMP34      = nuMP34ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP3 macrophage

% Efferocytosis
nuMP1eff    = nuMphago*VmaxPhago*wPhagoLPMP1*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP2eff    = nuMphago*VmaxPhago*wPhagoLPMP2*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP3eff    = nuMphago*VmaxPhago*wPhagoLPMP3*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP4eff    = nuMphago*VmaxPhago*wPhagoLPMP4*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis

% Bacterial inflow from lumen to lamina propria
inflow      = epsilonBact1.*(1-mucus).*(1-epi) + epsilonBact2.*(1-mucus).*epi;

% Proliferating T cells
Tn2Treg_inflow          	= [(Tn_LN/Ttot_LN)*(BSantiAPC_LN/BSAPC_LN)*(alphaTn*beta/Tcontact)*contacts_LN, zeros(size(Tn2Treg_LN,1),size(Tn2Treg_LN,2)-1)];
Tn2Treg_egress             	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Treg_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Treg_LN,1),1]).*Tn2Treg_LN;
Tn2Treg_prol                = repmat([pTn1,repmat(pTni,[1,size(Tn2Treg_LN,2)-2]),0],[size(Tn2Treg_LN,1),1]).*Tn2Treg_LN;
Tn2Treg_death               = muTprol*suscApoLow*Tn2Treg_LN;
Tn2Th_inflow                = [(Tn_LN/Ttot_LN)*(BSproAPC_LN/BSAPC_LN)*(alphaTn*beta/Tcontact)*contacts_LN, zeros(size(Tn2Th1_LN,1),size(Tn2Th1_LN,2)-1)]; 
Tn2Th1_egress              	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th1_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th1_LN,1),1]).*Tn2Th1_LN;
Tn2Th1_prol               	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th1_LN,2)-2]),0],[size(Tn2Th1_LN,1),1]).*Tn2Th1_LN;
Tn2Th1_death               	= muTprol*Tn2Th1_LN;
Tn2Th2_egress              	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th2_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th2_LN,1),1]).*Tn2Th2_LN;
Tn2Th2_prol               	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th2_LN,2)-2]),0],[size(Tn2Th2_LN,1),1]).*Tn2Th2_LN;
Tn2Th2_death              	= muTprol*Tn2Th2_LN;
Tn2Th17_egress              = repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th17_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th17_LN,1),1]).*Tn2Th17_LN;
Tn2Th17_prol              	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th17_LN,2)-2]),0],[size(Tn2Th17_LN,1),1]).*Tn2Th17_LN;
Tn2Th17_death              	= muTprol*Tn2Th17_LN;
Tcm2Temreg_inflow       	= [(Tcm_LN/Ttot_LN)*(BSantiAPC_LN/BSAPC_LN).*(alphaTm*beta/Tcontact)*contacts_LN, zeros(size(Tcm2Temreg_LN,1),size(Tcm2Temreg_LN,2)-1)];
Tcm2Temreg_egress           = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Temreg_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Temreg_LN,1),1]).*Tcm2Temreg_LN;
Tcm2Temreg_prol           	= repmat([repmat(pTni,[1,size(Tcm2Temreg_LN,2)-1]),0],[size(Tcm2Temreg_LN,1),1]).*Tcm2Temreg_LN;
Tcm2Temreg_death           	= muTprol*Tcm2Temreg_LN;
Tcm2Temh_inflow             = [(Tcm_LN/Ttot_LN)*(BSproAPC_LN/BSAPC_LN).*(alphaTm*beta/Tcontact)*contacts_LN, zeros(size(Tcm2Tem1_LN,1),size(Tcm2Tem1_LN,2)-1)];
Tcm2Tem1_egress             = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem1_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem1_LN,1),1]).*Tcm2Tem1_LN;
Tcm2Tem1_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem1_LN,2)-1]),0],[size(Tcm2Tem1_LN,1),1]).*Tcm2Tem1_LN;
Tcm2Tem1_death           	= muTprol*Tcm2Tem1_LN;
Tcm2Tem2_egress             = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem2_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem2_LN,1),1]).*Tcm2Tem2_LN;
Tcm2Tem2_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem2_LN,2)-1]),0],[size(Tcm2Tem2_LN,1),1]).*Tcm2Tem2_LN;
Tcm2Tem2_death           	= muTprol*Tcm2Tem2_LN;
Tcm2Tem17_egress          	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem17_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem17_LN,1),1]).*Tcm2Tem17_LN;
Tcm2Tem17_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem17_LN,2)-1]),0],[size(Tcm2Tem17_LN,1),1]).*Tcm2Tem17_LN;
Tcm2Tem17_death           	= muTprol*Tcm2Tem17_LN;
Tem2Treg_inflow             = [(Temreg_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Treg_LP,1),size(Tem2Treg_LP,2)-1)];
Tem2Treg_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Treg_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Treg_LP,1),1]).*Tem2Treg_LP;
Tem2Treg_prol              	= repmat([repmat(pTni,[1,size(Tem2Treg_LP,2)-1]),0],[size(Tem2Treg_LP,1),1]).*Tem2Treg_LP;
Tem2Treg_death            	= muTprol*Tem2Treg_LP;
Tem2Th1_inflow             	= [(Tem1_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th1_LP,1),size(Tem2Th1_LP,2)-1)];
Tem2Th1_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th1_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th1_LP,1),1]).*Tem2Th1_LP;
Tem2Th1_prol              	= repmat([repmat(pTni,[1,size(Tem2Th1_LP,2)-1]),0],[size(Tem2Th1_LP,1),1]).*Tem2Th1_LP;
Tem2Th1_death              	= muTprol*Tem2Th1_LP;
Tem2Th2_inflow             	= [(Tem2_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th2_LP,1),size(Tem2Th2_LP,2)-1)];
Tem2Th2_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th2_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th2_LP,1),1]).*Tem2Th2_LP;
Tem2Th2_prol              	= repmat([repmat(pTni,[1,size(Tem2Th2_LP,2)-1]),0],[size(Tem2Th2_LP,1),1]).*Tem2Th2_LP;
Tem2Th2_death              	= muTprol*Tem2Th2_LP;
Tem2Th17_inflow           	= [(Tem17_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th17_LP,1),size(Tem2Th17_LP,2)-1)];
Tem2Th17_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th17_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th17_LP,1),1]).*Tem2Th17_LP;
Tem2Th17_prol              	= repmat([repmat(pTni,[1,size(Tem2Th17_LP,2)-1]),0],[size(Tem2Th17_LP,1),1]).*Tem2Th17_LP;
Tem2Th17_death            	= muTprol*Tem2Th17_LP;

%--------------------------------------------------------------------------
%% ODEs
dX                          = zeros(I.nrOfStates,1);

% Dendritic cells
dX(I.qDC_LP)                = cRecDC - muDC*qDC_LP - nuDCa*sum(Bact_Lu)*qDC_LP - sum(phagoUptake)*qDC_LP*wPhagoLPqDC - ActDC*qDC_LP;
dX(I.tDC_LP)                = nuDCa*Bact_Lu*qDC_LP + phagoUptake*qDC_LP*wPhagoLPqDC - muDC*tDC_LP - epsilonDC*tDC_LP - ActDC*tDC_LP + nuDCa*Bact_Lu*tDCi_LP + phagoUptake*tDCi_LP*wPhagoLPtDC - (iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(tDC_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerDC;
dX(I.rDC_LP)                = ActDC*qDC_LP - muDC*rDC_LP - nuDCa*sum(Bact_Lu)*rDC_LP - sum(phagoUptake)*rDC_LP*wPhagoLPrDC;
dX(I.sDC_LP)                = ActDC*tDC_LP + nuDCa*Bact_Lu*rDC_LP + phagoUptake*rDC_LP*wPhagoLPrDC - muDC*sDC_LP - epsilonDC*sDC_LP + nuDCa*Bact_Lu*sDCi_LP + phagoUptake*sDCi_LP*wPhagoLPsDC - (iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(sDC_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerDC;
dX(I.tDCi_LP)               = sum((iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(tDC_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerDC) - muDC*tDCi_LP - epsilonDC*tDCi_LP - ActDC*tDCi_LP - nuDCa*sum(Bact_Lu)*tDCi_LP - sum(phagoUptake)*tDCi_LP*wPhagoLPtDC;
dX(I.sDCi_LP)               = sum((iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(sDC_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerDC) - muDC*sDCi_LP - epsilonDC*sDCi_LP + ActDC*tDCi_LP - nuDCa*sum(Bact_Lu)*sDCi_LP - sum(phagoUptake)*sDCi_LP*wPhagoLPsDC;
dX(I.tDC_LN)                = epsilonDC*tDC_LP*VLP_VLN - muDC_LN*tDC_LN - (iTreg_eff_LN/Ttot_LN).*(BSantiAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact)*contacts_LN/bsPerDC;
dX(I.sDC_LN)                = epsilonDC*sDC_LP*VLP_VLN - muDC_LN*sDC_LN - (iTreg_eff_LN/Ttot_LN).*(BSproAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact)*contacts_LN/bsPerDC;
dX(I.tDCi_LN)               = epsilonDC*tDCi_LP*VLP_VLN - muDC_LN*tDCi_LN + sum((iTreg_eff_LN/Ttot_LN).*(BSantiAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact)*contacts_LN/bsPerDC);
dX(I.sDCi_LN)               = epsilonDC*sDCi_LP*VLP_VLN - muDC_LN*sDCi_LN + sum((iTreg_eff_LN/Ttot_LN).*(BSproAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact)*contacts_LN/bsPerDC);

% T cells in LN
dX(I.Tn_LN)                 = lambdaT_LN*fractionTnCD4_bl - muT_LN*Tn_LN - sum(sum(Tn2Treg_inflow)) - sum(sum(Tn2Th_inflow));
dX(I.Tcm_LN)                = lambdaT_LN*fractionTcmCD4_bl - muT_LN*Tcm_LN - sum(sum(Tcm2Temreg_inflow)) - sum(sum(Tcm2Temh_inflow));

% Proliferating T cells:
% naive
dX(I.Tn2Treg_LN)            = Tn2Treg_inflow - Tn2Treg_egress - Tn2Treg_death - Tn2Treg_prol + 2*[zeros(size(Tn2Treg_LN,1),1) Tn2Treg_prol(:,1:end-1)];
dX(I.Tn2Th1_LN)           	= Tn2Th_inflow.*repmat(fractionTh1,[1,size(Tn2Th1_LN,2)]) - Tn2Th1_egress - Tn2Th1_death - Tn2Th1_prol + 2*[zeros(size(Tn2Th1_LN,1),1) Tn2Th1_prol(:,1:end-1)];
dX(I.Tn2Th2_LN)           	= Tn2Th_inflow.*repmat(fractionTh2,[1,size(Tn2Th2_LN,2)]) - Tn2Th2_egress - Tn2Th2_death - Tn2Th2_prol + 2*[zeros(size(Tn2Th2_LN,1),1) Tn2Th2_prol(:,1:end-1)];
dX(I.Tn2Th17_LN)           	= Tn2Th_inflow.*repmat(fractionTh17,[1,size(Tn2Th17_LN,2)]) - Tn2Th17_egress - Tn2Th17_death - Tn2Th17_prol + 2*[zeros(size(Tn2Th17_LN,1),1) Tn2Th17_prol(:,1:end-1)];
% central memory
dX(I.Tcm2Temreg_LN)      	= Tcm2Temreg_inflow - Tcm2Temreg_egress - Tcm2Temreg_death - Tcm2Temreg_prol + 2*[zeros(size(Tcm2Temreg_LN,1),1) Tcm2Temreg_prol(:,1:end-1)];
dX(I.Tcm2Tem1_LN)           = Tcm2Temh_inflow.*repmat(fractionTh1,[1,size(Tcm2Tem1_LN,2)]) - Tcm2Tem1_egress - Tcm2Tem1_death - Tcm2Tem1_prol + 2*[zeros(size(Tcm2Tem1_LN,1),1) Tcm2Tem1_prol(:,1:end-1)];
dX(I.Tcm2Tem2_LN)           = Tcm2Temh_inflow.*repmat(fractionTh2,[1,size(Tcm2Tem2_LN,2)]) - Tcm2Tem2_egress - Tcm2Tem2_death - Tcm2Tem2_prol + 2*[zeros(size(Tcm2Tem2_LN,1),1) Tcm2Tem2_prol(:,1:end-1)];
dX(I.Tcm2Tem17_LN)        	= Tcm2Temh_inflow.*repmat(fractionTh17,[1,size(Tcm2Tem17_LN,2)]) - Tcm2Tem17_egress - Tcm2Tem17_death - Tcm2Tem17_prol + 2*[zeros(size(Tcm2Tem17_LN,1),1) Tcm2Tem17_prol(:,1:end-1)];
% effector memory
dX(I.Tem2Treg_LP)         	= Tem2Treg_inflow - Tem2Treg_egress - Tem2Treg_death - Tem2Treg_prol + 2*[zeros(size(Tem2Treg_LP,1),1) Tem2Treg_prol(:,1:end-1)];
dX(I.Tem2Th1_LP)           	= Tem2Th1_inflow - Tem2Th1_egress - Tem2Th1_death - Tem2Th1_prol + 2*[zeros(size(Tem2Th1_LP,1),1) Tem2Th1_prol(:,1:end-1)];
dX(I.Tem2Th2_LP)           	= Tem2Th2_inflow - Tem2Th2_egress - Tem2Th2_death - Tem2Th2_prol + 2*[zeros(size(Tem2Th2_LP,1),1) Tem2Th2_prol(:,1:end-1)];
dX(I.Tem2Th17_LP)        	= Tem2Th17_inflow - Tem2Th17_egress - Tem2Th17_death - Tem2Th17_prol + 2*[zeros(size(Tem2Th17_LP,1),1) Tem2Th17_prol(:,1:end-1)];

% T cells in LP
dX(I.Temreg_LP)         	= sum(Tcm2Temreg_egress,2)*VLN_VLP - muT_LP*Temreg_LP - sum(Tem2Treg_inflow,2);
dX(I.Tem1_LP)               = sum(Tcm2Tem1_egress,2)*VLN_VLP   - muT_LP*Tem1_LP   - sum(Tem2Th1_inflow,2);
dX(I.Tem2_LP)               = sum(Tcm2Tem2_egress,2)*VLN_VLP   - muT_LP*Tem2_LP   - sum(Tem2Th2_inflow,2);
dX(I.Tem17_LP)              = sum(Tcm2Tem17_egress,2)*VLN_VLP  - muT_LP*Tem17_LP  - sum(Tem2Th17_inflow,2);

dX(I.iTreg_LP)              = sum(Tn2Treg_egress,2)*VLN_VLP + sum(Tem2Treg_egress,2) - muTeff*iTreg_LP;
dX(I.Th1_LP)            	= sum(Tn2Th1_egress,2)*VLN_VLP  + sum(Tem2Th1_egress,2)  - muTeff*Th1_LP;
dX(I.Th2_LP)            	= sum(Tn2Th2_egress,2)*VLN_VLP  + sum(Tem2Th2_egress,2)  - muTeff*Th2_LP;
dX(I.Th17_LP)            	= sum(Tn2Th17_egress,2)*VLN_VLP + sum(Tem2Th17_egress,2) - muTeff*Th17_LP;

% Macrophages
dX(I.MP1_LP)                = cRecM + lambdaMmax*cyto_RecM^HillRecM/((1+SPM_LP)+cyto_RecM^HillRecM) - nuMP12*MP1_LP - nuMP1eff*MP1_LP - muM*MP1_LP - phagoMP1*nuDCa*sum(Bact_Lu)*MP1_LP - sum(phagoUptake)*MP1_LP*wPhagoLPMP1;
dX(I.MP1a_LP)               = phagoMP1*nuDCa*Bact_Lu*MP1_LP + phagoUptake*MP1_LP*wPhagoLPMP1 - nuMP12*MP1a_LP - nuMP1eff*MP1a_LP - muM*MP1a_LP - (iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP1a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM + phagoMP1*nuDCa*Bact_Lu*MP1ai_LP + phagoUptake*MP1ai_LP*wPhagoLPMP1;
dX(I.MP1ai_LP)              = sum((iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP1a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM) - muM*MP1ai_LP - nuMP12*MP1ai_LP - nuMP1eff*MP1ai_LP - phagoMP1*nuDCa*sum(Bact_Lu)*MP1ai_LP - sum(phagoUptake)*MP1ai_LP*wPhagoLPMP1;
dX(I.MP2_LP)                = nuMP12*MP1_LP - nuMP23*MP2_LP - nuMP2eff*MP2_LP - muM*MP2_LP - phagoMP2*nuDCa*sum(Bact_Lu)*MP2_LP - sum(phagoUptake)*MP2_LP*wPhagoLPMP2;
dX(I.MP2a_LP)               = phagoMP2*nuDCa*Bact_Lu*MP2_LP + phagoUptake*MP2_LP*wPhagoLPMP2 + nuMP12*MP1a_LP - nuMP23*MP2a_LP - nuMP2eff*MP2a_LP - muM*MP2a_LP - (iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP2a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM + phagoMP2*nuDCa*Bact_Lu*MP2ai_LP + phagoUptake*MP2ai_LP*wPhagoLPMP2;
dX(I.MP2ai_LP)              = sum((iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP2a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM) - muM*MP2ai_LP + nuMP12*MP1ai_LP - nuMP23*MP2ai_LP - nuMP2eff*MP2ai_LP - phagoMP2*nuDCa*sum(Bact_Lu)*MP2ai_LP - sum(phagoUptake)*MP2ai_LP*wPhagoLPMP2;
dX(I.MP3_LP)                = nuMP23*MP2_LP - nuMP34*MP3_LP - nuMP3eff*MP3_LP - muM*MP3_LP - phagoMP3*nuDCa*sum(Bact_Lu)*MP3_LP - sum(phagoUptake)*MP3_LP*wPhagoLPMP3;
dX(I.MP3a_LP)               = phagoMP3*nuDCa*Bact_Lu*MP3_LP + phagoUptake*MP3_LP*wPhagoLPMP3 + nuMP23*MP2a_LP - nuMP34*MP3a_LP - nuMP3eff*MP3a_LP - muM*MP3a_LP - (iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP3a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM + phagoMP3*nuDCa*Bact_Lu*MP3ai_LP + phagoUptake*MP3ai_LP*wPhagoLPMP3;
dX(I.MP3ai_LP)              = sum((iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP3a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM) - muM*MP3ai_LP + nuMP23*MP2ai_LP - nuMP34*MP3ai_LP - nuMP3eff*MP3ai_LP - phagoMP3*nuDCa*sum(Bact_Lu)*MP3ai_LP - sum(phagoUptake)*MP3ai_LP*wPhagoLPMP3;
dX(I.MP4_LP)                = nuMP34*MP3_LP - nuMP4eff*MP4_LP - muM*MP4_LP - phagoMP4*nuDCa*sum(Bact_Lu)*MP4_LP - sum(phagoUptake)*MP4_LP*wPhagoLPMP4;
dX(I.MP4a_LP)               = phagoMP4*nuDCa*Bact_Lu*MP4_LP + phagoUptake*MP4_LP*wPhagoLPMP4 + nuMP34*MP3a_LP - nuMP4eff*MP4a_LP  - muM*MP4a_LP - (iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP4a_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM + phagoMP4*nuDCa*Bact_Lu*MP4ai_LP + phagoUptake*MP4ai_LP*wPhagoLPMP4;
dX(I.MP4ai_LP)              = sum((iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP4a_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM) - muM*MP4ai_LP + nuMP34*MP3ai_LP - nuMP4eff*MP4ai_LP - phagoMP4*nuDCa*sum(Bact_Lu)*MP4ai_LP - sum(phagoUptake)*MP4ai_LP*wPhagoLPMP4;
dX(I.Meffero_LP)            = nuMP4eff*MP4_LP + nuMP3eff*MP3_LP + nuMP2eff*MP2_LP + nuMP1eff*MP1_LP - muM*Meffero_LP - phagoMP4*nuDCa*sum(Bact_Lu)*Meffero_LP - sum(phagoUptake)*Meffero_LP*wPhagoLPMP4;
dX(I.Mefferoa_LP)           = phagoMP4*nuDCa*Bact_Lu*Meffero_LP + phagoUptake*Meffero_LP*wPhagoLPMP4 + nuMP4eff*MP4a_LP + nuMP3eff*MP3a_LP + nuMP2eff*MP2a_LP + nuMP1eff*MP1a_LP - muM*Mefferoa_LP - (iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*Mefferoa_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM + phagoMP4*nuDCa*Bact_Lu*Mefferoai_LP + phagoUptake*Mefferoai_LP*wPhagoLPMP4;
dX(I.Mefferoai_LP)        	= sum((iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*Mefferoa_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact)*contacts_LP/bsPerM) - muM*Mefferoai_LP + nuMP1eff*MP1ai_LP + nuMP2eff*MP2ai_LP + nuMP3eff*MP3ai_LP + nuMP4eff*MP4ai_LP - phagoMP4*nuDCa*sum(Bact_Lu)*Mefferoai_LP - sum(phagoUptake)*Mefferoai_LP*wPhagoLPMP4;

% Bacteria
dX(I.Bact_Lu)               = pBactLu.*Bact_Lu*nutrients - muBactLu*Bact_Lu;
dX(I.Bact_LP)               = inflow.*Bact_Lu + pBact.*Bact_LP*(1-sum(Bact_LP)/NmaxBact) - phagoElim.*Phago_LP;

% Neutrophils
dX(I.Neut_LP)               = lambdaNeutMax*(cyto_RecNeut^HillRecNeut+wProLPBact*sum(Bact_LP))/((1+SPM_LP^HillRecNeut)+cyto_RecNeut^HillRecNeut+wProLPBact*sum(Bact_LP)) - muNeutc*Neut_LP - muNeutPhago*sum(phagoElim)*Neut_LP - muNeutMax*Neut_LP*SPM_LP/((1+cyto_RecNeut)+SPM_LP);
dX(I.apoNeut_LP)            = muNeutc*Neut_LP + muNeutPhago*sum(phagoElim)*Neut_LP + muNeutMax*Neut_LP*SPM_LP/((1+cyto_RecNeut)+SPM_LP) - VmaxPhago*MPhago_LP*apoNeut_LP/(KmPhago+apoNeut_LP) - muAponeut*apoNeut_LP;

% Barrier
dX(I.nutrients)             = lambdaNutrients - sum(pBactLu.*Bact_Lu*nutrients);
dX(I.epi)                   = muEpi*ssEpi*min(tissue,1) - muEpi*epi*(1 + muEpiFac*cyto_DamageEpi/(1+cyto_DamageEpi)) - muEpiBact*sum(epsilonBact2.*(1-mucus).*epi.*Bact_Lu);
dX(I.mucus)                 = muMucus*ssMucus*epi - muMucus*mucus;
dX(I.tissue)                = muTis*ssTis*(1 + muTisFac*cyto_TisRemod/(1+cyto_TisRemod)) - muTis*tissue*(1 + muTisFac*cyto_DamageTis/(1+cyto_DamageTis));
dX(I.FCP)                   = (1-epi)*epsilonFCP*Neut_LP - muFCP*FCP;

% Salmonella
if ismember('STm',I.bactName)
    dX(I.MP1a_LP)               = dX(I.MP1a_LP) - phagoMP1*nuDCa*Bact_Lu(I.STm)*MP1a_LP - phagoUptake(I.STm)*MP1a_LP*wPhagoLPMP1;
    dX(I.MP1a_LP(I.STm))        = dX(I.MP1a_LP(I.STm)) + Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP1inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP - phagoMP1*nuDCa*Bact_Lu(I.STm)*MP1_LP - phagoUptake(I.STm)*MP1_LP*wPhagoLPMP1 - phagoMP1*nuDCa*Bact_Lu(I.STm)*MP1ai_LP - phagoUptake(I.STm)*MP1ai_LP*wPhagoLPMP1;
    dX(I.MP1inf_LP)         	= phagoMP1*nuDCa*Bact_Lu(I.STm)*MP1_LP + phagoUptake(I.STm)*MP1_LP*wPhagoLPMP1 + phagoMP1*nuDCa*Bact_Lu(I.STm)*sum(MP1a_LP) + phagoUptake(I.STm)*sum(MP1a_LP)*wPhagoLPMP1 + phagoMP1*nuDCa*Bact_Lu(I.STm)*MP1ai_LP + phagoUptake(I.STm)*MP1ai_LP*wPhagoLPMP1 - nuMP12*MP1inf_LP - nuMP1eff*MP1inf_LP - muM*MP1inf_LP - pSTmInt/(Nburst-1)*MP1inf_LP - Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP1inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    dX(I.MP2a_LP)               = dX(I.MP2a_LP) - phagoMP2*nuDCa*Bact_Lu(I.STm)*MP2a_LP - phagoUptake(I.STm)*MP2a_LP*wPhagoLPMP2;
    dX(I.MP2a_LP(I.STm))        = dX(I.MP2a_LP(I.STm)) + Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP2inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP - phagoMP2*nuDCa*Bact_Lu(I.STm)*MP2_LP - phagoUptake(I.STm)*MP2_LP*wPhagoLPMP2 - phagoMP2*nuDCa*Bact_Lu(I.STm)*MP2ai_LP - phagoUptake(I.STm)*MP2ai_LP*wPhagoLPMP2;
    dX(I.MP2inf_LP)            	= phagoMP2*nuDCa*Bact_Lu(I.STm)*MP2_LP + phagoUptake(I.STm)*MP2_LP*wPhagoLPMP2 + phagoMP2*nuDCa*Bact_Lu(I.STm)*sum(MP2a_LP) + phagoUptake(I.STm)*sum(MP2a_LP)*wPhagoLPMP2 + phagoMP2*nuDCa*Bact_Lu(I.STm)*MP2ai_LP + phagoUptake(I.STm)*MP2ai_LP*wPhagoLPMP2 + nuMP12*MP1inf_LP - nuMP23*MP2inf_LP - nuMP2eff*MP2inf_LP - muM*MP2inf_LP - pSTmInt/(Nburst-1)*MP2inf_LP - Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP2inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    dX(I.MP3a_LP)               = dX(I.MP3a_LP) - phagoMP3*nuDCa*Bact_Lu(I.STm)*MP3a_LP - phagoUptake(I.STm)*MP3a_LP*wPhagoLPMP3;
    dX(I.MP3a_LP(I.STm))        = dX(I.MP3a_LP(I.STm)) + Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP3inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP - phagoMP3*nuDCa*Bact_Lu(I.STm)*MP3_LP - phagoUptake(I.STm)*MP3_LP*wPhagoLPMP3 - phagoMP3*nuDCa*Bact_Lu(I.STm)*MP3ai_LP - phagoUptake(I.STm)*MP3ai_LP*wPhagoLPMP3;
    dX(I.MP3inf_LP)           	= phagoMP3*nuDCa*Bact_Lu(I.STm)*MP3_LP + phagoUptake(I.STm)*MP3_LP*wPhagoLPMP3 + phagoMP3*nuDCa*Bact_Lu(I.STm)*sum(MP3a_LP) + phagoUptake(I.STm)*sum(MP3a_LP)*wPhagoLPMP3 + phagoMP3*nuDCa*Bact_Lu(I.STm)*MP3ai_LP + phagoUptake(I.STm)*MP3ai_LP*wPhagoLPMP3 + nuMP23*MP2inf_LP - nuMP34*MP3inf_LP - nuMP3eff*MP3inf_LP - muM*MP3inf_LP - pSTmInt/(Nburst-1)*MP3inf_LP - Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP3inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    dX(I.MP4a_LP)               = dX(I.MP4a_LP) - phagoMP4*nuDCa*Bact_Lu(I.STm)*MP4a_LP - phagoUptake(I.STm)*MP4a_LP*wPhagoLPMP4;
    dX(I.MP4a_LP(I.STm))        = dX(I.MP4a_LP(I.STm)) + Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP4inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP - phagoMP4*nuDCa*Bact_Lu(I.STm)*MP4_LP - phagoUptake(I.STm)*MP4_LP*wPhagoLPMP4 - phagoMP4*nuDCa*Bact_Lu(I.STm)*MP4ai_LP - phagoUptake(I.STm)*MP4ai_LP*wPhagoLPMP4;
    dX(I.MP4inf_LP)           	= phagoMP4*nuDCa*Bact_Lu(I.STm)*MP4_LP + phagoUptake(I.STm)*MP4_LP*wPhagoLPMP4 + phagoMP4*nuDCa*Bact_Lu(I.STm)*sum(MP4a_LP) + phagoUptake(I.STm)*sum(MP4a_LP)*wPhagoLPMP4 + phagoMP4*nuDCa*Bact_Lu(I.STm)*MP4ai_LP + phagoUptake(I.STm)*MP4ai_LP*wPhagoLPMP4 + nuMP34*MP3inf_LP - nuMP4eff*MP4inf_LP  - muM*MP4inf_LP - pSTmInt/(Nburst-1)*MP4inf_LP - Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP4inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    dX(I.Mefferoa_LP)           = dX(I.Mefferoa_LP) - phagoMP4*nuDCa*Bact_Lu(I.STm)*Mefferoa_LP - phagoUptake(I.STm)*Mefferoa_LP*wPhagoLPMP4;
    dX(I.Mefferoa_LP(I.STm))    = dX(I.Mefferoa_LP(I.STm)) + Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*Mefferoinf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP - phagoMP4*nuDCa*Bact_Lu(I.STm)*Meffero_LP - phagoUptake(I.STm)*Meffero_LP*wPhagoLPMP4 - phagoMP4*nuDCa*Bact_Lu(I.STm)*Mefferoai_LP - phagoUptake(I.STm)*Mefferoai_LP*wPhagoLPMP4;
    dX(I.Mefferoinf_LP)      	= phagoMP4*nuDCa*Bact_Lu(I.STm)*Meffero_LP + phagoUptake(I.STm)*Meffero_LP*wPhagoLPMP4 + phagoMP4*nuDCa*Bact_Lu(I.STm)*sum(Mefferoa_LP) + phagoUptake(I.STm)*sum(Mefferoa_LP)*wPhagoLPMP4 + phagoMP4*nuDCa*Bact_Lu(I.STm)*Mefferoai_LP + phagoUptake(I.STm)*Mefferoai_LP*wPhagoLPMP4 + nuMP4eff*MP4inf_LP + nuMP3eff*MP3inf_LP + nuMP2eff*MP2inf_LP + nuMP1eff*MP1inf_LP - muM*Mefferoinf_LP - pSTmInt/(Nburst-1)*Mefferoinf_LP - Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*Mefferoinf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    dX(I.Bact_LP(I.STm))        = dX(I.Bact_LP(I.STm)) + Nburst*pSTmInt/(Nburst-1)*(MP1inf_LP+MP2inf_LP+MP3inf_LP+MP4inf_LP+Mefferoinf_LP);
end

%--------------------------------------------------------------------------

if any(isnan(dX))
    table(I.stateName(1:length(X))',X)
    error('NaN in ODE function!')
end

if any(isnan(X))
    table(I.stateName(1:length(X))',X)
    error('NaN in state variables!')
end

%--------------------------------------------------------------------------
%%% Uncomment for script IBD_Contacts %%%
% APCtot_LN = tDC_LN+sDC_LN+tDCi_LN+sDCi_LN;
% fprintf('Lymph node:\n\t%.1f contacts per h per DC\n\t%.1f contacts per h per T cell\n',contacts_LN/Tcontact/APCtot_LN,contacts_LN/Tcontact/Ttot_LN)
% fprintf('\tDC in average in contact to %.1f T cells\n\tT cell in average in contact with %.1f DC\n',contacts_LN/APCtot_LN,contacts_LN/Ttot_LN)
% APCtot_LP = BSantiAPC_LP_cells+BSproAPC_LP_cells+BSneutralAPC_LP/bsPerDC;
% fprintf('Lamina propria:\n\t%.1f contacts per h per DC\n\t%.1f contacts per h per T cell\n',contacts_LP/Tcontact/APCtot_LP,contacts_LP/Tcontact/Ttot_LP)
% fprintf('\tDC in average in contact to %.1f T cells\n\tT cell in average in contact with %.1f DC\n',contacts_LP/APCtot_LP,contacts_LP/Ttot_LP)
%%% end %%%
%--------------------------------------------------------------------------

end