function model = IBD_options(model)
%==========================================================================
% model = IBD_options(model)
%==========================================================================
% Default options
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

% Time span
default.timespan_ss = [0 1e9];
default.timespanFactor = 100;
default.timespan   	= [0 50*24];
default.ss_small  	= 1e-5;
default.timeLimit   = 30;           % [s]

% Hybrid algorithm options
default.asd        	= 10;           % propensity threshold between stochastic and deterministic simulation
default.det        	= [];           % reactions that are always simulated deterministically
default.sto       	= [];           % reactions that are always simulated stochastically
default.t_print    	= 10;           % time step to print notification (hybrid algorithm)

% Simulation options
default.odeType   	= 'RHS';       	% 'RHS' (ODE right-hand side function) | 'rates' (reaction rates and stoichiometric matrix)
AbsTol              = 1e-6;         % Matlab default: 1e-6
RelTol              = 1e-3;         % Matlab default: 1e-3

%--------------------------------------------------------------------------

for field = fieldnames(default)'
    Field = char(field);
    if ~isfield(model,Field)
        model.(Field) = default.(Field);
    end
end

%--------------------------------------------------------------------------
model.ODEoptions_ss	= @(odefunction,startTime) odeset('AbsTol',AbsTol,'RelTol',RelTol,'NonNegative',1:model.I.nrOfStates,'Events',@(t,y)event_ss(t,y,model.ss_small,odefunction,startTime,model.timeLimit));
model.ODEoptions 	= odeset('AbsTol',AbsTol,'RelTol',RelTol,'NonNegative',1:model.I.nrOfStates);

%--------------------------------------------------------------------------

end

%==========================================================================
% LOCAL FUNCTIONS

% Event function: steady state or time limit exceeded
function [value,isterminal,direction] = event_ss(t,x,xi,odefunction,startTime,timeLimit)
dx          = odefunction(t,x);
a           = abs(dx./x);
a(x<1e-5)   = 0;
slope       = max(a)-xi;    % value(i) is a mathematical expression describing the ith event. An event occurs when value(i) is equal to zero.
timeLeft    = timeLimit - toc(startTime);
value       = [slope;timeLeft];
isterminal  = [1;1];        	% isterminal(i) = 1 if the integration is to terminate when the ith event occurs. Otherwise, it is 0.
direction   = [0;0];         	% direction(i) = 0 if all zeros are to be located (the default); 1 event function increasing; -1 event function decreasing.
end


%--------------------------------------------------------------------------