function ode = IBD_prepareSimulation(par,model)
%==========================================================================
% model = IBD_prepareSimulation(par,model)
%==========================================================================
% Define ODE with input (t,X)
%--------------------------------------------------------------------------
%-- input
% par:          parameter vector
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% T:            time points of simulation results
% Y:            simulation results
%==========================================================================

switch model.odeType

    % Using ODE right-hand side function
    case 'RHS'
        ode = @(t,X) IBD_ode(t,X,par,model);

    % Using reaction rates/propensities and stoichiometric matrix
    case 'rates'
    	nu  = sparse(IBD_stochMatrix(model));                               % par used: VLN_VLP, VLP_VLN, nTn, nTm
        ode	= @(t,X) nu*(IBD_reactionRates(t,X,par.*(1-model.ko.par),model).*(1-model.ko.a));
end

%--------------------------------------------------------------------------

end