function a = IBD_reactionRates(~,X,par,model)
%==========================================================================
% a = IBD_reactionRates(~,X,par,model)
%==========================================================================
% Reaction rates/propensities
%--------------------------------------------------------------------------
%-- input
% t:            time point
% X:            current values of state variables
% par:          parameters
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% a:            reaction rates/propensities (row vector)
%==========================================================================

I 	= model.I;

%--------------------------------------------------------------------------
%% SPECIES
% LP = lamina propria; LN = mesenteric lymph node
% [1/mL]
qDC_LP          = X(I.qDC_LP);          % quiescent dendritic cells
tDC_LP          = X(I.tDC_LP);          % tolerogenic dendritic cells
rDC_LP          = X(I.rDC_LP);          % responsive dendritic cells
sDC_LP          = X(I.sDC_LP);          % stimulatory dendritic cells
tDCi_LP         = X(I.tDCi_LP);         % tolerogenic dendritic cells (inhibited antigen presentation)
sDCi_LP         = X(I.sDCi_LP);         % stimulatory dendritic cells (inhibited antigen presentation)
tDC_LN  		= X(I.tDC_LN);          % tolerogenic dendritic cells
sDC_LN          = X(I.sDC_LN);          % stimulatory dendritic cells
tDCi_LN         = X(I.tDCi_LN);         % tolerogenic dendritic cells (inhibited antigen presentation)
sDCi_LN         = X(I.sDCi_LN);         % stimulatory dendritic cells (inhibited antigen presentation)
Tn_LN           = X(I.Tn_LN);           % naive CD4+ T cells
Tcm_LN          = X(I.Tcm_LN);          % central memory T cells
Tn2Treg_LN 		= reshape(X(I.Tn2Treg_LN),size(I.Tn2Treg_LN));     	% naive T cells stimulated by tolerogenic dendritic cells, proliferating and differentiating to Treg
Tn2Th1_LN     	= reshape(X(I.Tn2Th1_LN),size(I.Tn2Th1_LN));     	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th1
Tn2Th2_LN     	= reshape(X(I.Tn2Th2_LN),size(I.Tn2Th2_LN));      	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th2
Tn2Th17_LN     	= reshape(X(I.Tn2Th17_LN),size(I.Tn2Th17_LN));   	% naive T cells stimulated by stimulatory dendritic cells, proliferating and differentiating to Th17
Tcm2Temreg_LN   = reshape(X(I.Tcm2Temreg_LN),size(I.Tcm2Temreg_LN));% central memory T cells stimulated by tolerogenic dendritic cells, proliferating and differentiating (regulatory type)
Tcm2Tem1_LN     = reshape(X(I.Tcm2Tem1_LN),size(I.Tcm2Tem1_LN));	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 1)
Tcm2Tem2_LN     = reshape(X(I.Tcm2Tem2_LN),size(I.Tcm2Tem2_LN));   	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 2)
Tcm2Tem17_LN    = reshape(X(I.Tcm2Tem17_LN),size(I.Tcm2Tem17_LN)); 	% central memory T cells stimulated by stimulatory dendritic cells, proliferating and differentiating (type 17)
Tem2Treg_LP     = reshape(X(I.Tem2Treg_LP),size(I.Tem2Treg_LP));  	% effector memory T cells, proliferating and differentiating to Treg
Tem2Th1_LP      = reshape(X(I.Tem2Th1_LP),size(I.Tem2Th1_LP));      % effector memory T cells, proliferating and differentiating to Th1
Tem2Th2_LP      = reshape(X(I.Tem2Th2_LP),size(I.Tem2Th2_LP));      % effector memory T cells, proliferating and differentiating to Th2
Tem2Th17_LP   	= reshape(X(I.Tem2Th17_LP),size(I.Tem2Th17_LP)); 	% effector memory T cells, proliferating and differentiating to Th17
Temreg_LP       = X(I.Temreg_LP);       % effector memory T cells (regulatory type)
Tem1_LP       	= X(I.Tem1_LP);         % effector memory T cells (type 1)
Tem2_LP       	= X(I.Tem2_LP);         % effector memory T cells (type 2)
Tem17_LP       	= X(I.Tem17_LP);    	% effector memory T cells (type 17)
iTreg_LP 		= X(I.iTreg_LP);        % induced regulatory T cells
Th1_LP       	= X(I.Th1_LP);       	% type 1 T helper cells
Th2_LP       	= X(I.Th2_LP);       	% type 2 T helper cells
Th17_LP       	= X(I.Th17_LP);       	% type 17 T helper cells
MP1_LP        	= X(I.MP1_LP);         	% macrophages (P1)
MP1a_LP         = X(I.MP1a_LP);        	% antigen-experienced macrophages (P1)
MP1ai_LP        = X(I.MP1ai_LP);        % antigen-experienced macrophages (P1) (inhibited antigen presentation)
MP2_LP        	= X(I.MP2_LP);         	% macrophages (P2)
MP2a_LP       	= X(I.MP2a_LP);        	% antigen-experienced macrophages (P2)
MP2ai_LP        = X(I.MP2ai_LP);        % antigen-experienced macrophages (P2) (inhibited antigen presentation)
MP3_LP         	= X(I.MP3_LP);       	% macrophages (P3)
MP3a_LP       	= X(I.MP3a_LP);       	% antigen-experienced macrophages (P3)
MP3ai_LP        = X(I.MP3ai_LP);        % antigen-experienced macrophages (P3) (inhibited antigen presentation)
MP4_LP         	= X(I.MP4_LP);        	% macrophages (P4)
MP4a_LP        	= X(I.MP4a_LP);      	% antigen-experienced macrophages (P4)
MP4ai_LP        = X(I.MP4ai_LP);        % antigen-experienced macrophages (P4) (inhibited antigen presentation)
Meffero_LP      = X(I.Meffero_LP);      % efferocytosis-type macrophages
Mefferoa_LP     = X(I.Mefferoa_LP);     % antigen-experienced efferocytosis-type macrophages
Mefferoai_LP   	= X(I.Mefferoai_LP);  	% antigen-experienced efferocytosis-type (P1) (inhibited antigen presentation)
MP1inf_LP    	= X(I.MP1inf_LP);       % infected macrophages (P1)
MP2inf_LP     	= X(I.MP2inf_LP);      	% infected macrophages (P2)
MP3inf_LP     	= X(I.MP3inf_LP);     	% infected macrophages (P3)
MP4inf_LP     	= X(I.MP4inf_LP);      	% infected macrophages (P4)
Mefferoinf_LP	= X(I.Mefferoinf_LP); 	% infected efferocytosis-type macrophages
Bact_LP         = X(I.Bact_LP);         % extracellular bacteria
Neut_LP         = X(I.Neut_LP);         % neutrophil granulocytes
apoNeut_LP      = X(I.apoNeut_LP);      % apoptotitc neutrophil granulocytes
Bact_Lu         = X(I.Bact_Lu);         % bacteria
nutrients       = X(I.nutrients);       % nutrients for bacteria
epi           	= X(I.epi);             % epithelial barrier
mucus           = X(I.mucus);           % mucus layer
tissue          = X(I.tissue);          % tissue/ECM
FCP             = X(I.FCP);             % fecal calprotectin

%--------------------------------------------------------------------------
%% PARAMETERS
par = par';
VLP                 = par(I.VLP);                   % [mL] volume of total lamina propria (small + large intestine)
muT_LN              = par(I.muT_LN);                % [1/h] outflow of T cells from MLN
muT_LP              = par(I.muT_LP);                % [1/h] death of effector memory T cells
lambdaT_LN          = par(I.lambdaT_LN);            % [1/(mL*h)] rate constant (inflow rate constant * volume correction coefficient * concentration of CD4+ T cells in blood) for inflow of T cells into MLN
muTeff              = par(I.muTeff);                % [1/h] effector T cell death rate constant
fractionTnCD4_bl    = par(I.fractionTnCD4_bl);      % [] fraction of naive CD4+ T cells from CD4+ T cells (blood)
fractionTcmCD4_bl   = par(I.fractionTcmCD4_bl);     % [] fraction of central memory CD4+ T cells from CD4+ (blood)
nTn                 = par(I.nTn);                   % [] maximal number of transit compartments for naive T cells
nTm                 = par(I.nTm);                   % [] number of transit compartments for differentiation/proliferation of memory T cells
muTprol             = par(I.muTprol);             	% [1/h] death rate constant of proliferating T cells
suscApoLow          = par(I.suscApoLow);            % [] susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th)
pTn1                = par(I.pTn1);                  % [1/h] proliferation rate constant of activated naive T cells (first division)
pTni                = par(I.pTni);                  % [1/h] proliferation rate constant of activated naive T cells (subsequent divisions)
egressPerDivision   = par(I.egressPerDivision); 	% [] increase in egress rate per division (starting at division 4)
egressThreshold     = par(I.egressThreshold);       % [] minimal division number for egress
egressThresholdm    = par(I.egressThresholdm);      % [] minimal division number for egress (memory T cells)
fractionTh1         = par(I.theta1host)*par(I.theta1bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));  % [] fraction of Th1 cells elicited by this bacterial species
fractionTh2         = par(I.theta2host)*par(I.theta2bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));  % [] fraction of Th2 cells elicited by this bacterial species
fractionTh17        = par(I.theta17host)*par(I.theta17bact)./(par(I.theta1host)*par(I.theta1bact)+par(I.theta2host)*par(I.theta2bact)+par(I.theta17host)*par(I.theta17bact));% [] fraction of Th17 cells elicited by this bacterial species
alphaTn             = par(I.alphaTn);               % [] frequency of antigen specificity in naive T cells
alphaTh             = par(I.alphaTh);             	% [] frequency of antigen specificity in effector T cells
alphaTm             = par(I.alphaTm);               % [] frequency of antigen specificity in memory T cells
beta                = par(I.beta);                	% [] number of antigens per bacterium/presented per dendritic cell
Tcontact            = par(I.Tcontact);             	% [h] mean contact duration between DC and Tn/Tm
muDC                = par(I.muDC);                  % [1/h] death rate constant of dendritic cells
muDC_LN             = par(I.muDC_LN);               % [1/h] migration rate of dendritic cells out of LN
nuDCa               = par(I.nuDCa);                 % [1/h] conversion rate constant from antigen-unexperienced to antigen-experienced dendritic cells (LP)
epsilonDC           = par(I.epsilonDC);             % [1/h] migration of dendritic cells from LP to MLN
cRecDC              = par(I.cRecDC);                % [1/(mL*h)] constant inflow of quiescent dendritic cells into LP
nuDCsMax            = par(I.nuDCsMax);              % [1/h] maximal dendritic cell activation
HillProActDC      	= par(I.HillProActDC);        	% [] Hill factor for dendritic cell activation stimulation by pro-inflammatory cytokines
HillAntiActDC    	= par(I.HillAntiActDC);     	% [] Hill factor for dendritic cell activation inhibition by anti-inflammatory cytokines
kTDC_LN             = par(I.kTDC_LN);               % [mL/h] contact rate constant for T and DC in LN
kTDC_LP             = par(I.kTDC_LP);               % [mL/h] contact rate constant for T and DC in LP
bsPerDC           	= par(I.bsPerDC);               % [] T cell binding sites per DC
bsPerT           	= par(I.bsPerT);            	% [] DC binding sites per T cell
bsPerM           	= par(I.bsPerM);            	% [] T cell binding sites per macrophage
muM                 = par(I.muM);                   % [1/h] death of macrophages
nuMP12ss            = par(I.nuMP12ss);              % [1/h] transition from macrophage compartment 1 to 2 in steady state
nuMP23ss            = par(I.nuMP23ss);              % [1/h] transition from macrophage compartment 2 to 3 in steady state
nuMP34ss            = par(I.nuMP34ss);              % [1/h] transition from macrophage compartment 3 to 4 in steady state
phagoMP1            = par(I.phagoMP1);              % [] phagocytic activity of P1 macrophages, relative to dendritic cells
phagoMP2            = par(I.phagoMP2);              % [] phagocytic activity of P2 macrophages, relative to dendritic cells
phagoMP3            = par(I.phagoMP3);              % [] phagocytic activity of P3 macrophages, relative to dendritic cells
phagoMP4            = par(I.phagoMP4);              % [] phagocytic activity of P4 macrophages, relative to dendritic cells
lambdaMmax          = par(I.lambdaMmax);            % [1/(mL*h)] maximal macrophage inflow into LP
HillRecM            = par(I.HillRecM);              % [] Hill factor for macrophage recruitment by stimulated cells
cRecM               = par(I.cRecM);                 % [1/(mL*h)] constant macrophage inflow into LP
nuMphago            = par(I.nuMphago);              % [] fraction of macrophages that move to next state after phagocytosis of one apoptotic neutrophil
HillProActM      	= par(I.HillProActM);        	% [] Hill factor for macrophage transition inhibition by pro-inflammatory cytokines
HillAntiActM      	= par(I.HillAntiActM);      	% [] Hill factor for macrophage transition stimulation by anti-inflammatory cytokines
pBact               = par(I.pBact);                 % [1/h] growth of bacteria in tissue
NmaxBact            = par(I.NmaxBact);              % [1/mL] maximal concentration of bacteria in LP
VmaxPhago           = par(I.VmaxPhago);             % [1/h] maximal phagocytosis rate of bacteria per neutrophil (/phagocytic cell)
KmPhago             = par(I.KmPhago);               % [1/mL] bacteria concentration for half-maximal phagocytosis rate per neutrophil (/phagocytic cell)
phagoRec            = par(I.phagoRec);              % [] probability of recognition of bacteria by phagocytic cells
pSTmInt             = par(I.pSTmInt);               % [1/h] intracellular growth rate of S.Tm [Gog2012]
Nburst              = par(I.Nburst);                % [] burst threshold: maximal number of bacteria per macrophage [Brown2006]
lambdaNeutMax       = par(I.lambdaNeutMax);         % [1/(mL*h)] maximal neutrophil inflow into LP
HillRecNeut         = par(I.HillRecNeut);           % [] Hill factor for neutrophil recruitment
muNeutc             = par(I.muNeutc);               % [1/h] constitutive/spontaneous neutrophil apoptosis
muNeutPhago     	= par(I.muNeutPhago);       	% [] proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell
muNeutMax           = par(I.muNeutMax);             % [1/h] maximal neutrophil apoptosis, stimulated by SPM
muAponeut           = par(I.muAponeut);             % [1/h] necrosis of apoptotic neutrophils
pBactLu             = par(I.pBactLu);               % [1/h] proliferation of bacteria in lumen
muBactLu            = par(I.muBactLu);              % [1/h] death of bacteria in lumen
lambdaNutrients     = par(I.lambdaNutrients);       % [1/h] inflow of nutrients
epsilonBact1        = par(I.epsilonBact1);       	% [1/(mL*h)] inflow of bacteria without toxin
epsilonBact2        = par(I.epsilonBact2);          % [1/(mL*h)] inflow of bacteria with toxin
muEpi               = par(I.muEpi);                 % [1/h] degradation of epithelium
ssEpi           	= par(I.ssEpi);                 % [] steady state value of epithelium
muEpiBact           = par(I.muEpiBact);           	% [mL] destruction of epithelium by bacteria with toxin
muEpiFac            = par(I.muEpiFac);              % [] maximal relative increase of epithelium degradation
muMucus             = par(I.muMucus);            	% [1/h] degradation of mucus layer
ssMucus             = par(I.ssMucus);        		% [] steady state value of mucus
muTis               = par(I.muTis);                 % [1/h] degradation of tissue
ssTis           	= par(I.ssTis);                 % [] steady state value of tissue
muTisFac            = par(I.muTisFac);              % [] maximal relative increase of tissue degradation
epsilonFCP          = par(I.epsilonFCP);            % [mL*ug/(h*g)] outflow of neutrophils (FCP) into lumen
muFCP               = par(I.muFCP);                 % [1/h] outflow of FCP from lumen

% Weights:
wPhagoLPqDC         = par(I.wPhagoLPqDC);
wPhagoLPrDC         = par(I.wPhagoLPrDC);
wPhagoLPtDC         = par(I.wPhagoLPtDC);
wPhagoLPsDC         = par(I.wPhagoLPsDC);
wPhagoLPMP1         = par(I.wPhagoLPMP1);
wPhagoLPMP2         = par(I.wPhagoLPMP2);
wPhagoLPMP3         = par(I.wPhagoLPMP3);
wPhagoLPMP4         = par(I.wPhagoLPMP4);
wPhagoLPNeut        = par(I.wPhagoLPNeut);
wcyto_RecNeut_Th1   = par(I.wcyto_RecNeut_Th1);
wcyto_RecNeut_Th17  = par(I.wcyto_RecNeut_Th17);
wcyto_RecNeut_Neut  = par(I.wcyto_RecNeut_Neut);
wcyto_RecNeut_M     = par(I.wcyto_RecNeut_M);
wcyto_RecM_Th1      = par(I.wcyto_RecM_Th1);
wcyto_RecM_Th17     = par(I.wcyto_RecM_Th17);
wcyto_RecM_Neut     = par(I.wcyto_RecM_Neut);
wcyto_RecM_M        = par(I.wcyto_RecM_M);
wcyto_ActM_Th1      = par(I.wcyto_ActM_Th1);
wcyto_ActM_Th17     = par(I.wcyto_ActM_Th17);
wcyto_ActM_Neut     = par(I.wcyto_ActM_Neut);
wcyto_ActM_M        = par(I.wcyto_ActM_M);
wcyto_ActDC_Th1     = par(I.wcyto_ActDC_Th1);
wcyto_ActDC_Th17    = par(I.wcyto_ActDC_Th17);
wcyto_ActDC_Neut    = par(I.wcyto_ActDC_Neut);
wcyto_ActDC_M       = par(I.wcyto_ActDC_M);
wcyto_DeactM_Treg   = par(I.wcyto_DeactM_Treg);
wcyto_DeactM_Th2    = par(I.wcyto_DeactM_Th2);
wcyto_DeactM_M      = par(I.wcyto_DeactM_M);
wcyto_DeactDC_Treg  = par(I.wcyto_DeactDC_Treg);
wcyto_DeactDC_Th2   = par(I.wcyto_DeactDC_Th2);
wcyto_DeactDC_M     = par(I.wcyto_DeactDC_M);
wcyto_DamageEpi_Th1	= par(I.wcyto_DamageEpi_Th1);
wcyto_DamageEpi_Th17= par(I.wcyto_DamageEpi_Th17);
wcyto_DamageEpi_Th2 = par(I.wcyto_DamageEpi_Th2);
wcyto_DamageEpi_Neut= par(I.wcyto_DamageEpi_Neut);
wcyto_DamageEpi_M  	= par(I.wcyto_DamageEpi_M);
wcyto_DamageTis_Th1	= par(I.wcyto_DamageTis_Th1);
wcyto_DamageTis_Th17= par(I.wcyto_DamageTis_Th17);
wcyto_DamageTis_Th2 = par(I.wcyto_DamageTis_Th2);
wcyto_DamageTis_Neut= par(I.wcyto_DamageTis_Neut);
wcyto_DamageTis_M  	= par(I.wcyto_DamageTis_M);
wcyto_TisRemod_Th2  = par(I.wcyto_TisRemod_Th2);
wcyto_TisRemod_M  	= par(I.wcyto_TisRemod_M);
wProLPBact         	= par(I.wProLPBact);
wSPMLPNeut          = par(I.wSPMLPNeut);
wSPMLPMeffero       = par(I.wSPMLPMeffero);

%--------------------------------------------------------------------------
%% Calculations of combined species and rates for multiple use

% Effector T cells
iTreg_eff_LN	= sum(Tn2Treg_LN(:,2:end),2);
iTreg_eff_LP    = sum(Tem2Treg_LP(:,2:end),2)+iTreg_LP+Temreg_LP;
Th1_eff_LP     	= sum(Tem2Th1_LP(:,2:end),2)+Th1_LP+Tem1_LP;
Th2_eff_LP     	= sum(Tem2Th2_LP(:,2:end),2)+Th2_LP+Tem2_LP;
Th17_eff_LP   	= sum(Tem2Th17_LP(:,2:end),2)+Th17_LP+Tem17_LP;

% T cell - dendritic cell contacts
% LN:
Ttot_LN     = Tn_LN + Tcm_LN...
    + sum(sum(Tn2Th1_LN(:,2:end)))   + sum(sum(Tn2Th2_LN(:,2:end)))   + sum(sum(Tn2Th17_LN(:,2:end)))   + sum(sum(Tn2Treg_LN(:,2:end)))...
    + sum(sum(Tcm2Tem1_LN(:,2:end))) + sum(sum(Tcm2Tem2_LN(:,2:end))) + sum(sum(Tcm2Tem17_LN(:,2:end))) + sum(sum(Tcm2Temreg_LN(:,2:end)));
BST_LN              = Ttot_LN*bsPerT;                                            	% T cell binding sites
BSantiAPC_LN        = tDC_LN*bsPerDC - (Tn2Treg_LN(:,1) + Tcm2Temreg_LN(:,1));    	% tDC binding sites (Bact-specific)
BSproAPC_LN         = sDC_LN*bsPerDC - (Tn2Th1_LN(:,1) + Tn2Th2_LN(:,1) + Tn2Th17_LN(:,1) + Tcm2Tem1_LN(:,1) + Tcm2Tem2_LN(:,1) + Tcm2Tem17_LN(:,1)); % sDC binding sites (Bact-specific)
BSneutralAPC_LN     = (tDCi_LN + sDCi_LN)*bsPerDC;
BSAPC_LN            = sum(BSantiAPC_LN) + sum(BSproAPC_LN) + BSneutralAPC_LN;   	% DC binding sites (total, all Bact)
contacts_LN         = (BST_LN+BSAPC_LN+(bsPerT*bsPerDC/(Tcontact*kTDC_LN))-sqrt((BST_LN+BSAPC_LN+(bsPerT*bsPerDC/(Tcontact*kTDC_LN)))^2-4*BST_LN*BSAPC_LN))/2;
if Ttot_LN == 0
    Ttot_LN = 1;
end
if BSAPC_LN == 0
    BSAPC_LN = 1;
end

% LP:
Ttot_LP             = sum(iTreg_eff_LP) + sum(Th1_eff_LP) + sum(Th2_eff_LP) + sum(Th17_eff_LP);
BST_LP              = Ttot_LP*bsPerT;                                           	% T cell binding sites
BSantiAPC_LP_cells  = tDC_LP+bsPerM/bsPerDC*(MP4a_LP+Mefferoa_LP);
BSantiAPC_LP_cells(I.STm) = BSantiAPC_LP_cells(I.STm) + bsPerM/bsPerDC*(MP4inf_LP + Mefferoinf_LP);
BSantiAPC_LP        = BSantiAPC_LP_cells*bsPerDC - (Tem2Treg_LP(:,1));    	% tDC + Manti binding sites (Bact-specific)
BSproAPC_LP_cells   = sDC_LP+bsPerM/bsPerDC*(MP1a_LP+MP2a_LP+MP3a_LP);
BSproAPC_LP_cells(I.STm) = BSproAPC_LP_cells(I.STm) + bsPerM/bsPerDC*(MP1inf_LP + MP2inf_LP + MP3inf_LP);
BSproAPC_LP         = BSproAPC_LP_cells*bsPerDC - (Tem2Th1_LP(:,1) + Tem2Th2_LP(:,1) + Tem2Th17_LP(:,1));	% sDC + Mpro binding sites (Bact-specific)
BSneutralAPC_LP     = (tDCi_LP + sDCi_LP + bsPerM/bsPerDC*(MP1ai_LP + MP2ai_LP + MP3ai_LP + MP4ai_LP + Mefferoai_LP))*bsPerDC;
BSAPC_LP            = sum(BSantiAPC_LP) + sum(BSproAPC_LP) + BSneutralAPC_LP;       % APC binding sites (total, all Bact)
contacts_LP         = (BST_LP+BSAPC_LP+(bsPerT*bsPerDC/(Tcontact*kTDC_LP))-sqrt((BST_LP+BSAPC_LP+(bsPerT*bsPerDC/(Tcontact*kTDC_LP)))^2-4*BST_LP*BSAPC_LP))/2;
if Ttot_LP == 0
    Ttot_LP = 1;
end
if BSAPC_LP == 0
    BSAPC_LP = 1;
end
for k = 1:length(BSantiAPC_LP_cells)
    if BSantiAPC_LP_cells(k) == 0
        BSantiAPC_LP_cells(k) = 1;
    end
end
for k = 1:length(BSproAPC_LP_cells)
    if BSproAPC_LP_cells(k) == 0
        BSproAPC_LP_cells(k) = 1;
    end
end

% Cytokine-producing cells
cyto_Th1        = sum((Th1_eff_LP/Ttot_LP) .*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
cyto_Th2        = sum((Th2_eff_LP/Ttot_LP) .*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
cyto_Th17      	= sum((Th17_eff_LP/Ttot_LP).*((BSproAPC_LP+BSantiAPC_LP)/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP); % cytokine production only after stimulation by cognate antigen
Mpro            = sum(MP1a_LP)+sum(MP2a_LP)+sum(MP3a_LP)+sum(MP1ai_LP)+sum(MP2ai_LP)+sum(MP3ai_LP)+sum(MP1inf_LP)+sum(MP2inf_LP)+sum(MP3inf_LP);
Manti           = sum(MP4a_LP)+sum(Mefferoa_LP)+sum(MP4ai_LP)+sum(Mefferoai_LP)+sum(MP4inf_LP)+sum(Mefferoinf_LP);
cyto_RecNeut    = wcyto_RecNeut_Th1*cyto_Th1    + wcyto_RecNeut_Th17*cyto_Th17  + wcyto_RecNeut_Neut*Neut_LP    + wcyto_RecNeut_M*Mpro;
cyto_RecM       = wcyto_RecM_Th1*cyto_Th1       + wcyto_RecM_Th17*cyto_Th17     + wcyto_RecM_Neut*Neut_LP       + wcyto_RecM_M*Mpro;
cyto_ActM       = wcyto_ActM_Th1*cyto_Th1       + wcyto_ActM_Th17*cyto_Th17     + wcyto_ActM_Neut*Neut_LP       + wcyto_ActM_M*Mpro;
cyto_ActDC      = wcyto_ActDC_Th1*cyto_Th1      + wcyto_ActDC_Th17*cyto_Th17 	+ wcyto_ActDC_Neut*Neut_LP     	+ wcyto_ActDC_M*Mpro;
cyto_DeactM     = wcyto_DeactM_Treg*sum(iTreg_LP)   + wcyto_DeactM_Th2*cyto_Th2     + wcyto_DeactM_M*Manti;
cyto_DeactDC    = wcyto_DeactDC_Treg*sum(iTreg_LP)  + wcyto_DeactDC_Th2*cyto_Th2    + wcyto_DeactDC_M*Manti;
cyto_DamageEpi  = wcyto_DamageEpi_Th1*cyto_Th1      + wcyto_DamageEpi_Th17*cyto_Th17 + wcyto_DamageEpi_Th2*cyto_Th2 + wcyto_DamageEpi_Neut*Neut_LP + wcyto_DamageEpi_M*Mpro;
cyto_DamageTis  = wcyto_DamageTis_Th1*cyto_Th1      + wcyto_DamageTis_Th17*cyto_Th17 + wcyto_DamageTis_Th2*cyto_Th2 + wcyto_DamageTis_Neut*Neut_LP + wcyto_DamageTis_M*Mpro;
cyto_TisRemod   = wcyto_TisRemod_Th2*cyto_Th2       + wcyto_TisRemod_M*Manti;

% Specialised pro-resolving mediators (SPM)-producing cells
SPM_LP    	= apoNeut_LP*wSPMLPNeut + (Meffero_LP + sum(Mefferoa_LP) + Mefferoai_LP + Mefferoinf_LP)*wSPMLPMeffero;

% Phagocytosing cells
MPhago_LP 	=   (sum(MP1_LP) + sum(MP1a_LP) + sum(MP1ai_LP) + sum(MP1inf_LP))*wPhagoLPMP1...
              + (sum(MP2_LP) + sum(MP2a_LP) + sum(MP2ai_LP) + sum(MP2inf_LP))*wPhagoLPMP2...
              + (sum(MP3_LP) + sum(MP3a_LP) + sum(MP3ai_LP) + sum(MP3inf_LP))*wPhagoLPMP3...
              + (sum(MP4_LP) + sum(MP4a_LP) + sum(MP4ai_LP) + sum(MP4inf_LP))*wPhagoLPMP4...
              + (sum(Meffero_LP) + sum(Mefferoa_LP) + sum(Mefferoai_LP) + sum(Mefferoinf_LP))*wPhagoLPMP4; % phagocytosing macrophages in LP
Phago_LP    = MPhago_LP...
              + sum(qDC_LP)*wPhagoLPqDC + sum(rDC_LP)*wPhagoLPrDC...
              + sum(tDC_LP)*wPhagoLPtDC + sum(sDC_LP)*wPhagoLPsDC...
              + sum(Neut_LP)*wPhagoLPNeut;                                  % phagocytosing cells in LP

% Phagocytosis of bacteria
phagoElim  	= (VmaxPhago*Bact_LP)./(KmPhago./phagoRec+sum(Bact_LP));        % elimination of bacteria per phagocytic cell
phagoUptake = (VmaxPhago*Bact_LP)./(KmPhago./phagoRec+sum(Bact_LP));      	% antigen uptake per antigen-unexperienced cell

% No infection if absolute number of bacteria or infected cell type < 1
if Bact_LP(I.STm) < 1/VLP
    phagoUptake(I.STm) = 0;
end
if all([MP1inf_LP,MP2inf_LP,MP3inf_LP,MP4inf_LP,Mefferoinf_LP] < 1/VLP)
    pSTmInt = 0;
end

% Activation/deactivation of dendritic cells and macrophages
ActDC       = nuDCsMax*cyto_ActDC^HillProActDC/((1+cyto_DeactDC^HillAntiActDC)+cyto_ActDC^HillProActDC);   	% activation rate per DC (qDC/tDC)
nuMP12      = nuMP12ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP1 macrophage
nuMP23      = nuMP23ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP2 macrophage
nuMP34      = nuMP34ss*cyto_DeactM^HillAntiActM/((1+cyto_ActM^HillProActM)+cyto_DeactM^HillAntiActM);       % inactivation rate per MP3 macrophage

% Efferocytosis
nuMP1eff    = nuMphago*VmaxPhago*wPhagoLPMP1*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP2eff    = nuMphago*VmaxPhago*wPhagoLPMP2*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP3eff    = nuMphago*VmaxPhago*wPhagoLPMP3*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis
nuMP4eff    = nuMphago*VmaxPhago*wPhagoLPMP4*apoNeut_LP/(KmPhago+apoNeut_LP);   % efferocytosis

% Bacterial inflow from lumen to lamina propria
inflow      = epsilonBact1.*(1-mucus).*(1-epi) + epsilonBact2.*(1-mucus).*epi;

% Proliferating T cells
Tn2Treg_inflow          	= [(Tn_LN/Ttot_LN)*(BSantiAPC_LN/BSAPC_LN)*(alphaTn*beta/Tcontact)*contacts_LN, zeros(size(Tn2Treg_LN,1),size(Tn2Treg_LN,2)-1)];
Tn2Treg_egress             	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Treg_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Treg_LN,1),1]).*Tn2Treg_LN;
Tn2Treg_prol                = repmat([pTn1,repmat(pTni,[1,size(Tn2Treg_LN,2)-2]),0],[size(Tn2Treg_LN,1),1]).*Tn2Treg_LN;
Tn2Treg_death               = muTprol*suscApoLow*Tn2Treg_LN;
Tn2Th_inflow                = [(Tn_LN/Ttot_LN)*(BSproAPC_LN/BSAPC_LN)*(alphaTn*beta/Tcontact)*contacts_LN, zeros(size(Tn2Th1_LN,1),size(Tn2Th1_LN,2)-1)]; 
Tn2Th1_egress              	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th1_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th1_LN,1),1]).*Tn2Th1_LN;
Tn2Th1_prol               	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th1_LN,2)-2]),0],[size(Tn2Th1_LN,1),1]).*Tn2Th1_LN;
Tn2Th1_death               	= muTprol*Tn2Th1_LN;
Tn2Th2_egress              	= repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th2_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th2_LN,1),1]).*Tn2Th2_LN;
Tn2Th2_prol               	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th2_LN,2)-2]),0],[size(Tn2Th2_LN,1),1]).*Tn2Th2_LN;
Tn2Th2_death              	= muTprol*Tn2Th2_LN;
Tn2Th17_egress              = repmat([zeros(1,egressThreshold),muT_LN*(1+(0:size(Tn2Th17_LN,2)-egressThreshold-1)*egressPerDivision)],[size(Tn2Th17_LN,1),1]).*Tn2Th17_LN;
Tn2Th17_prol              	= repmat([pTn1,repmat(pTni,[1,size(Tn2Th17_LN,2)-2]),0],[size(Tn2Th17_LN,1),1]).*Tn2Th17_LN;
Tn2Th17_death              	= muTprol*Tn2Th17_LN;
Tcm2Temreg_inflow       	= [(Tcm_LN/Ttot_LN)*(BSantiAPC_LN/BSAPC_LN).*(alphaTm*beta/Tcontact)*contacts_LN, zeros(size(Tcm2Temreg_LN,1),size(Tcm2Temreg_LN,2)-1)];
Tcm2Temreg_egress           = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Temreg_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Temreg_LN,1),1]).*Tcm2Temreg_LN;
Tcm2Temreg_prol           	= repmat([repmat(pTni,[1,size(Tcm2Temreg_LN,2)-1]),0],[size(Tcm2Temreg_LN,1),1]).*Tcm2Temreg_LN;
Tcm2Temreg_death           	= muTprol*Tcm2Temreg_LN;
Tcm2Temh_inflow             = [(Tcm_LN/Ttot_LN)*(BSproAPC_LN/BSAPC_LN).*(alphaTm*beta/Tcontact)*contacts_LN, zeros(size(Tcm2Tem1_LN,1),size(Tcm2Tem1_LN,2)-1)];
Tcm2Tem1_egress             = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem1_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem1_LN,1),1]).*Tcm2Tem1_LN;
Tcm2Tem1_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem1_LN,2)-1]),0],[size(Tcm2Tem1_LN,1),1]).*Tcm2Tem1_LN;
Tcm2Tem1_death           	= muTprol*Tcm2Tem1_LN;
Tcm2Tem2_egress             = repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem2_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem2_LN,1),1]).*Tcm2Tem2_LN;
Tcm2Tem2_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem2_LN,2)-1]),0],[size(Tcm2Tem2_LN,1),1]).*Tcm2Tem2_LN;
Tcm2Tem2_death           	= muTprol*Tcm2Tem2_LN;
Tcm2Tem17_egress          	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tcm2Tem17_LN,2)-egressThresholdm-1)*egressPerDivision)],[size(Tcm2Tem17_LN,1),1]).*Tcm2Tem17_LN;
Tcm2Tem17_prol           	= repmat([repmat(pTni,[1,size(Tcm2Tem17_LN,2)-1]),0],[size(Tcm2Tem17_LN,1),1]).*Tcm2Tem17_LN;
Tcm2Tem17_death           	= muTprol*Tcm2Tem17_LN;
Tem2Treg_inflow             = [(Temreg_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Treg_LP,1),size(Tem2Treg_LP,2)-1)];
Tem2Treg_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Treg_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Treg_LP,1),1]).*Tem2Treg_LP;
Tem2Treg_prol              	= repmat([repmat(pTni,[1,size(Tem2Treg_LP,2)-1]),0],[size(Tem2Treg_LP,1),1]).*Tem2Treg_LP;
Tem2Treg_death            	= muTprol*Tem2Treg_LP;
Tem2Th1_inflow             	= [(Tem1_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th1_LP,1),size(Tem2Th1_LP,2)-1)];
Tem2Th1_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th1_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th1_LP,1),1]).*Tem2Th1_LP;
Tem2Th1_prol              	= repmat([repmat(pTni,[1,size(Tem2Th1_LP,2)-1]),0],[size(Tem2Th1_LP,1),1]).*Tem2Th1_LP;
Tem2Th1_death              	= muTprol*Tem2Th1_LP;
Tem2Th2_inflow             	= [(Tem2_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th2_LP,1),size(Tem2Th2_LP,2)-1)];
Tem2Th2_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th2_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th2_LP,1),1]).*Tem2Th2_LP;
Tem2Th2_prol              	= repmat([repmat(pTni,[1,size(Tem2Th2_LP,2)-1]),0],[size(Tem2Th2_LP,1),1]).*Tem2Th2_LP;
Tem2Th2_death              	= muTprol*Tem2Th2_LP;
Tem2Th17_inflow           	= [(Tem17_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(alphaTh*beta/Tcontact)*contacts_LP, zeros(size(Tem2Th17_LP,1),size(Tem2Th17_LP,2)-1)];
Tem2Th17_egress            	= repmat([zeros(1,egressThresholdm),muT_LN*(1+(0:size(Tem2Th17_LP,2)-egressThresholdm-1)*egressPerDivision)],[size(Tem2Th17_LP,1),1]).*Tem2Th17_LP;
Tem2Th17_prol              	= repmat([repmat(pTni,[1,size(Tem2Th17_LP,2)-1]),0],[size(Tem2Th17_LP,1),1]).*Tem2Th17_LP;
Tem2Th17_death            	= muTprol*Tem2Th17_LP;

%--------------------------------------------------------------------------
%% Rates
a           = zeros(model.nrOfRct,I.nrOfBact);

a(1,1)      = cRecDC;
a(2,1)      = muDC*qDC_LP;
a(3,1)      = muDC*rDC_LP;
a(4,:)      = muDC*tDC_LP;
a(5,:)      = muDC*sDC_LP;
a(6,1)      = ActDC*qDC_LP;
a(7,:)      = ActDC*tDC_LP;
a(8,:)      = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPqDC)*qDC_LP;
a(9,:)      = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPrDC)*rDC_LP;
a(10,:)     = epsilonDC*tDC_LP;
a(11,:)     = epsilonDC*sDC_LP;
a(12,:)     = muDC_LN*tDC_LN;
a(13,:)     = muDC_LN*sDC_LN;
a(14,1)     = lambdaT_LN*fractionTnCD4_bl;
a(15,1)     = muT_LN*Tn_LN;
a(16,1)     = lambdaT_LN*fractionTcmCD4_bl;
a(17,1)     = muT_LN*Tcm_LN;
a(18,:)     = muT_LP*Temreg_LP;
a(19,:)     = muT_LP*Tem1_LP;
a(20,:)     = muT_LP*Tem2_LP;
a(21,:)     = muT_LP*Tem17_LP;
a(22,:)     = muTeff*iTreg_LP;
a(23,:)     = muTeff*Th1_LP;
a(24,:)     = muTeff*Th2_LP;
a(25,:)     = muTeff*Th17_LP;
a(26,1)     = muEpi*ssEpi*min(tissue,1);
a(27,1)     = muEpi*epi*(1 + muEpiFac*cyto_DamageEpi/(1+cyto_DamageEpi)) + muEpiBact*sum(epsilonBact2.*(1-mucus).*epi.*Bact_Lu);
a(28,1)     = muTis*ssTis*(1 + muTisFac*cyto_TisRemod/(1+cyto_TisRemod));
a(29,1)     = muTis*tissue*(1 + muTisFac*cyto_DamageTis/(1+cyto_DamageTis));
a(30,:)     = muMucus*ssMucus*epi;
a(31,:)     = muMucus*mucus;
a(32,1)     = lambdaNutrients;
a(33,:)     = pBactLu.*Bact_Lu*nutrients;
a(34,:)     = muBactLu*Bact_Lu;
a(35,:)     = inflow.*Bact_Lu;
a(36,:)     = pBact.*Bact_LP*(1-sum(Bact_LP)/NmaxBact);
a(37,:)    	= phagoElim.*Phago_LP;
a(38,1)     = lambdaNeutMax*(cyto_RecNeut^HillRecNeut+wProLPBact*sum(Bact_LP))/((1+SPM_LP^HillRecNeut)+cyto_RecNeut^HillRecNeut+wProLPBact*sum(Bact_LP));
a(39,1)     = muNeutc*Neut_LP + muNeutPhago*sum(phagoElim)*Neut_LP + muNeutMax*Neut_LP*SPM_LP/((1+cyto_RecNeut)+SPM_LP);
a(40,1)     = VmaxPhago*apoNeut_LP/(KmPhago+apoNeut_LP)*MPhago_LP;
a(41,1)     = muAponeut*apoNeut_LP;
a(42,1)     = cRecM + lambdaMmax*cyto_RecM^HillRecM/((1+SPM_LP)+cyto_RecM^HillRecM);
a(43,1)     = muM*MP1_LP;
a(44,1)     = muM*MP2_LP;
a(45,1)     = muM*MP3_LP;
a(46,1)     = muM*MP4_LP;
a(47,1)     = muM*Meffero_LP;
a(48,1)     = nuMP12*MP1_LP;
a(49,1)     = nuMP23*MP2_LP;
a(50,1)     = nuMP34*MP3_LP;
a(51,1)     = nuMP1eff*MP1_LP;
a(52,1)     = nuMP2eff*MP2_LP;
a(53,1)     = nuMP3eff*MP3_LP;
a(54,1)     = nuMP4eff*MP4_LP;
a(55,:)     = muM*MP1a_LP;
a(56,:)     = muM*MP2a_LP;
a(57,:)     = muM*MP3a_LP;
a(58,:)     = muM*MP4a_LP;
a(59,:)     = muM*Mefferoa_LP;
a(60,:)     = (phagoMP1*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP1)*MP1_LP;
a(61,:)     = (phagoMP2*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP2)*MP2_LP;
a(62,:)     = (phagoMP3*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP3)*MP3_LP;
a(63,:)     = (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*MP4_LP;
a(64,:)     = (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*Meffero_LP;
a(65,:)     = nuMP12*MP1a_LP;
a(66,:)     = nuMP23*MP2a_LP;
a(67,:)     = nuMP34*MP3a_LP;
a(68,:)     = nuMP1eff*MP1a_LP;
a(69,:)     = nuMP2eff*MP2a_LP;
a(70,:)     = nuMP3eff*MP3a_LP;
a(71,:)     = nuMP4eff*MP4a_LP;
a(72,:)     = contacts_LP/bsPerDC*(iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(tDC_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(73,:)     = contacts_LP/bsPerDC*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(sDC_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(74,1)     = muDC*tDCi_LP;
a(75,1)     = muDC*sDCi_LP;
a(76,1)     = ActDC*tDCi_LP;
a(77,1)     = epsilonDC*tDCi_LP;
a(78,1)     = epsilonDC*sDCi_LP;
a(79,:)     = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPtDC)*tDCi_LP;
a(80,:)     = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPsDC)*sDCi_LP;
a(81,:)     = contacts_LN/bsPerDC*(iTreg_eff_LN/Ttot_LN).*(BSantiAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact);
a(82,:)     = contacts_LN/bsPerDC*(iTreg_eff_LN/Ttot_LN).*(BSproAPC_LN/BSAPC_LN).*(alphaTh*beta/Tcontact);
a(83,1)     = muDC_LN*tDCi_LN;
a(84,1)     = muDC_LN*sDCi_LN;
a(85,:)     = contacts_LP/bsPerM*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP1a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(86,:)     = contacts_LP/bsPerM*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP2a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(87,:)     = contacts_LP/bsPerM*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP3a_LP./BSproAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(88,:)     = contacts_LP/bsPerM*(iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*MP4a_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(89,:)     = contacts_LP/bsPerM*(iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(bsPerM/bsPerDC*Mefferoa_LP./BSantiAPC_LP_cells).*(alphaTh*beta/Tcontact);
a(90,1)     = muM*MP1ai_LP;
a(91,1)     = muM*MP2ai_LP;
a(92,1)     = muM*MP3ai_LP;
a(93,1)     = muM*MP4ai_LP;
a(94,1)     = muM*Mefferoai_LP;
a(95,1)     = nuMP12*MP1ai_LP;
a(96,1)     = nuMP23*MP2ai_LP;
a(97,1)     = nuMP34*MP3ai_LP;
a(98,1)     = nuMP1eff*MP1ai_LP;
a(99,1)     = nuMP2eff*MP2ai_LP;
a(100,1)    = nuMP3eff*MP3ai_LP;
a(101,1)    = nuMP4eff*MP4ai_LP;
a(102,:)    = (phagoMP1*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP1)*MP1ai_LP;
a(103,:) 	= (phagoMP2*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP2)*MP2ai_LP;
a(104,:)  	= (phagoMP3*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP3)*MP3ai_LP;
a(105,:)   	= (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*MP4ai_LP;
a(106,:)   	= (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*Mefferoai_LP;
% 107-133: Salmonella
a(134,1)    = (1-epi)*epsilonFCP*Neut_LP;
a(135,1)    = muFCP*FCP;

% Salmonella
if ismember('STm',I.bactName)
    a(107,:)    = (phagoMP1*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP1)*MP1a_LP;
    a(108,:) 	= (phagoMP2*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP2)*MP2a_LP;
    a(109,:)  	= (phagoMP3*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP3)*MP3a_LP;
    a(110,:)   	= (phagoMP4*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP4)*MP4a_LP;
    a(111,:)   	= (phagoMP4*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP4)*Mefferoa_LP;
    a(112,1)    = muM*MP1inf_LP;
    a(113,1)    = muM*MP2inf_LP;
    a(114,1)    = muM*MP3inf_LP;
    a(115,1)    = muM*MP4inf_LP;
    a(116,1)    = muM*Mefferoinf_LP;
    a(117,1)    = nuMP12*MP1inf_LP;
    a(118,1)    = nuMP23*MP2inf_LP;
    a(119,1)    = nuMP34*MP3inf_LP;
    a(120,1)    = nuMP1eff*MP1inf_LP;
    a(121,1)    = nuMP2eff*MP2inf_LP;
    a(122,1)    = nuMP3eff*MP3inf_LP;
    a(123,1)    = nuMP4eff*MP4inf_LP;
    a(124,1)    = Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP1inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    a(125,1)    = Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP2inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    a(126,1)    = Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP3inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    a(127,1)    = Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*MP4inf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    a(128,1)    = Th1_eff_LP(I.STm)/Ttot_LP * bsPerM/bsPerDC*Mefferoinf_LP/BSproAPC_LP_cells(I.STm) * BSproAPC_LP(I.STm)/BSAPC_LP * alphaTh(I.STm)*beta/Tcontact * contacts_LP;
    a(129,1)    = pSTmInt/(Nburst-1)*MP1inf_LP;
    a(130,1)    = pSTmInt/(Nburst-1)*MP2inf_LP;
    a(131,1)    = pSTmInt/(Nburst-1)*MP3inf_LP;
    a(132,1)    = pSTmInt/(Nburst-1)*MP4inf_LP;
    a(133,1)    = pSTmInt/(Nburst-1)*Mefferoinf_LP;
end


%--------------------------------------------------------------------------

if any(a((model.nrOfRctWoTransit_true+1):end,:))
    error('model.nrOfRctWoTransit_true not correctly specified.')
end

%--------------------------------------------------------------------------
%%% Uncomment for script IBD_CytokineWeights %%%
% x           = model.nrOfRctWoTransit_true;
% 
% a(x+2,:)  	= cyto_RecNeut;
% a(x+3,:)   	= wcyto_RecNeut_Th1*cyto_Th1;
% a(x+4,:) 	= wcyto_RecNeut_Th17*cyto_Th17;
% a(x+5,:)   	= wcyto_RecNeut_Neut*Neut_LP;
% a(x+6,:) 	= wcyto_RecNeut_M*Mpro;
% 
% a(x+7,:)  	= cyto_RecM;
% a(x+8,:)  	= wcyto_RecM_Th1*cyto_Th1;
% a(x+9,:)  	= wcyto_RecM_Th17*cyto_Th17;
% a(x+10,:) 	= wcyto_RecM_Neut*Neut_LP;
% a(x+11,:) 	= wcyto_RecM_M*Mpro;
% 
% a(x+12,:) 	= cyto_ActM;
% a(x+13,:) 	= wcyto_ActM_Th1*cyto_Th1;
% a(x+14,:) 	= wcyto_ActM_Th17*cyto_Th17;
% a(x+15,:)  	= wcyto_ActM_Neut*Neut_LP;
% a(x+16,:) 	= wcyto_ActM_M*Mpro;
% 
% a(x+17,:)  	= cyto_ActDC;
% a(x+18,:)  	= wcyto_ActDC_Th1*cyto_Th1;
% a(x+19,:) 	= wcyto_ActDC_Th17*cyto_Th17;
% a(x+20,:)  	= wcyto_ActDC_Neut*Neut_LP;
% a(x+21,:) 	= wcyto_ActDC_M*Mpro;
% 
% a(x+22,:)	= cyto_DeactM;
% a(x+23,:)  	= wcyto_DeactM_Treg*sum(iTreg_LP);
% a(x+24,:)  	= wcyto_DeactM_Th2*cyto_Th2;
% a(x+25,:) 	= wcyto_DeactM_M*Manti;
% 
% a(x+26,:) 	= cyto_DeactDC;
% a(x+27,:)  	= wcyto_DeactDC_Treg*sum(iTreg_LP);
% a(x+28,:)  	= wcyto_DeactDC_Th2*cyto_Th2;
% a(x+29,:)  	= wcyto_DeactDC_M*Manti;
% 
% a(x+30,:) 	= cyto_DamageEpi;
% a(x+31,:) 	= wcyto_DamageEpi_Th1*cyto_Th1;
% a(x+32,:)	= wcyto_DamageEpi_Th17*cyto_Th17;
% a(x+33,:)	= wcyto_DamageEpi_Th2*cyto_Th2;
% a(x+34,:)  	= wcyto_DamageEpi_Neut*Neut_LP;
% a(x+35,:) 	= wcyto_DamageEpi_M*Mpro;
% 
% a(x+36,:) 	= cyto_DamageTis;
% a(x+37,:) 	= wcyto_DamageTis_Th1*cyto_Th1;
% a(x+38,:)	= wcyto_DamageTis_Th17*cyto_Th17;
% a(x+39,:)	= wcyto_DamageTis_Th2*cyto_Th2;
% a(x+40,:)  	= wcyto_DamageTis_Neut*Neut_LP;
% a(x+41,:) 	= wcyto_DamageTis_M*Mpro;
% 
% a(x+42,:) 	= SPM_LP;
% a(x+43,:)  	= apoNeut_LP*wSPMLPNeut;
% a(x+44,:)  	= Meffero_LP*wSPMLPMeffero + sum(Mefferoa_LP)*wSPMLPMeffero;
% 
% a(x+45,:)   = cyto_TisRemod;
% a(x+46,:)   = wcyto_TisRemod_Th2*cyto_Th2;
% a(x+47,:)   = wcyto_TisRemod_M*Manti;
%%% end %%%

%--------------------------------------------------------------------------
% Transit compartments
mu = model.nrOfRctWoTransit+1;

% naive
a(mu:(mu+nTn-1),:)          = Tn2Treg_inflow';      mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Treg_egress';      mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Treg_prol';        mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Treg_death';       mu = mu+nTn;

a(mu:(mu+nTn-1),:)          = (Tn2Th_inflow.*repmat(fractionTh1,[1,size(Tn2Th1_LN,2)]))';  mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th1_egress';       mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th1_prol';         mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th1_death';        mu = mu+nTn;

a(mu:(mu+nTn-1),:)          = (Tn2Th_inflow.*repmat(fractionTh2,[1,size(Tn2Th2_LN,2)]))';  mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th2_egress';       mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th2_prol';         mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th2_death';        mu = mu+nTn;

a(mu:(mu+nTn-1),:)          = (Tn2Th_inflow.*repmat(fractionTh17,[1,size(Tn2Th17_LN,2)]))';	mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th17_egress';      mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th17_prol';        mu = mu+nTn;
a(mu:(mu+nTn-1),:)          = Tn2Th17_death';       mu = mu+nTn;

% central memory
a(mu:(mu+nTm-1),:)          = Tcm2Temreg_inflow';	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Temreg_egress'; 	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Temreg_prol';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Temreg_death';   	mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = (Tcm2Temh_inflow.*repmat(fractionTh1,[1,size(Tcm2Tem1_LN,2)]))';     mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem1_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem1_prol';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem1_death';   	mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = (Tcm2Temh_inflow.*repmat(fractionTh2,[1,size(Tcm2Tem2_LN,2)]))';     mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem2_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem2_prol';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem2_death';   	mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = (Tcm2Temh_inflow.*repmat(fractionTh17,[1,size(Tcm2Tem17_LN,2)]))';   mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem17_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem17_prol';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tcm2Tem17_death';   	mu = mu+nTm;

% effector memory
a(mu:(mu+nTm-1),:)          = Tem2Treg_inflow';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Treg_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Treg_prol';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Treg_death';   	mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = Tem2Th1_inflow';     	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th1_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th1_prol';       	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th1_death';     	mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = Tem2Th2_inflow';     	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th2_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th2_prol';       	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th2_death';       mu = mu+nTm;

a(mu:(mu+nTm-1),:)          = Tem2Th17_inflow';    	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th17_egress';   	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th17_prol';      	mu = mu+nTm;
a(mu:(mu+nTm-1),:)          = Tem2Th17_death';   	mu = mu+nTm;

%--------------------------------------------------------------------------

% if any(isnan(a))
%     table(I.stateName(1:length(X))',X)
%     error('NaN in reaction rates!')
% end
% 
% if any(isnan(X))
%     table(I.stateName(1:length(X))',X)
%     error('NaN in state variables!')
% end

a(a<0)  = 0;
a = reshape(a,[],1);                % columnwise ordering preserved --> [a(:,1);a(:,2)]

%--------------------------------------------------------------------------

end