function [ssData,model] = IBD_steadyStateData(aux,model)
%==========================================================================
% [ssData,model] = IBD_steadyStateData(aux,model)
%==========================================================================
% Steady state data for comparison to simularion results/parameter
% estimation
%--------------------------------------------------------------------------
%-- input
% aux:          auxiliary parameter vector
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% ss:           steady state data for all species and sums of species
%==========================================================================

I       = model.I;
auxI    = model.I.aux;

%--------------------------------------------------------------------------
ssData = nan(1,I.nrOfStatesAdd);

ssData(I.Tn_LN)      	= aux(auxI.concTn_LN);          % naive CD4+ T cells
ssData(I.DC_tot_LP)   	= aux(auxI.concDC_LP);         	% total dendritic cells
ssData(I.M_tot_LP)      = aux(auxI.concM_LP);           % total macrophages
M_data = [0.0120 0.0072 0.0224 0.1584];                 % [Bain2013]
ssData(I.MP1_tot_LP)    = ssData(I.M_tot_LP)*M_data(1)/sum(M_data);     % P1 macrophages
ssData(I.MP2_tot_LP)    = ssData(I.M_tot_LP)*M_data(2)/sum(M_data);     % P2 macrophages
ssData(I.MP3_tot_LP)    = ssData(I.M_tot_LP)*M_data(3)/sum(M_data);     % P3 macrophages
ssData(I.MP4_tot_LP)    = ssData(I.M_tot_LP)*M_data(4)/sum(M_data);     % P4 macrophages
ssData(I.iTreg_eff_LN)	= aux(auxI.concITreg_LN);      	% induced regulatory T cells
ssData(I.iTreg_eff_LP)  = aux(auxI.concITreg_LP);      	% induced regulatory T cells
ssData(I.Tcm_LN)        = aux(auxI.concTcm_LN);        	% (central) memory T cells
ssData(I.Tm_tot_LP)     = aux(auxI.concTem_LP);         % (effector) memory T cells
ssData(I.Bact_LP(I.commensal)) = aux(auxI.concBact_LP); % [1/mL] [Swidsinski 2010]: total anaerobe count in sigmoid colon
ssData(I.Bact_LP(setdiff(I.allBact,I.commensal))) = 0;
ssData(I.Neut_LP)       = aux(auxI.concNeut_LP);        % neutrophils

%--------------------------------------------------------------------------

end