function ssTable = IBD_steadyStateTable(X,model,ssData)
%==========================================================================
% ss_table = IBD_steadyStateTable(X,model,ssData)
%==========================================================================
% Summarise steady state values in table
%--------------------------------------------------------------------------
%-- input
% X         simulation results
% model     model struct
% ssData: 	steady state data for all species and sums of species
%--------------------------------------------------------------------------
%-- output
% ssTable   table of steady state (simulation vs literature)
%==========================================================================

fprintf('Generating table of steady state values...\n');
I = model.I;

%--------------------------------------------------------------------------

allStates = [model.stateNames,model.addStateNames];

% Steady state concentrations
ssTable = array2table(zeros(length(allStates),2));       	% empty table
ssTable.Properties.RowNames = allStates;
ssTable.Properties.VariableNames = {'simulation','literature'};
for i = 1:length(allStates)
    S                       = allStates{i};
    ssTable.simulation(i) 	= sum(X(end,reshape(I.(S),[1,size(I.(S),1)*size(I.(S),2)])));
 	ssTable.literature(i)   = sum(ssData(reshape(I.(S),[1,size(I.(S),1)*size(I.(S),2)])));
end
ssTable.relativeToLiterature 	= ssTable.simulation./ssTable.literature;

%--------------------------------------------------------------------------

end

