function nu = IBD_stochMatrix(model)
%==========================================================================
% nu = IBD_stochMatrix(par,model)
%==========================================================================
% Stoichiometric matrix
%--------------------------------------------------------------------------
%-- input
% par:          parameters
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% nu:           stochiometric matrix
%==========================================================================

I           = model.I;
nrOfRct     = model.nrOfRct;
nrOfBact    = model.I.nrOfBact;

%--------------------------------------------------------------------------
nu = zeros(model.I.nrOfStates,nrOfRct*nrOfBact);

% a(1,1)      = cRecDC + lambdaDCmax*PRO_LP^HillRecDC/(KmRecDC^HillRecDC*(1+SPM_LP/KmSPMNeut)+PRO_LP^HillRecDC);
mu = 1;
nu(I.qDC_LP,mu)                             = +1;

% a(2,1)      = muDC*qDC_LP;
mu = 2;
nu(I.qDC_LP,mu)                             = -1; 

% a(3,1)      = muDC*rDC_LP;
mu = 3;
nu(I.rDC_LP,mu)                             = -1;

% a(4,:)      = muDC*tDC_LP;
mu = 4;
for i = 1:nrOfBact
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(5,:)      = muDC*sDC_LP;
mu = 5;
for i = 1:nrOfBact
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(6,1)      = ActDC*qDC_LP;
mu = 6;
nu(I.qDC_LP,mu)                             = -1;
nu(I.rDC_LP,mu)                             = +1;

% a(7,:)      = ActDC*tDC_LP;
mu = 7;
for i = 1:nrOfBact
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)        = +1;
end

% a(8,:)      = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPqDC)*qDC_LP;
mu = 8;
for i = 1:nrOfBact
    nu(I.qDC_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)        = +1;
end

% a(9,:)      = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPrDC)*rDC_LP;
mu = 9;
for i = 1:nrOfBact
    nu(I.rDC_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)        = +1;
end

% a(10,:)     = epsilonDC*tDC_LP;
mu = 10;
for i = 1:nrOfBact
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
    nu(I.tDC_LN(i),mu+(i-1)*nrOfRct)        = +1*model.par(model.I.VLP)/model.par(model.I.VLN);
end

% a(11,:)     = epsilonDC*sDC_LP;
mu = 11;
for i = 1:nrOfBact
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
    nu(I.sDC_LN(i),mu+(i-1)*nrOfRct)        = +1*model.par(model.I.VLP)/model.par(model.I.VLN);
end

% a(12,:)     = muDC*tDC_LN;
mu = 12;
for i = 1:nrOfBact
    nu(I.tDC_LN(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(13,:)     = muDC*sDC_LN;
mu = 13;
for i = 1:nrOfBact
    nu(I.sDC_LN(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(14,1)     = lambdaT_LN*fractionTnCD4_bl;
mu = 14;
nu(I.Tn_LN,mu)                              = +1;

% a(15,1)     = muT_LN*Tn_LN;
mu = 15;
nu(I.Tn_LN,mu)                              = -1;

% a(16,1)     = lambdaT_LN*fractionTcmCD4_bl;
mu = 16;
nu(I.Tcm_LN,mu)                             = +1;

% a(17,1)     = muT_LN*Tcm_LN;
mu = 17;
nu(I.Tcm_LN,mu)                             = -1;

% a(18,:)     = muT_LP*Temreg_LP;
mu = 18;
for i = 1:nrOfBact
    nu(I.Temreg_LP(i),mu+(i-1)*nrOfRct)     = -1;
end

% a(19,:)     = muT_LP*Tem1_LP;
mu = 19;
for i = 1:nrOfBact
    nu(I.Tem1_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(20,:)     = muT_LP*Tem2_LP;
mu = 20;
for i = 1:nrOfBact
    nu(I.Tem2_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(21,:)     = muT_LP*Tem17_LP;
mu = 21;
for i = 1:nrOfBact
    nu(I.Tem17_LP(i),mu+(i-1)*nrOfRct)      = -1;
end

% a(22,:)     = muTeff*iTreg_LP;
mu = 22;
for i = 1:nrOfBact
    nu(I.iTreg_LP(i),mu+(i-1)*nrOfRct)      = -1;
end

% a(23,:)     = muTeff*Th1_LP;
mu = 23;
for i = 1:nrOfBact
    nu(I.Th1_LP(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(24,:)     = muTeff*Th2_LP;
mu = 24;
for i = 1:nrOfBact
    nu(I.Th2_LP(i),mu+(i-1)*nrOfRct)        = -1;
end

% a(25,:)     = muTeff*Th17_LP;
mu = 25;
for i = 1:nrOfBact
    nu(I.Th17_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(26,1)     = muEpi*ssEpi*tissue;
mu = 26;
nu(I.epi,mu)                                = +1;

% a(27,1)     = muEpi*epi + muEpiBact*sum(epsilonBact2.*(1-mucus).*epi.*Bact_Lu);% + muEpiPro*cyto_DamageEpi*epi;     % USE MM EQUATION
mu = 27;
nu(I.epi,mu)                                = -1;

% a(28,1)     = muTissue*ssTissue;
mu = 28;
nu(I.tissue,mu)                             = +1;

% a(29,1)     = muTissue*tissue;% +muTissuePro*cyto_DamageTissue*tissue
mu = 29;
nu(I.tissue,mu)                             = -1;

% a(30,:)     = muMucus*ssMucus*epi;
mu = 30;
nu(I.mucus,mu)                              = +1;

% a(31,:)     = muMucus*mucus;
mu = 31;
nu(I.mucus,mu)                              = -1;

% a(32,1)     = lambdaNutrients;
mu = 32;
nu(I.nutrients,mu)                          = +1;

% a(33,:)     = pBactLu.*Bact_Lu*nutrients;
mu = 33;
for i = 1:nrOfBact
    nu(I.Bact_Lu(i),mu+(i-1)*nrOfRct)       = +1;
    nu(I.nutrients,mu+(i-1)*nrOfRct)        = -1;
end

% a(34,:)     = muBactLu*Bact_Lu;
mu = 34;
for i = 1:nrOfBact
    nu(I.Bact_Lu(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(35,:)     = inflow.*Bact_Lu;
mu = 35;
for i = 1:nrOfBact
    nu(I.Bact_LP(i),mu+(i-1)*nrOfRct)       = +1;
end

% a(36,:)     = pBact.*Bact_LP*(1-sum(Bact_LP)/NmaxBact);
mu = 36;
for i = 1:nrOfBact
    nu(I.Bact_LP(i),mu+(i-1)*nrOfRct)       = +1;
end

% a(37,:)    	= phagoElim.*Phago_LP;
mu = 37;
for i = 1:nrOfBact
    nu(I.Bact_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(38,1)     = lambdaNeutMax*(PRO_LP/10+wProLPBact*sum(Bact_LP))^HillRecNeut/(KmRecNeut^HillRecNeut*(1+SPM_LP/KmSPMNeut)+(PRO_LP+wProLPBact*sum(Bact_LP))^HillRecNeut);
mu = 38;
nu(I.Neut_LP,mu)                            = +1;

% a(39,1)     = muNeutc*Neut_LP + muNeutPhago*sum(phagoElim)*Neut_LP + muNeutMax*Neut_LP*SPM_LP/(KmSPMNeut*(1+PRO_LP/KmApoNeut)+SPM_LP);
mu = 39;
nu(I.Neut_LP,mu)                           	= -1;
nu(I.apoNeut_LP,mu)                         = +1;

% a(40,1)     = VmaxPhago*apoNeut_LP/(KmPhago+apoNeut_LP)*MPhago_LP;
mu = 40;
nu(I.apoNeut_LP,mu)                         = -1;

% a(41,1)     = muAponeut*apoNeut_LP;
mu = 41;
nu(I.apoNeut_LP,mu)                         = -1;

% a(42,1)     = cRecM + lambdaMmax*cyto_RecM^HillRecM/((1+SPM_LP)+cyto_RecM^HillRecM);
mu = 42;
nu(I.MP1_LP,mu)                             = +1;

% a(43,1)     = muM*MP1_LP;
mu = 43;
nu(I.MP1_LP,mu)                             = -1;

% a(44,1)     = muM*MP2_LP;
mu = 44;
nu(I.MP2_LP,mu)                             = -1;

% a(45,1)     = muM*MP3_LP;
mu = 45;
nu(I.MP3_LP,mu)                             = -1;

% a(46,1)     = muM*MP4_LP;
mu = 46;
nu(I.MP4_LP,mu)                             = -1;

% a(47,1)     = muM*Meffero_LP;
mu = 47;
nu(I.Meffero_LP,mu)                         = -1;

% a(48,1)     = nuMP12*MP1_LP;
mu = 48;
nu(I.MP1_LP,mu)                             = -1;
nu(I.MP2_LP,mu)                             = +1;

% a(49,1)     = nuMP23*MP2_LP;
mu = 49;
nu(I.MP2_LP,mu)                             = -1;
nu(I.MP3_LP,mu)                             = +1;

% a(50,1)     = nuMP34*MP3_LP;
mu = 50;
nu(I.MP3_LP,mu)                             = -1;
nu(I.MP4_LP,mu)                             = +1;

% a(51,1)     = nuMP1eff*MP1_LP;
mu = 51;
nu(I.MP1_LP,mu)                             = -1;
nu(I.Meffero_LP,mu)                         = +1;

% a(52,1)     = nuMP2eff*MP2_LP;
mu = 52;
nu(I.MP2_LP,mu)                             = -1;
nu(I.Meffero_LP,mu)                         = +1;

% a(53,1)     = nuMP3eff*MP3_LP;
mu = 53;
nu(I.MP3_LP,mu)                             = -1;
nu(I.Meffero_LP,mu)                         = +1;

% a(54,1)     = nuMP4eff*MP4_LP;
mu = 54;
nu(I.MP4_LP,mu)                             = -1;
nu(I.Meffero_LP,mu)                         = +1;

% a(55,:)     = muM*MP1a_LP;
mu = 55;
for i = 1:nrOfBact
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(56,:)     = muM*MP2a_LP;
mu = 56;
for i = 1:nrOfBact
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(57,:)     = muM*MP3a_LP;
mu = 57;
for i = 1:nrOfBact
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(58,:)     = muM*MP4a_LP;
mu = 58;
for i = 1:nrOfBact
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)       = -1;
end

% a(59,:)     = muM*Mefferoa_LP;
mu = 59;
for i = 1:nrOfBact
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct)	= -1;
end

% a(60,:)     = (phagoMP1*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP1)*MP1_LP;
mu = 60;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP1_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP1_LP,mu+(i-1)*nrOfRct)               = -1;
nu(I.MP1inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(61,:)     = (phagoMP2*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP2)*MP2_LP;
mu = 61;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP2_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP2_LP,mu+(i-1)*nrOfRct)               = -1;
nu(I.MP2inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(62,:)     = (phagoMP3*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP3)*MP3_LP;
mu = 62;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP3_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP3_LP,mu+(i-1)*nrOfRct)               = -1;
nu(I.MP3inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(63,:)     = (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*MP4_LP;
mu = 63;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP4_LP,mu+(i-1)*nrOfRct)           = -1;
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP4_LP,mu+(i-1)*nrOfRct)               = -1;
nu(I.MP4inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(64,:)     = (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4)*Meffero_LP;
mu = 64;
for i = setdiff(I.allBact,I.STm)
    nu(I.Meffero_LP,mu+(i-1)*nrOfRct)       = -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct)	= +1;
end
i = I.STm;
nu(I.Meffero_LP,mu+(i-1)*nrOfRct)       	= -1;
nu(I.Mefferoinf_LP,mu+(i-1)*nrOfRct)        = +1;

% a(65,:)     = nuMP12*MP1a_LP;
mu = 65;
for i = 1:nrOfBact
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end

% a(66,:)     = nuMP23*MP2a_LP;
mu = 66;
for i = 1:nrOfBact
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end

% a(67,:)     = nuMP34*MP3a_LP;
mu = 67;
for i = 1:nrOfBact
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end

% a(68,:)     = nuMP1eff*MP1a_LP;
mu = 68;
for i = 1:nrOfBact
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct)  	= +1;
end

% a(69,:)     = nuMP2eff*MP2a_LP;
mu = 69;
for i = 1:nrOfBact
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct) 	= +1;
end

% a(70,:)     = nuMP3eff*MP3a_LP;
mu = 70;
for i = 1:nrOfBact
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct) 	= +1;
end

% a(71,:)     = nuMP4eff*MP4a_LP;
mu = 71;
for i = 1:nrOfBact
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)       = -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct)  	= +1;
end

% a(72,:)     = contacts_LP/bsPerDC*iTreg_eff_LP/Ttot_LP.*BSantiAPC_LP/BSAPC_LP.*tDC_LP./BSantiAPC_LP_cells.*alphaTh*beta/Tcontact;
mu = 72;
for i = 1:nrOfBact
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
    nu(I.tDCi_LP,mu+(i-1)*nrOfRct)          = +1;
end

% a(73,:)     = contacts_LP/bsPerDC*iTreg_eff_LP/Ttot_LP.*BSproAPC_LP/BSAPC_LP.*sDC_LP./BSproAPC_LP_cells.*alphaTh*beta/Tcontact;
mu = 73;
for i = 1:nrOfBact
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)        = -1;
    nu(I.sDCi_LP,mu+(i-1)*nrOfRct)          = +1;
end

% a(74,1)     = muDC*tDCi_LP;
mu = 74;
nu(I.tDCi_LP,mu)                            = -1;

% a(75,1)     = muDC*sDCi_LP;
mu = 75;
nu(I.sDCi_LP,mu)                            = -1;

% a(76,1)     = ActDC*tDCi_LP;
mu = 76;
nu(I.tDCi_LP,mu)                            = -1;
nu(I.sDCi_LP,mu)                            = +1;

% a(77,1)     = epsilonDC*tDCi_LP;
mu = 77;
nu(I.tDCi_LP,mu)                            = -1;
nu(I.tDCi_LN,mu)                            = +1*model.par(model.I.VLP)/model.par(model.I.VLN);

% a(78,1)     = epsilonDC*sDCi_LP;
mu = 78;
nu(I.sDCi_LP,mu)                            = -1;
nu(I.sDCi_LN,mu)                            = +1*model.par(model.I.VLP)/model.par(model.I.VLN);

% a(79,:)     = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPtDC)*tDCi_LP;
mu = 79;
for i = 1:nrOfBact
    nu(I.tDCi_LP,mu+(i-1)*nrOfRct)          = -1;
    nu(I.tDC_LP(i),mu+(i-1)*nrOfRct)     	= +1;
end

% a(80,:)     = (nuDCa*Bact_Lu + phagoUptake*wPhagoLPsDC)*sDCi_LP;
mu = 80;
for i = 1:nrOfBact
    nu(I.sDCi_LP,mu+(i-1)*nrOfRct)          = -1;
    nu(I.sDC_LP(i),mu+(i-1)*nrOfRct)     	= +1;
end

% a(81,:)     = contacts_LN/bsPerDC*iTreg_eff_LN/Ttot_LN.*BSantiAPC_LN/BSAPC_LN.*alphaTh*beta/Tcontact;
mu = 81;
for i = 1:nrOfBact
    nu(I.tDC_LN(i),mu+(i-1)*nrOfRct)      	= -1;
    nu(I.tDCi_LN,mu+(i-1)*nrOfRct)          = +1;
end

% a(82,:)     = contacts_LN/bsPerDC*iTreg_eff_LN/Ttot_LN.*BSproAPC_LN/BSAPC_LN.*alphaTh*beta/Tcontact;
mu = 82;
for i = 1:nrOfBact
    nu(I.sDC_LN(i),mu+(i-1)*nrOfRct)      	= -1;
    nu(I.sDCi_LN,mu+(i-1)*nrOfRct)          = +1;
end

% a(83,1)     = muDC_LN*tDCi_LN;
mu = 83;
nu(I.tDCi_LN,mu)                         	= -1;

% a(84,1)     = muDC_LN*sDCi_LN;
mu = 84;
nu(I.sDCi_LN,mu)                        	= -1;

% a(85,:)     = contacts_LP/(bsPerDC*kTM_LP/kTDC_LP)*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(kTM_LP/kTDC_LP*MP1a_LP./BSproAPC_LP_cell).*(alphaTh*beta/Tcontact);
mu = 85;
for i = 1:nrOfBact
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)    	= -1;
    nu(I.MP1ai_LP,mu+(i-1)*nrOfRct)     	= +1;
end

% a(86,:)     = contacts_LP/(bsPerDC*kTM_LP/kTDC_LP)*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(kTM_LP/kTDC_LP*MP2a_LP./BSproAPC_LP_cell).*(alphaTh*beta/Tcontact);
mu = 86;
for i = 1:nrOfBact
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)    	= -1;
    nu(I.MP2ai_LP,mu+(i-1)*nrOfRct)     	= +1;
end

% a(87,:)     = contacts_LP/(bsPerDC*kTM_LP/kTDC_LP)*(iTreg_eff_LP/Ttot_LP).*(BSproAPC_LP/BSAPC_LP).*(kTM_LP/kTDC_LP*MP3a_LP./BSproAPC_LP_cell).*(alphaTh*beta/Tcontact);
mu = 87;
for i = 1:nrOfBact
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)    	= -1;
    nu(I.MP3ai_LP,mu+(i-1)*nrOfRct)     	= +1;
end

% a(88,:)     = contacts_LP/(bsPerDC*kTM_LP/kTDC_LP)*(iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(kTM_LP/kTDC_LP*MP4a_LP./BSantiAPC_LP_cell).*(alphaTh*beta/Tcontact);
mu = 88;
for i = 1:nrOfBact
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)    	= -1;
    nu(I.MP4ai_LP,mu+(i-1)*nrOfRct)     	= +1;
end

% a(89,:)     = contacts_LP/(bsPerDC*kTM_LP/kTDC_LP)*(iTreg_eff_LP/Ttot_LP).*(BSantiAPC_LP/BSAPC_LP).*(kTM_LP/kTDC_LP*Mefferoa_LP./BSantiAPC_LP_cell).*(alphaTh*beta/Tcontact);
mu = 89;
for i = 1:nrOfBact
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct) 	= -1;
    nu(I.Mefferoai_LP,mu+(i-1)*nrOfRct)  	= +1;
end

% a(90,1)     = muM*MP1ai_LP;
mu = 90;
nu(I.MP1ai_LP,mu)                        	= -1;

% a(91,1)     = muM*MP2ai_LP;
mu = 91;
nu(I.MP2ai_LP,mu)                        	= -1;

% a(92,1)     = muM*MP3ai_LP;
mu = 92;
nu(I.MP3ai_LP,mu)                        	= -1;

% a(93,1)     = muM*MP4ai_LP;
mu = 93;
nu(I.MP4ai_LP,mu)                        	= -1;

% a(94,1)     = muM*Mefferoai_LP;
mu = 94;
nu(I.Mefferoai_LP,mu)                   	= -1;

% a(95,1)     = nuMP12*MP1ai_LP;
mu = 95;
nu(I.MP1ai_LP,mu)                        	= -1;
nu(I.MP2ai_LP,mu)                           = +1;

% a(96,1)     = nuMP23*MP2ai_LP;
mu = 96;
nu(I.MP2ai_LP,mu)                        	= -1;
nu(I.MP3ai_LP,mu)                           = +1;

% a(97,1)     = nuMP34*MP3ai_LP;
mu = 97;
nu(I.MP3ai_LP,mu)                        	= -1;
nu(I.MP4ai_LP,mu)                           = +1;

% a(98,1)     = nuMP1eff*MP1ai_LP;
mu = 98;
nu(I.MP1ai_LP,mu)                        	= -1;
nu(I.Mefferoai_LP,mu)                    	= +1;

% a(99,1)     = nuMP2eff*MP2ai_LP;
mu = 99;
nu(I.MP2ai_LP,mu)                        	= -1;
nu(I.Mefferoai_LP,mu)                    	= +1;

% a(100,1)    = nuMP3eff*MP3ai_LP;
mu = 100;
nu(I.MP3ai_LP,mu)                        	= -1;
nu(I.Mefferoai_LP,mu)                    	= +1;

% a(101,1)    = nuMP4eff*MP4ai_LP;
mu = 101;
nu(I.MP4ai_LP,mu)                        	= -1;
nu(I.Mefferoai_LP,mu)                    	= +1;

% a(102,:)    = (phagoMP1*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP1a)*MP1ai_LP;
mu = 102;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP1ai_LP,mu+(i-1)*nrOfRct)         = -1;
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP1ai_LP,mu+(i-1)*nrOfRct)           	= -1;
nu(I.MP1inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(103,:) 	= (phagoMP2*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP2a)*MP2ai_LP;
mu = 103;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP2ai_LP,mu+(i-1)*nrOfRct)         = -1;
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP2ai_LP,mu+(i-1)*nrOfRct)           	= -1;
nu(I.MP2inf_LP,mu+(i-1)*nrOfRct)            = +1;


% a(104,:)  	= (phagoMP3*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP3a)*MP3ai_LP;
mu = 104;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP3ai_LP,mu+(i-1)*nrOfRct)         = -1;
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP3ai_LP,mu+(i-1)*nrOfRct)           	= -1;
nu(I.MP3inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(105,:)   	= (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4a)*MP4ai_LP;
mu = 105;
for i = setdiff(I.allBact,I.STm)
    nu(I.MP4ai_LP,mu+(i-1)*nrOfRct)         = -1;
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)       = +1;
end
i = I.STm;
nu(I.MP4ai_LP,mu+(i-1)*nrOfRct)           	= -1;
nu(I.MP4inf_LP,mu+(i-1)*nrOfRct)            = +1;

% a(106,:)   	= (phagoMP4*nuDCa*Bact_Lu + phagoUptake*wPhagoLPMP4a)*Mefferoai_LP;
mu = 106;
for i = setdiff(I.allBact,I.STm)
    nu(I.Mefferoai_LP,mu+(i-1)*nrOfRct)   	= -1;
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct)	= +1;
end
i = I.STm;
nu(I.Mefferoai_LP,mu+(i-1)*nrOfRct)        	= -1;
nu(I.Mefferoinf_LP,mu+(i-1)*nrOfRct)      	= +1;

% a(107,:)    = (phagoMP1*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP1)*MP1a_LP;
mu = 107;
for i = 1:nrOfBact
    nu(I.MP1a_LP(i),mu+(i-1)*nrOfRct)   	= -1;
    nu(I.MP1inf_LP,mu+(i-1)*nrOfRct)        = +1;
end

% a(108,:) 	= (phagoMP2*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP2)*MP2a_LP;
mu = 108;
for i = 1:nrOfBact
    nu(I.MP2a_LP(i),mu+(i-1)*nrOfRct)   	= -1;
    nu(I.MP2inf_LP,mu+(i-1)*nrOfRct)        = +1;
end

% a(109,:)  	= (phagoMP3*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP3)*MP3a_LP;
mu = 109;
for i = 1:nrOfBact
    nu(I.MP3a_LP(i),mu+(i-1)*nrOfRct)   	= -1;
    nu(I.MP3inf_LP,mu+(i-1)*nrOfRct)        = +1;
end

% a(110,:)   	= (phagoMP4*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP4)*MP4a_LP;
mu = 110;
for i = 1:nrOfBact
    nu(I.MP4a_LP(i),mu+(i-1)*nrOfRct)   	= -1;
    nu(I.MP4inf_LP,mu+(i-1)*nrOfRct)        = +1;
end

% a(111,:)   	= (phagoMP4*nuDCa*Bact_Lu(I.STm) + phagoUptake(I.STm)*wPhagoLPMP4)*Mefferoa_LP;
mu = 111;
for i = 1:nrOfBact
    nu(I.Mefferoa_LP(i),mu+(i-1)*nrOfRct) 	= -1;
    nu(I.Mefferoinf_LP,mu+(i-1)*nrOfRct)   	= +1;
end

% a(112,1)    = muM*MP1inf_LP;
mu = 112;
nu(I.MP1inf_LP,mu)                          = -1;

% a(113,1)    = muM*MP2inf_LP;
mu = 113;
nu(I.MP2inf_LP,mu)                          = -1;

% a(114,1)    = muM*MP3inf_LP;
mu = 114;
nu(I.MP3inf_LP,mu)                          = -1;

% a(115,1)    = muM*MP4inf_LP;
mu = 115;
nu(I.MP4inf_LP,mu)                          = -1;

% a(116,1)    = muM*Mefferoinf_LP;
mu = 116;
nu(I.Mefferoinf_LP,mu)                   	= -1;

% a(117,1)    = nuMP12*MP1inf_LP;
mu = 117;
nu(I.MP1inf_LP,mu)                          = -1;
nu(I.MP2inf_LP,mu)                          = +1;

% a(118,1)    = nuMP23*MP2inf_LP;
mu = 118;
nu(I.MP2inf_LP,mu)                          = -1;
nu(I.MP3inf_LP,mu)                          = +1;

% a(119,1)    = nuMP34*MP3inf_LP;
mu = 119;
nu(I.MP3inf_LP,mu)                          = -1;
nu(I.MP4inf_LP,mu)                          = +1;

% a(120,1)    = nuMP1eff*MP1inf_LP;
mu = 120;
nu(I.MP1inf_LP,mu)                          = -1;
nu(I.Mefferoinf_LP,mu)                   	= +1;

% a(121,1)    = nuMP2eff*MP2inf_LP;
mu = 121;
nu(I.MP2inf_LP,mu)                          = -1;
nu(I.Mefferoinf_LP,mu)                   	= +1;

% a(122,1)    = nuMP3eff*MP3inf_LP;
mu = 122;
nu(I.MP3inf_LP,mu)                          = -1;
nu(I.Mefferoinf_LP,mu)                   	= +1;

% a(123,1)    = nuMP4eff*MP4inf_LP;
mu = 123;
nu(I.MP4inf_LP,mu)                          = -1;
nu(I.Mefferoinf_LP,mu)                   	= +1;

% a(124,1)    = kTM_LP*Th1_eff_LP(I.STm)*MP1inf_LP;
mu = 124;
nu(I.MP1inf_LP,mu)                          = -1;
nu(I.MP1a_LP(I.STm),mu)                   	= +1;

% a(125,1)    = kTM_LP*Th1_eff_LP(I.STm)*MP2inf_LP;
mu = 125;
nu(I.MP2inf_LP,mu)                          = -1;
nu(I.MP2a_LP(I.STm),mu)                   	= +1;

% a(126,1)    = kTM_LP*Th1_eff_LP(I.STm)*MP3inf_LP;
mu = 126;
nu(I.MP3inf_LP,mu)                          = -1;
nu(I.MP3a_LP(I.STm),mu)                   	= +1;

% a(127,1)    = kTM_LP*Th1_eff_LP(I.STm)*MP4inf_LP;
mu = 127;
nu(I.MP4inf_LP,mu)                          = -1;
nu(I.MP4a_LP(I.STm),mu)                     = +1;

% a(128,1)    = kTM_LP*Th1_eff_LP(I.STm)*Mefferoinf_LP;
mu = 128;
nu(I.Mefferoinf_LP,mu)                  	= -1;
nu(I.Mefferoa_LP(I.STm),mu)               	= +1;

% a(129,1)    = pSTmInt/(Nburst-1)*MP1inf_LP;
mu = 129;
nu(I.MP1inf_LP,mu)                          = -1;
nu(I.Bact_LP(I.STm),mu)                     = +model.par(model.I.Nburst);

% a(130,1)    = pSTmInt/(Nburst-1)*MP2inf_LP;
mu = 130;
nu(I.MP2inf_LP,mu)                          = -1;
nu(I.Bact_LP(I.STm),mu)                     = +model.par(model.I.Nburst);

% a(131,1)    = pSTmInt/(Nburst-1)*MP3inf_LP;
mu = 131;
nu(I.MP3inf_LP,mu)                          = -1;
nu(I.Bact_LP(I.STm),mu)                     = +model.par(model.I.Nburst);

% a(132,1)    = pSTmInt/(Nburst-1)*MP4inf_LP;
mu = 132;
nu(I.MP4inf_LP,mu)                          = -1;
nu(I.Bact_LP(I.STm),mu)                     = +model.par(model.I.Nburst);

% a(133,1)    = pSTmInt/(Nburst-1)*Mefferoinf_LP;
mu = 133;
nu(I.Mefferoinf_LP,mu)                   	= -1;
nu(I.Bact_LP(I.STm),mu)                     = +model.par(model.I.Nburst);

% a(134,1)    = (1-epi)*epsilonFCP*Neut_LP;
mu = 134;
nu(I.FCP,mu)                                = +1;

% a(135,1)    = muFCP*FCP;
mu = 135;
nu(I.FCP,mu)                                = -1;


%--------------------------------------------------------------------------
%% Transit compartments
mu = model.nrOfRctWoTransit+1;

% Definition of the transit compartment reactions
%                          number of comp.,  precursor,                     effector,          vcc                     
define.Tn2Treg_LN       = {model.par(I.nTn), repmat(model.I.Tn_LN,[3,1]),	model.I.iTreg_LP,  true };
define.Tn2Th1_LN        = {model.par(I.nTn), repmat(model.I.Tn_LN,[3,1]), 	model.I.Th1_LP,    true };
define.Tn2Th2_LN        = {model.par(I.nTn), repmat(model.I.Tn_LN,[3,1]), 	model.I.Th2_LP,    true };
define.Tn2Th17_LN       = {model.par(I.nTn), repmat(model.I.Tn_LN,[3,1]),	model.I.Th17_LP,   true };
define.Tcm2Temreg_LN 	= {model.par(I.nTm), repmat(model.I.Tcm_LN,[3,1]),	model.I.Temreg_LP, true };
define.Tcm2Tem1_LN      = {model.par(I.nTm), repmat(model.I.Tcm_LN,[3,1]),	model.I.Tem1_LP,   true };
define.Tcm2Tem2_LN      = {model.par(I.nTm), repmat(model.I.Tcm_LN,[3,1]),	model.I.Tem2_LP,   true };
define.Tcm2Tem17_LN     = {model.par(I.nTm), repmat(model.I.Tcm_LN,[3,1]),	model.I.Tem17_LP,  true };
define.Tem2Treg_LP      = {model.par(I.nTm), model.I.Temreg_LP,           	model.I.iTreg_LP,  false};
define.Tem2Th1_LP       = {model.par(I.nTm), model.I.Tem1_LP,               model.I.Th1_LP,    false};
define.Tem2Th2_LP       = {model.par(I.nTm), model.I.Tem2_LP,               model.I.Th2_LP,    false};
define.Tem2Th17_LP      = {model.par(I.nTm), model.I.Tem17_LP,              model.I.Th17_LP,   false};

for t = fieldnames(define)'
    T = char(t);
    
    % Inflow: a(mu:(mu+nTn-1),:)          = Tn2Treg_inflow';      mu = mu+nTn;
    for i = 1:nrOfBact
        for j = 1:define.(T){1}
            nu(define.(T){2}(i),mu+(j-1)+(i-1)*nrOfRct)    	= -1;
            nu(I.(T)(i,j),mu+(j-1)+(i-1)*nrOfRct)         	= +1;
        end
    end
    mu = mu+define.(T){1};

    % Egress: a(mu:(mu+nTn-1),:)          = Tn2Treg_egress';      mu = mu+nTn;
    if define.(T){4}
        vcc = model.par(model.I.VLN)/model.par(model.I.VLP);
    else
        vcc = 1;
    end
    for i = 1:nrOfBact
        for j = 1:define.(T){1}
            nu(I.(T)(i,j),mu+(j-1)+(i-1)*nrOfRct)         	= -1;
            nu(define.(T){3}(i),mu+(j-1)+(i-1)*nrOfRct)   	= +1*vcc;
        end
    end
    mu = mu+define.(T){1};

    % Proliferation: a(mu:(mu+nTn-1),:)          = Tn2Treg_prol';        mu = mu+nTn;
    for i = 1:nrOfBact
        for j = 1:define.(T){1}-1
            nu(I.(T)(i,j),mu+(j-1)+(i-1)*nrOfRct)         	= -1;
            nu(I.(T)(i,j+1),mu+(j-1)+(i-1)*nrOfRct)      	= +2;
        end
    end
    mu = mu+define.(T){1};

    % Death: a(mu:(mu+nTn-1),:)          = Tn2Treg_death';       mu = mu+nTn;
    for i = 1:nrOfBact
        for j = 1:define.(T){1}
            nu(I.(T)(i,j),mu+(j-1)+(i-1)*nrOfRct)           = -1;
        end
    end
    mu = mu+define.(T){1};
end

%--------------------------------------------------------------------------

end