function [grpPars,grpIdx] = IBD_stratifyPars(model)
%==========================================================================
% grpPars = IBD_stratifyPars(model)
%==========================================================================
% Stratify parameters into groups according to cell types/processes
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% grpPars:   	group index for each parameter
% grpIdx:       index struct for parameter groups
%==========================================================================

I = model.I;

% Groups:
% 'bacteria','neutrophils','phagocytosis','Tcells','barrier','macrophages','DC','other'
allGrp = {'bact','neut','phago','T','barrier','M','DC','resolution','other'};
for i = 1:length(allGrp)
    grpIdx.(allGrp{i}) = i;
end
grpIdx.nrOfGroups   = i;
grpIdx.allGroups    = 1:i;
grpIdx.grpName      = allGrp;
grpIdx.longName = {'bacteria','neutrophils','phagocytosis','T cells','barrier','macrophages','dendritic cells','resolution','other'};

grpPars = nan(1,I.nrOfPar);

grpPars(I.VLP)                  = grpIdx.other;
grpPars(I.VLN)                  = grpIdx.other;
grpPars(I.maxConc)              = grpIdx.other;
grpPars(I.muT_LN)               = grpIdx.T;
grpPars(I.muT_LP)               = grpIdx.T;
grpPars(I.lambdaT_LN)           = grpIdx.T;
grpPars(I.muTeff)               = grpIdx.T;
grpPars(I.fractionTnCD4_bl)     = grpIdx.T;
grpPars(I.fractionTcmCD4_bl)    = grpIdx.T;
grpPars(I.nTn)                  = grpIdx.T;
grpPars(I.nTm)                  = grpIdx.T;
grpPars(I.muTprol)              = grpIdx.T;
grpPars(I.suscApoLow)           = grpIdx.T;
grpPars(I.pTn1)                 = grpIdx.T;
grpPars(I.pTni)                 = grpIdx.T;
grpPars(I.egressPerDivision)    = grpIdx.T;
grpPars(I.egressThreshold)      = grpIdx.T;
grpPars(I.egressThresholdm)     = grpIdx.T;
grpPars(I.theta1host)           = grpIdx.T;
grpPars(I.theta2host)           = grpIdx.T;
grpPars(I.theta17host)          = grpIdx.T;
grpPars(I.theta1bact)           = grpIdx.bact;
grpPars(I.theta2bact)           = grpIdx.bact;
grpPars(I.theta17bact)          = grpIdx.bact;
grpPars(I.beta)                 = grpIdx.T;
grpPars(I.alphaTn)              = grpIdx.T;
grpPars(I.alphaTh)              = grpIdx.T;
grpPars(I.alphaTm)              = grpIdx.T;
grpPars(I.Tcontact)             = grpIdx.T;
grpPars(I.pBact)                = grpIdx.bact;
grpPars(I.NmaxBact)             = grpIdx.bact;
grpPars(I.VmaxPhago)            = grpIdx.phago;
grpPars(I.KmPhago)              = grpIdx.phago;
grpPars(I.phagoRec)             = grpIdx.phago;
grpPars(I.pSTmInt)              = grpIdx.bact;
grpPars(I.Nburst)               = grpIdx.bact;
grpPars(I.muDC)                 = grpIdx.DC;
grpPars(I.muDC_LN)              = grpIdx.DC;
grpPars(I.nuDCa)                = grpIdx.DC;
grpPars(I.epsilonDC)            = grpIdx.DC;
grpPars(I.cRecDC)               = grpIdx.DC;
grpPars(I.nuDCsMax)             = grpIdx.DC;
grpPars(I.HillProActDC)         = grpIdx.DC;
grpPars(I.HillAntiActDC)        = grpIdx.DC;
grpPars(I.kTDC_LN)              = grpIdx.DC;
grpPars(I.kTDC_LP)              = grpIdx.DC;
grpPars(I.bsPerDC)              = grpIdx.DC;
grpPars(I.bsPerT)               = grpIdx.T;
grpPars(I.bsPerM)               = grpIdx.M;
grpPars(I.muM)                  = grpIdx.M;
grpPars(I.nuMP12ss)             = grpIdx.M;
grpPars(I.nuMP23ss)             = grpIdx.M;
grpPars(I.nuMP34ss)             = grpIdx.M;
grpPars(I.phagoMP1)             = grpIdx.M;
grpPars(I.phagoMP2)             = grpIdx.M;
grpPars(I.phagoMP3)             = grpIdx.M;
grpPars(I.phagoMP4)             = grpIdx.M;
grpPars(I.lambdaMmax)           = grpIdx.M;
grpPars(I.HillRecM)             = grpIdx.M;
grpPars(I.cRecM)                = grpIdx.M;
grpPars(I.nuMphago)             = grpIdx.M;
grpPars(I.HillProActM)          = grpIdx.M;
grpPars(I.HillAntiActM)         = grpIdx.M;
grpPars(I.lambdaNeutMax)        = grpIdx.neut;
grpPars(I.wProLPBact)           = grpIdx.bact;
grpPars(I.HillRecNeut)          = grpIdx.neut;
grpPars(I.muNeutc)              = grpIdx.neut;
grpPars(I.muNeutPhago)          = grpIdx.neut;
grpPars(I.muNeutMax)            = grpIdx.neut;
grpPars(I.muAponeut)            = grpIdx.neut;
grpPars(I.pBactLu)              = grpIdx.bact;
grpPars(I.muBactLu)             = grpIdx.bact;
grpPars(I.lambdaNutrients)      = grpIdx.bact;
grpPars(I.epsilonBact1)         = grpIdx.bact;
grpPars(I.epsilonBact2)         = grpIdx.bact;
grpPars(I.muEpi)                = grpIdx.barrier;
grpPars(I.ssEpi)                = grpIdx.barrier;
grpPars(I.muEpiBact)            = grpIdx.barrier;
grpPars(I.muEpiFac)             = grpIdx.barrier;
grpPars(I.muMucus)              = grpIdx.barrier;
grpPars(I.ssMucus)              = grpIdx.barrier;
grpPars(I.muTis)                = grpIdx.barrier;
grpPars(I.ssTis)                = grpIdx.barrier;
grpPars(I.muTisFac)             = grpIdx.barrier;
grpPars(I.epsilonFCP)           = grpIdx.barrier;
grpPars(I.muFCP)                = grpIdx.barrier;
grpPars(I.wPhagoLPqDC)          = grpIdx.phago;
grpPars(I.wPhagoLPrDC)          = grpIdx.phago;
grpPars(I.wPhagoLPtDC)          = grpIdx.phago;
grpPars(I.wPhagoLPsDC)          = grpIdx.phago;
grpPars(I.wPhagoLPMP1)          = grpIdx.phago;
grpPars(I.wPhagoLPMP2)          = grpIdx.phago;
grpPars(I.wPhagoLPMP3)          = grpIdx.phago;
grpPars(I.wPhagoLPMP4)          = grpIdx.phago;
grpPars(I.wPhagoLPNeut)         = grpIdx.phago;
grpPars(I.wcyto_RecNeut_Th1)    = grpIdx.neut;
grpPars(I.wcyto_RecNeut_Th17)   = grpIdx.neut;
grpPars(I.wcyto_RecNeut_Neut)   = grpIdx.neut;
grpPars(I.wcyto_RecNeut_M)      = grpIdx.neut;
grpPars(I.wcyto_RecM_Th1)       = grpIdx.M;
grpPars(I.wcyto_RecM_Th17)      = grpIdx.M;
grpPars(I.wcyto_RecM_Neut)      = grpIdx.M;
grpPars(I.wcyto_RecM_M)         = grpIdx.M;
grpPars(I.wcyto_ActM_Th1)       = grpIdx.M;
grpPars(I.wcyto_ActM_Th17)      = grpIdx.M;
grpPars(I.wcyto_ActM_Neut)      = grpIdx.M;
grpPars(I.wcyto_ActM_M)         = grpIdx.M;
grpPars(I.wcyto_ActDC_Th1)      = grpIdx.M;
grpPars(I.wcyto_ActDC_Th17)     = grpIdx.M;
grpPars(I.wcyto_ActDC_Neut)     = grpIdx.M;
grpPars(I.wcyto_ActDC_M)        = grpIdx.M;
grpPars(I.wcyto_DeactM_Treg)    = grpIdx.M;
grpPars(I.wcyto_DeactM_Th2)     = grpIdx.M;
grpPars(I.wcyto_DeactM_M)       = grpIdx.M;
grpPars(I.wcyto_DeactDC_Treg)   = grpIdx.DC;
grpPars(I.wcyto_DeactDC_Th2)    = grpIdx.DC;
grpPars(I.wcyto_DeactDC_M)      = grpIdx.DC;
grpPars(I.wcyto_DamageEpi_Th1)  = grpIdx.barrier;
grpPars(I.wcyto_DamageEpi_Th17) = grpIdx.barrier;
grpPars(I.wcyto_DamageEpi_Th2)  = grpIdx.barrier;
grpPars(I.wcyto_DamageEpi_Neut) = grpIdx.barrier;
grpPars(I.wcyto_DamageEpi_M)    = grpIdx.barrier;
grpPars(I.wcyto_DamageTis_Th1)  = grpIdx.barrier;
grpPars(I.wcyto_DamageTis_Th17) = grpIdx.barrier;
grpPars(I.wcyto_DamageTis_Th2)  = grpIdx.barrier;
grpPars(I.wcyto_DamageTis_Neut) = grpIdx.barrier;
grpPars(I.wcyto_DamageTis_M)    = grpIdx.barrier;
grpPars(I.wcyto_TisRemod_Th2)   = grpIdx.barrier;
grpPars(I.wcyto_TisRemod_M)     = grpIdx.barrier;
grpPars(I.wSPMLPNeut)           = grpIdx.resolution;
grpPars(I.wSPMLPMeffero)        = grpIdx.resolution;
    
% Was passiert wenn length(I.xx)>1 ?? 
    
if sum(isnan(grpPars))
    fprintf('%i parameters not classified.\n',sum(isnan(grpPars)))
    I.parName(isnan(grpPars))
end
