function outName = IBD_translateToLatexCommands(inName,addMathMode,bold,transitStateNumbers)
%==========================================================================
% outName = IBD_translateToLatexCommands(inName,addMathMode,bold,transitStateNumbers)
%==========================================================================
% Translate parameter names of the Matlab code to latex commands
% Requires the file 'Settings_SSt_modelCommands.tex' defining the used latex commands
%--------------------------------------------------------------------------
%-- input
% inName:               Matlab model parameter/state name
% addMathMode:          (optional) add $$ for math mode
% bold:                 (optional) add \boldsymbol for bold symbols
% transitStateNumbers:  (optional) number transit states (default: true)
%--------------------------------------------------------------------------
%-- output
% outName:          latex command for this parameter/state
%==========================================================================

if ~exist('transitStateNumbers','var')
    transitStateNumbers = true;
end

%% Parameters

i = 1;
%translatePars = cell(size(individual_ref.parTable,1),2);
translatePars = cell(131,2);

% Volumes
translatePars(i,:) = {'VLP','\VLP'}; i = i+1;
translatePars(i,:) = {'\VLN',}; i = i+1;
translatePars(i,:) = {'maxConc','maxConc'}; i = i+1;

% T cells
translatePars(i,:) = {'muT_LN','\muTLN'}; i = i+1;
translatePars(i,:) = {'muT_LP','\muTLP'}; i = i+1;
translatePars(i,:) = {'lambdaT_LN','\lambdaTn'}; i = i+1;
translatePars(i,:) = {'muTeff','\muTeff'}; i = i+1;
translatePars(i,:) = {'fractionTnCD4_bl','\lambdaTcm'}; i = i+1;
translatePars(i,:) = {'fractionTcmCD4_bl','\lambdaTcm'}; i = i+1;

% T cell proliferation (transit compartments)
translatePars(i,:) = {'nTn','\nTn'}; i = i+1;
translatePars(i,:) = {'nTm','\nTn'}; i = i+1;
translatePars(i,:) = {'muTprol','\muTprol'}; i = i+1;
translatePars(i,:) = {'suscApoLow','suscApoLow'}; i = i+1;
translatePars(i,:) = {'pTn1','\pTnone'}; i = i+1;
translatePars(i,:) = {'pTni','\pTni'}; i = i+1;
translatePars(i,:) = {'egressPerDivision','egressPerDivision'}; i = i+1;
translatePars(i,:) = {'egressThreshold','egressThreshold'}; i = i+1;
translatePars(i,:) = {'egressThresholdm','egressThresholdm'}; i = i+1;

% Effector T cells
translatePars(i,:) = {'theta1host','H_1'}; i = i+1;
translatePars(i,:) = {'theta2host','H_2'}; i = i+1;
translatePars(i,:) = {'theta17host','H_17'}; i = i+1;
translatePars(i,:) = {'theta1bact','A_1'}; i = i+1;
translatePars(i,:) = {'theta2bact','A_2'}; i = i+1;
translatePars(i,:) = {'theta17bact','A_17'}; i = i+1;

% Antigen specificities
translatePars(i,:) = {'alphaTn','\alphaTn'}; i = i+1;
translatePars(i,:) = {'alphaTh','\alphaTh'}; i = i+1;
translatePars(i,:) = {'alphaTm','\alphaTm'}; i = i+1;
translatePars(i,:) = {'beta','\beta'}; i = i+1;
translatePars(i,:) = {'Tcontact','\Tcontact'}; i = i+1;

% Dendritic cells
translatePars(i,:) = {'muDC','\muDC'}; i = i+1;
translatePars(i,:) = {'muDC_LN','\muDCLN'}; i = i+1;
translatePars(i,:) = {'nuDCa','nuDCa'}; i = i+1;
translatePars(i,:) = {'epsilonDC'}; i = i+1;
translatePars(i,:) = {'cRecDC','\lambdaDC'}; i = i+1;
translatePars(i,:) = {'nuDCsMax','\nuDCs'}; i = i+1;
translatePars(i,:) = {'HillProActDC','\HillProActDC'}; i = i+1;
translatePars(i,:) = {'HillAntiActDC','\HillAntiActDC'}; i = i+1;

% Contact rates
translatePars(i,:) = {'kTDC_LN','\kTDCLN'}; i = i+1;
translatePars(i,:) = {'kTDC_LP','\kTDCLP'}; i = i+1;
translatePars(i,:) = {'bsPerDC','\DCbs'}; i = i+1;
translatePars(i,:) = {'bsPerT','\Tbs'}; i = i+1;
translatePars(i,:) = {'bsPerM','\Mbs'}; i = i+1;

% Macrophages
translatePars(i,:) = {'muM','\muM'}; i = i+1;
translatePars(i,:) = {'nuMP12ss','\nuMPonetwo'}; i = i+1;
translatePars(i,:) = {'nuMP23ss','\nuMPtwothree'}; i = i+1;
translatePars(i,:) = {'nuMP34ss','\nuMPthreefour'}; i = i+1;
translatePars(i,:) = {'phagoMP1','\phagoMone'}; i = i+1;
translatePars(i,:) = {'phagoMP2','\phagoMtwo'}; i = i+1;
translatePars(i,:) = {'phagoMP3','\phagoMthree'}; i = i+1;
translatePars(i,:) = {'phagoMP4','\phagoMfour'}; i = i+1;
translatePars(i,:) = {'lambdaMmax','\lambdaMmax'}; i = i+1;
translatePars(i,:) = {'HillRecM','\HillRecM'}; i = i+1;
translatePars(i,:) = {'cRecM','\cRecM'}; i = i+1;
translatePars(i,:) = {'nuMphago','\nuMphago'}; i = i+1;
translatePars(i,:) = {'HillProActM','\HillProActM'}; i = i+1;
translatePars(i,:) = {'HillAntiActM','\HillAntiActM'}; i = i+1;

% Pathogenic bacteria in LP
translatePars(i,:) = {'pBact','\pBactLP'}; i = i+1;
translatePars(i,:) = {'NmaxBact','\NmaxBact'}; i = i+1;
translatePars(i,:) = {'VmaxPhago','\VmaxPhago'}; i = i+1;
translatePars(i,:) = {'KmPhago','\KmPhago'}; i = i+1;
translatePars(i,:) = {'phagoRec','\phagoRec'}; i = i+1;
translatePars(i,:) = {'pSTmInt','\pSTmInt'}; i = i+1;
translatePars(i,:) = {'Nburst','\Nburst'}; i = i+1;

% Neutrophils
translatePars(i,:) = {'lambdaNeutMax','\lambdaNeutMax'}; i = i+1;
translatePars(i,:) = {'HillRecNeut','\HillRecNeut'}; i = i+1;
translatePars(i,:) = {'muNeutc','\muNeutc'}; i = i+1;
translatePars(i,:) = {'muNeutPhago','\muNeutPhago'}; i = i+1;
translatePars(i,:) = {'muNeutMax','\muNeutMax'}; i = i+1;
translatePars(i,:) = {'muAponeut','\muNeutApo'}; i = i+1;

% Bacteria in lumen
translatePars(i,:) = {'pBactLu','\pBactLu'}; i = i+1;
translatePars(i,:) = {'muBactLu','\muBactLu'}; i = i+1;
translatePars(i,:) = {'lambdaNutrients','\lambdanutrients'}; i = i+1;

% Mucus & epithelial barrier
translatePars(i,:) = {'epsilonBact1','\epsBactwithout'}; i = i+1;
translatePars(i,:) = {'epsilonBact2','\epsBactwith'}; i = i+1;
translatePars(i,:) = {'muEpi','\muepi'}; i = i+1;
translatePars(i,:) = {'ssEpi','ssEpi'}; i = i+1;
translatePars(i,:) = {'muEpiBact','\muepiBact'}; i = i+1;
translatePars(i,:) = {'muEpiFac','muEpiFac'}; i = i+1;
translatePars(i,:) = {'muMucus'}; i = i+1;
translatePars(i,:) = {'ssMucus','ssMucus'}; i = i+1;
translatePars(i,:) = {'muTis','\mutis'}; i = i+1;
translatePars(i,:) = {'ssTis','ssTis'}; i = i+1;
translatePars(i,:) = {'muTisFac','muTisFac'}; i = i+1;
translatePars(i,:) = {'epsilonFCP','epsilonFCP'}; i = i+1;
translatePars(i,:) = {'muFCP','muFCP'}; i = i+1;

% Weights for phagocytosis
% --> relative to neutrophils (weight Neut = {1)
translatePars(i,:) = {'wPhagoLPqDC','wPhagoLPqDC'}; i = i+1;
translatePars(i,:) = {'wPhagoLPrDC','wPhagoLPrDC'}; i = i+1;
translatePars(i,:) = {'wPhagoLPtDC','wPhagoLPtDC'}; i = i+1;
translatePars(i,:) = {'wPhagoLPsDC','wPhagoLPsDC'}; i = i+1;
translatePars(i,:) = {'wPhagoLPMP1','\phagoMone'}; i = i+1;
translatePars(i,:) = {'wPhagoLPMP2','\phagoMtwi'}; i = i+1;
translatePars(i,:) = {'wPhagoLPMP3','\phagoMthree'}; i = i+1;
translatePars(i,:) = {'wPhagoLPMP4','wPhagoLPMP4'}; i = i+1;
translatePars(i,:) = {'wPhagoLPNeut','wPhagoLPNeut'}; i = i+1;

% Weights for cytokine production
translatePars(i,:) = {'wcyto_RecNeut_Th1',      '\Thoneeff\rightarrow\cytoRecNeut'}; i = i+1;
translatePars(i,:) = {'wcyto_RecNeut_Th17',     '\Thseventeeneff\rightarrow\cytoRecNeut'}; i = i+1;
translatePars(i,:) = {'wcyto_RecNeut_Neut',     '\Neut\rightarrow\cytoRecNeut'}; i = i+1;
translatePars(i,:) = {'wcyto_RecNeut_M',        '\Mproaix\rightarrow\cytoRecNeut'}; i = i+1;
translatePars(i,:) = {'wcyto_RecM_Th1',         '\Thoneeff\rightarrow\cytoRecM'}; i = i+1;
translatePars(i,:) = {'wcyto_RecM_Th17',        '\Thseventeeneff\rightarrow\cytoRecM'}; i = i+1;
translatePars(i,:) = {'wcyto_RecM_Neut',        '\Neut\rightarrow\cytoRecM'}; i = i+1;
translatePars(i,:) = {'wcyto_RecM_M',           '\Mproaix\rightarrow\cytoRecM'}; i = i+1;
translatePars(i,:) = {'wcyto_ActM_Th1',         '\Thoneeff\rightarrow\cytoActM'}; i = i+1;
translatePars(i,:) = {'wcyto_ActM_Th17',        '\Thseventeeneff\rightarrow\cytoActM'}; i = i+1;
translatePars(i,:) = {'wcyto_ActM_Neut',        '\Neut\rightarrow\cytoActM'}; i = i+1;
translatePars(i,:) = {'wcyto_ActM_M',           '\Mproaix\rightarrow\cytoActM'}; i = i+1;
translatePars(i,:) = {'wcyto_ActDC_Th1',        '\Thoneeff\rightarrow\cytoActDC'}; i = i+1;
translatePars(i,:) = {'wcyto_ActDC_Th17',       '\Thseventeeneff\rightarrow\cytoActDC'}; i = i+1;
translatePars(i,:) = {'wcyto_ActDC_Neut',       '\Neut\rightarrow\cytoActDC'}; i = i+1;
translatePars(i,:) = {'wcyto_ActDC_M',          '\Mproaix\rightarrow\cytoActDC'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactM_Treg',      '\iTregeffLP\rightarrow\cytoDeactM'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactM_Th2',       '\Thtwoeff\rightarrow\cytoDeactM'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactM_M',         '\Mantiaix\rightarrow\cytoDeactM'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactDC_Treg',     '\iTregeffLP\rightarrow\cytoDeactDC'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactDC_Th2',      '\Thtwoeff\rightarrow\cytoDeactDC'}; i = i+1;
translatePars(i,:) = {'wcyto_DeactDC_M',        '\Mantiaix\rightarrow\cytoDeactDC'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageEpi_Th1',    '\Thoneeff\rightarrow\cytoDamageEpi'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageEpi_Th17',   '\Thseventeeneff\rightarrow\cytoDamageEpi'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageEpi_Th2',    '\Thtwoeff\rightarrow\cytoDamageEpi'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageEpi_Neut',   '\Neut\rightarrow\cytoDamageEpi'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageEpi_M',      '\Mproaix\rightarrow\cytoDamageEpi'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageTis_Th1',    '\Thoneeff\rightarrow\cytoDamageTis'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageTis_Th17',   '\Thseventeeneff\rightarrow\cytoDamageTis'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageTis_Th2',    '\Thtwoeff\rightarrow\cytoDamageTis'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageTis_Neut',   '\Neut\rightarrow\cytoDamageTis'}; i = i+1;
translatePars(i,:) = {'wcyto_DamageTis_M',      '\Mproaix\rightarrow\cytoDamageTis'}; i = i+1;
translatePars(i,:) = {'wcyto_TisRemod_Th2',     '\Thtwoeff\rightarrow\cytoTisRemod'}; i = i+1;
translatePars(i,:) = {'wcyto_TisRemod_M',       '\Mantiaix\rightarrow\cytoTisRemod'}; i = i+1;
translatePars(i,:) = {'wProLPBact','\wProBact'}; i = i+1;

% Weights of specialised pro-resolving mediator production
% --> relative to neutrophils (weight Neut = {1)
translatePars(i,:) = {'wSPMLPNeut','wSPMLPNeut'}; i = i+1;
translatePars(i,:) = {'wSPMLPMeffero','\wSPMMeffero'}; i = i+1;


%% States

i = 1;
% translateStates = cell(size(individual_ref.stateTable,1),2);
translateStates = cell(92,2);

translateStates(i,:) = {'qDC_LP','\qDC'}; i = i+1;
translateStates(i,:) = {'tDC_LP','\tDCLP'}; i = i+1;
translateStates(i,:) = {'rDC_LP','\rDC'}; i = i+1;
translateStates(i,:) = {'sDC_LP','\sDCLP'}; i = i+1;
translateStates(i,:) = {'tDCi_LP','\tDCiLP'}; i = i+1;
translateStates(i,:) = {'sDCi_LP','\sDCiLP'}; i = i+1;
translateStates(i,:) = {'tDC_LN','\tDCLN'}; i = i+1;
translateStates(i,:) = {'sDC_LN','\sDCLN'}; i = i+1;
translateStates(i,:) = {'tDCi_LN','\tDCiLN'}; i = i+1;
translateStates(i,:) = {'sDCi_LN','\sDCiLN'}; i = i+1;
translateStates(i,:) = {'Tn_LN','\Tn'}; i = i+1;
translateStates(i,:) = {'Tcm_LN','\Tcm'}; i = i+1;
translateStates(i,:) = {'Tn2Treg_LN','\TntoTreg'}; i = i+1;
translateStates(i,:) = {'Tn2Th1_LN','\TntoThone'}; i = i+1;
translateStates(i,:) = {'Tn2Th2_LN','\TntoThtwo'}; i = i+1;
translateStates(i,:) = {'Tn2Th17_LN','\TntoThseventeen'}; i = i+1;
translateStates(i,:) = {'Tcm2Temreg_LN','\TcmtoTreg'}; i = i+1;
translateStates(i,:) = {'Tcm2Tem1_LN','\TcmtoTone'}; i = i+1;
translateStates(i,:) = {'Tcm2Tem2_LN','\TcmtoTtwo'}; i = i+1;
translateStates(i,:) = {'Tcm2Tem17_LN','\TcmtoTseventeen'}; i = i+1;
translateStates(i,:) = {'Tem2Treg_LP','\TemtoTreg'}; i = i+1;
translateStates(i,:) = {'Tem2Th1_LP','\TemtoThone'}; i = i+1;
translateStates(i,:) = {'Tem2Th2_LP','\TemtoThtwo'}; i = i+1;
translateStates(i,:) = {'Tem2Th17_LP','\TemtoThseventeen'}; i = i+1;
translateStates(i,:) = {'Temreg_LP','\Temreg'}; i = i+1;
translateStates(i,:) = {'Tem1_LP','\Temone'}; i = i+1;
translateStates(i,:) = {'Tem2_LP','\Temtwo'}; i = i+1;
translateStates(i,:) = {'Tem17_LP','\Temseventeen'}; i = i+1;
translateStates(i,:) = {'iTreg_LP','\iTreg'}; i = i+1;
translateStates(i,:) = {'Th1_LP','\Thone'}; i = i+1;
translateStates(i,:) = {'Th2_LP','\Thtwo'}; i = i+1;
translateStates(i,:) = {'Th17_LP','\Thseventeen'}; i = i+1;
translateStates(i,:) = {'MP1_LP','\Mone'}; i = i+1;
translateStates(i,:) = {'MP1a_LP','\Monea'}; i = i+1;
translateStates(i,:) = {'MP1ai_LP','\Moneai'}; i = i+1;
translateStates(i,:) = {'MP2_LP','\Mtwo'}; i = i+1;
translateStates(i,:) = {'MP2a_LP','\Mtwoa'}; i = i+1;
translateStates(i,:) = {'MP2ai_LP','\Mtwoai'}; i = i+1;
translateStates(i,:) = {'MP3_LP','\Mthree'}; i = i+1;
translateStates(i,:) = {'MP3a_LP','\Mthreea'}; i = i+1;
translateStates(i,:) = {'MP3ai_LP','\Mthreeai'}; i = i+1;
translateStates(i,:) = {'MP4_LP','\Mfour'}; i = i+1;
translateStates(i,:) = {'MP4a_LP','\Mfoura'}; i = i+1;
translateStates(i,:) = {'MP4ai_LP','\Mfourai'}; i = i+1;
translateStates(i,:) = {'Meffero_LP','\Meffero'}; i = i+1;
translateStates(i,:) = {'Mefferoa_LP','\Mefferoa'}; i = i+1;
translateStates(i,:) = {'Mefferoai_LP','\Mefferoai'}; i = i+1;
translateStates(i,:) = {'MP1inf_LP','\Moneinf'}; i = i+1;
translateStates(i,:) = {'MP2inf_LP','\Mtwoinf'}; i = i+1;
translateStates(i,:) = {'MP3inf_LP','\Mthreeinf'}; i = i+1;
translateStates(i,:) = {'MP4inf_LP','\Mfourinf'}; i = i+1;
translateStates(i,:) = {'Mefferoinf_LP','\Mefferoinf'}; i = i+1;
translateStates(i,:) = {'Bact_LP','\BactLP'}; i = i+1;
translateStates(i,:) = {'Neut_LP','\Neut'}; i = i+1;
translateStates(i,:) = {'apoNeut_LP','\Neutapo'}; i = i+1;
translateStates(i,:) = {'Bact_Lu','\BactLu'}; i = i+1;
translateStates(i,:) = {'nutrients','\nutrients'}; i = i+1;
translateStates(i,:) = {'epi','\epi'}; i = i+1;
translateStates(i,:) = {'mucus','\mucus'}; i = i+1;
translateStates(i,:) = {'tissue','\tissue'}; i = i+1;
translateStates(i,:) = {'FCP','FCP'}; i = i+1;
translateStates(i,:) = {'DC_tot_LN','\mathrm{DC}_{\mathrm{tot,LN}}'}; i = i+1;
translateStates(i,:) = {'Th_tot_LN','\mathrm{Th}_{\mathrm{tot+1,LN}}'}; i = i+1;
translateStates(i,:) = {'iTreg_tot_LN',''}; i = i+1;
translateStates(i,:) = {'Tm_tot_LN',''}; i = i+1;
translateStates(i,:) = {'DC_tot_LP',''}; i = i+1;
translateStates(i,:) = {'Th_tot_LP','\mathrm{Th}_{\mathrm{tot,LP}}'}; i = i+1;
translateStates(i,:) = {'Temh_tot_LP','\mathrm{Temh}_{\mathrm{tot,LP}}'}; i = i+1;
translateStates(i,:) = {'iTreg_tot_LP','\mathrm{iTreg}_{\mathrm{tot,LP}}'}; i = i+1;
translateStates(i,:) = {'Temreg_tot_LP','\mathrm{Temreg}_{\mathrm{tot,LP}}'}; i = i+1;
translateStates(i,:) = {'Tm_tot_LP','\mathrm{Tm}_{\mathrm{tot,LP}}'}; i = i+1;
translateStates(i,:) = {'MP1_tot_LP','\Monetot'}; i = i+1;
translateStates(i,:) = {'MP2_tot_LP','\Mtwotot'}; i = i+1;
translateStates(i,:) = {'MP3_tot_LP','\Mthreetot'}; i = i+1;
translateStates(i,:) = {'MP4_tot_LP','\Mfourtot'}; i = i+1;
translateStates(i,:) = {'Meffero_tot_LP','\Mefferotot'}; i = i+1;
translateStates(i,:) = {'M_tot_LP','\Mtot'}; i = i+1;
translateStates(i,:) = {'SPM_LP','\SPM'}; i = i+1;
translateStates(i,:) = {'APCp_LN',''}; i = i+1;
translateStates(i,:) = {'APCm_LN',''}; i = i+1;
translateStates(i,:) = {'APCp_LP',''}; i = i+1;
translateStates(i,:) = {'APCm_LP',''}; i = i+1;
translateStates(i,:) = {'MPhago_LP','\MPhago'}; i = i+1;
translateStates(i,:) = {'Phago_LP','\Phago'}; i = i+1;
translateStates(i,:) = {'CNC_LP','\mathrm{CNC}'}; i = i+1;
translateStates(i,:) = {'iTreg_eff_LN','\iTregeffLN'}; i = i+1;
translateStates(i,:) = {'iTreg_eff_LP','\iTregeffLP'}; i = i+1;
translateStates(i,:) = {'Th1_eff_LP','\Thoneeff'}; i = i+1;
translateStates(i,:) = {'Th2_eff_LP','\Thtwoeff'}; i = i+1;
translateStates(i,:) = {'Th17_eff_LP','\Thseventeeneff'}; i = i+1;
translateStates(i,:) = {'Th_eff_tot_LN','\TheffLN'}; i = i+1;
translateStates(i,:) = {'Th_eff_tot_LP','\TheffLP'}; i = i+1;


%% Translate
if ~exist('addMathMode','var')
    addMathMode = false;
end
if ~exist('bold','var')
    bold = false;
end

translateAll = [translatePars;translateStates];

if ~iscell(inName)
    singleInName = true;
    inName = {inName};
else
    singleInName = false;
end

outName = inName;
for i = 1:length(inName)
    % Case of unique par/state names: added numbers for transit compartments
    pattern = '_[0-9]+$';
    if ~isempty(regexp(inName{i},pattern,'once'))
        uniqueNumber = inName{i}(regexp(inName{i},pattern,'once')+1:end);
        inName{i} = inName{i}(1:regexp(inName{i},pattern,'once')-1);
    else
        uniqueNumber = 0;
    end
    
    idx = find(strcmp(inName{i},translateAll(:,1)),1);
    
    if ~isempty(idx)
        outName{i} = translateAll{idx,2};
    end
    
    if uniqueNumber && transitStateNumbers
        outName{i} = [outName{i},'_{',uniqueNumber,'}'];
    end
    
    if bold
        outName{i} = ['\boldsymbol{',outName{i},'}'];
    end
    if addMathMode
        outName{i} = ['$',outName{i},'$'];
    end
end

if singleInName
    outName = outName{1};
end

%--------------------------------------------------------------------------
end

