%==========================================================================
% IBD_PlotLSA_hurricane
%==========================================================================
% Plot LSA results as hurricane plot
%--------------------------------------------------------------------------
%-- sources:
% see IBD_parameters
%--------------------------------------------------------------------------
%-- dependencies:
% none
% LSA table must be based on the model struct in the current workspace!
%==========================================================================

% Specify settings
input   = 'STm';
output  = 'elimination';
date    = '31-Mar-2019';

filename = ['LSA_',input,'_',output,'_',date,'.mat'];
load(filename)

plotName = ['LSA_',input,'_',output,'_',date];
assert(exist(filename,'file')>0,'Specified LSA has not been run yet (check date!).')

LSAx = LSA;
yref = LSAx.Properties.UserData;

%--------------------------------------------------------------------------
% Sort rows based on sensitivity
LSAx.absS = abs(LSAx.S);
LSAx = sortrows(LSAx,'absS','descend','MissingPlacement','last');
LSAx.uniqueState = LSAx.state;
LSAx.uniqueState(~strcmp('commensal',LSAx.bact)) = strcat(LSAx.state(~strcmp('commensal',LSAx.bact)),LSAx.bact(~strcmp('commensal',LSAx.bact)));
LSAx.printName = cellfun(@(s) regexprep(s,'_','\\_'),LSAx.state,'UniformOutput',false);
LSAx.printName(~strcmp('commensal',LSAx.bact)) = strcat(LSAx.printName(~strcmp('commensal',LSAx.bact)),{' ('},LSAx.bact(~strcmp('commensal',LSAx.bact)),{')'});

%--------------------------------------------------------------------------
% Hurricane plot of top 10
% alternative: all with sensitivity of at least 10% of most sensitive par
plotIdx = 1:10;
%plotIdx = find(LSAx.absS>=LSAx.absS(1)*0.1);

LSAx = LSAx(plotIdx(end:-1:1),:);

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.5, 0.7]);
baseline  	= yref;
incColour	= [0.9 0 0];
decColour	= [0 0.2 0.8];
fontSize	= 14;

b1 = barh(categorical(LSAx.uniqueState,LSAx.uniqueState),LSAx.plus,'FaceAlpha',0.3,'EdgeColor',incColour,'FaceColor','flat','LineWidth',1.5,'DisplayName','increased');
set(gca,'YTickLabel',LSAx.printName)
b1(1).BaseValue = baseline;
hold on;
b2 = barh(categorical(LSAx.uniqueState,LSAx.uniqueState),LSAx.minus,'FaceAlpha',0.3,'EdgeColor',decColour,'FaceColor','flat','LineWidth',1.5,'DisplayName','decreased');
b2(1).BaseValue = baseline;
xlabel([output,' for ',num2str(LSAx.delta(1)),' relative change in parameter'])
hold off
l = legend('Location','east','FontSize',fontSize);

% Colours according to processes
[parAnnot,colour]   = IBD_annotatePars(model.I.parName);
parAnnot            = parAnnot(LSAx.idx);
processes           = unique(parAnnot);
for i = 1:length(LSAx.idx)
    b1.CData(i,:)   = colour.(parAnnot{i});
    b2.CData(i,:)   = colour.(parAnnot{i});
end

IBD_saveFigure(f,plotName,false)
