%==========================================================================
% IBD_PlotLSA_sensitivities
%==========================================================================
% Plot LSA results as sensitivities
%--------------------------------------------------------------------------
%-- sources:
% see IBD_parameters
%--------------------------------------------------------------------------
%-- dependencies:
% none
% LSA table must be based on the model struct in the current workspace!
%==========================================================================

% Specify settings
datex       = '29-Apr-2019';
whichOutput = 'AUCtis';
absolute    = 'true';       % plot absolute coefficients (vs positive and negative)

filename    = ['Data/LSA_',datex,'.mat'];
load(filename)

% Temporary
LSA.Properties.VariableNames{2} = 'par';

plotName    = ['LSA_',whichOutput,'_',datex];
assert(exist(filename,'file')>0,'Specified LSA has not been run yet (check date!).')

LSAx = LSA(strcmp(LSA.output,whichOutput),:);

%--------------------------------------------------------------------------
% Sort rows based on sensitivity
LSAx.absS = abs(LSAx.S);
LSAx = sortrows(LSAx,'absS','descend','MissingPlacement','last');
LSAx.uniquePar = LSAx.par;
LSAx.uniquePar(~strcmp('commensal',LSAx.bact)) = strcat(LSAx.par(~strcmp('commensal',LSAx.bact)),LSAx.bact(~strcmp('commensal',LSAx.bact)));
LSAx.printName = cellfun(@(s) regexprep(s,'_','\\_'),LSAx.par,'UniformOutput',false);
LSAx.printName(~strcmp('commensal',LSAx.bact)) = strcat(LSAx.printName(~strcmp('commensal',LSAx.bact)),{' ('},LSAx.bact(~strcmp('commensal',LSAx.bact)),{')'});

if absolute
    LSAx.S = LSAx.absS;
end

%--------------------------------------------------------------------------
% Hurricane plot of top 10
% alternative: all with sensitivity of at least 10% of most sensitive par

switch whichOutput
    case 'tissue'
        plotIdx = 2:30;
    otherwise
        plotIdx = 2:30;
end
%plotIdx = find(LSAx.absS>=LSAx.absS(1)*0.1);

LSAx = LSAx(plotIdx(end:-1:1),:);

% Colours according to processes
[parAnnot,colour]   = IBD_annotatePars(model.I.parName);
parAnnot            = parAnnot(LSAx.idx);
processes           = unique(parAnnot);

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2, 0.6]);
fontSize	= 14;

% Divide parameters into processes
stacked = zeros(length(plotIdx),length(processes));
for p = 1:length(processes)
    thisStack   = zeros(length(plotIdx),1);
    thisProcess	= strcmp(parAnnot,processes{p});
    thisStack(thisProcess) = LSAx.S(thisProcess);
    stacked(:,p) = thisStack;
end
b = barh(stacked,'stacked');
for p = 1:length(processes)
    b(p).FaceColor = colour.(processes{p});
    b(p).EdgeColor = colour.(processes{p});
end
%yticks(plotIdx)
%yticklabels(LSAx.printName)
yticks([])
yticklabels({})
box off
ylabel('parameters')

if absolute
    xlabel('|sensitivity coefficient|')
else
    xlabel('sensitivity coefficient')
end

IBD_saveFigure(f,plotName,true)






