function f = IBD_barPlot(x,colours,options,ax)
%==========================================================================
% f = IBD_barPlot(x,colours,options)
%==========================================================================
% Violin plot
%--------------------------------------------------------------------------
%-- input
% x:            data vector
% colours:      colour matrix
% options:      labels, ylabel, addValues
% ax:           (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output
% f:            figure
%==========================================================================

x = reshape(x,1,[]);

if ~exist('colours','var') || isempty(colours)
    colours = repmat([0 0 0],[length(labels),1]);
end

if ~exist('options','var')
    options = struct;
end

if ~exist('ax','var')
    f = figure;
    set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*length(x)/2, 0.3]);
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

width = 0.4;

% Bars
for i = 1:length(x)
    fill(ax,[i-width,i+width,i+width,i-width],[0 0 x(i) x(i)],colours(i,:),'EdgeColor',colours(i,:),'FaceAlpha',0.5)
end

% Add values on top of bars
if isfield(options,'addValues') && options.addValues
    text(ax,1:length(x),x,num2str(x','%.2f'),'vert','bottom','horiz','center');
end

% xlim
xlim(ax,[0.5 i+0.5])

% ylim
if isfield(options,'ylim')
    ylim(ax,options.ylim)
end

% y label
if isfield(options,'ylabel')
    ylabel(ax,options.ylabel)
end

% ticklabels
if isfield(options,'xticklabels')
    xticklabels(ax,options.xticklabels)
end
if isfield(options,'xtickangle')
    xtickangle(ax,options.xtickangle)
end

if makeFigure
    f = IBD_nicePlot(f);
else
    f = nan;
end

end

