function f = IBD_nicePlot(f,lwd,fontsize)
%==========================================================================
% f = nicePlot(f,lwd,fontsize)
%==========================================================================
% Nice plots
%--------------------------------------------------------------------------
%-- input
% f:            figure handle
% lwd:          (optional) line width
% fontsize:     (optional) font size
%--------------------------------------------------------------------------
%-- output
% f:            figure handle
%==========================================================================    

% Settings
if ~exist('lwd','var') || isempty(lwd)
    lwd         = 3;
end
if ~exist('fontsize','var') || isempty(fontsize)
    fontsize    = 18;
end

set(findobj(f,'Type','Line'),'LineWidth',lwd);
set(findobj(f,'Type','ErrorBar'),'LineWidth',lwd);
set(findobj(f,'Type','ConstantLine'),'LineWidth',lwd);
set(findobj(f,'Type','Text'),'FontSize',fontsize);
set(findobj(f,'Type','Patch'),'LineWidth',lwd);

subplots = get(f,'children');
for s = 1:length(subplots)
    set(subplots(s),'FontSize',fontsize)
    set(subplots(s),'LineWidth',lwd-1)
    if strcmp(subplots(s).Type,'axes')
        set(subplots(s),'TickDir','out')
        subplots(s).Box = 'off';
    end
end

% Move created figures into edges of screen
switch f.Number
    case 1
        pos = 'northwest';
    case 2
        pos = 'north';
    case 3
        pos = 'northeast';
    case 4
        pos = 'west';
    case 5
        pos = 'center';
    case 6
        pos = 'east';
    case 7
        pos = 'southwest';
    case 8
        pos = 'south';
    case 9
        pos = 'southeast';
    otherwise
        pos = 'center';
end
movegui(f,pos);

end

%--------------------------------------------------------------------------
