function f = IBD_plotCumulativeDist(par,individual_ref,whichClasses,whichPars,options)
%==========================================================================
% f = IBD_plotParDist(histCounts,individual_ref)
%==========================================================================
% Plot cumulative frequency distribution of parameters among different 
% classes
%--------------------------------------------------------------------------
%-- input
% par:              struct of parameter values per class
% individual_ref:   reference individual
% whichClasses:     which classes to plot
% whichPars:        which parameters to plot
% options:          additional options
%--------------------------------------------------------------------------
%-- output
% f:            figure
%--------------------------------------------------------------------------
%-- sources:
% -
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

if ~exist('options','var')
    options = struct;
end

% Figure
[m,n] = IBD_getNrOfColsAndRows(length(whichPars),5,5);

f_counter   = 0;

if isfield(options,'colours')
    colours     = options.colours;
else
    colours     = IBD_colourMap('dark rainbow',length(whichClasses)+1);
end

% Parameters or states?
if size(par.healthy,1)==individual_ref.I.nrOfPar
    parName     = IBD_uniqueParName(individual_ref.I);
    parOrState  = 'par';
else
    parName     = IBD_uniqueStateName(individual_ref.I);
    parOrState  = 'state';
end

% Plot per parameter
for i = 1:length(whichPars)
    
    % Subplot/new figure
    if mod(i,m*n)==1
        if f_counter>0
            % Make previous figure nice
            f(f_counter) = IBD_nicePlot(f(f_counter));
        end
        f_counter = f_counter+1;
        f(f_counter) = figure;
        set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);
        subplot(m,n,1)
    else
        subplot(m,n,i-(f_counter-1)*m*n)
    end
    
    legendArray = {};
    
    % Axis labels, title
    xlabel('parameter value')
    ylabel('density')
    title(parName{whichPars(i)},'Interpreter','none')
    
    hold on
    
    % Cumulative frequency distributions
    xThreshold = 0;
    for c = 1:length(whichClasses)
        colour  = colours(c,:);
        thisPar = par.(whichClasses{c})(whichPars(i),:);
        xvalues = sort(thisPar);
        yvalues = (1:length(thisPar))/length(thisPar);
        plot(xvalues,yvalues,'Color',colour);
        xThreshold = max(xThreshold,xvalues(find(yvalues>0.99,1)));
        legendArray = [legendArray,strrep(whichClasses{c},'_',' ')];
    end
    
    if i==1 % legend only in first plot
        legend(legendArray)
    end
    
    ax = gca;
    ax.YLim(1) = 0;
    
    % Trim X axis when all classes are above 95 %
    ax.XLim(2) = xThreshold;
    
end

% Make last figure nice
f(f_counter) = IBD_nicePlot(f(f_counter));

%--------------------------------------------------------------------------
end
