function p = IBD_plotDatabase(which,model)
%==========================================================================
% p = IBD_plotDatabase(which,model)
%==========================================================================
% Plot specifications 
%--------------------------------------------------------------------------
%-- input
% which:       	name of plot
% model:     	model struct
%--------------------------------------------------------------------------
%-- output
% p:            struct of plot specifications
%==========================================================================

default = IBD_plotSpecReference(model);

switch which
     
    %----------------------------------------------------------------------
    case {'overview','overview_classes','overview_woBarrier','overview_classes_withInset'}
        default.xunit   = 'd';
        default.ylabel  = 'Conc. [1/mL]';
        default.titlePos= 'left';
        default.grid    = false;
        default.titleUp = 1.3;
        p(1)            = default;
        p(1).states     = {'Bact_LP'};
        p(1).Bact       = {};
        p(1).tikzLegend	= 'bacteria';
        p(1).main       = 'Bacteria';
        p(1).legendPos  = 'northeast';
        p(1).ylabel     = 'Conc. / value';
        p(2)          	= default;
        p(2).states     = {'tissue','epi'};
        p(2).tikzLegend = {'$\tissue$','$\epi$'};
        p(2).main       = 'Barrier';
        p(2).legendPos  = 'southeast';
        p(2).yline      = 1;
        p(2).ylim       = [0 1.3];
        p(2).ylabel     = '';
        p(3)            = default;
        p(3).states     = {'Th_tot_LP','M_tot_LP','Neut_LP'};
        p(3).tikzLegend = {'T helper cells','macrophages','neutrophils'};
        p(3).main       = 'Immune response';
        p(3).legendPos  = 'northeast';
        p(3).ylabel     = '';
        colours         = IBD_colourMap('dark rainbow',7);
        p(1).colourMap  = colours(1,:);
        p(2).colourMap  = colours(2:3,:);
        p(3).colourMap  = colours(4:6,:);
        
        switch which
            
            case 'overview_classes'
                p(1).noLink = 4;
                
            case 'overview_woBarrier'
                p = p([1 3]);
                
            case 'overview_classes_withInset'
                p(4) = p(3);
                p(4).xlim = [0 5*24];
                p(4).ylim = [0 0.3e9];
                p(4).main = '(zoom)';
                p(4).showLegend = false;
        end
        
    %----------------------------------------------------------------------
	case 'cytokines'
        
        default.rowcol	= [4 3];
        default.grid    = false;
        default.yline 	= 1;
        default.xunit 	= 'd';
        default.Bact  	= {'commensal'};
        
        x = model.nrOfRctWoTransit_true;
        
        i = 1;
        p(i)            = default;
        p(i).rates      = x+(2:6);
        p(i).main       = 'Rec Neut';
        p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(7:11);
        p(i).main       = 'Rec M';
        p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(12:16);
        p(i).main       = 'Act M';
        p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(17:21);
        p(i).main       = 'Act DC';
        p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(22:25);
        p(i).main       = 'Deact M';
        p(i).legend     = {'total','Treg','Th2','Manti'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(26:29);
        p(i).main       = 'Deact DC';
        p(i).legend     = {'total','Treg','Th2','Manti'};
        
%         i = i+1;
%         p(i)            = default;
%         p(i).rates      = x+(42:44);
%         p(i).main       = 'SPM';
%         p(i).legend     = {'total','apoNeut','Meffero'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(30:35);
        p(i).main       = 'Damage Epi';
        p(i).legend     = {'total','Th1','Th17','Th2','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(36:41);
        p(i).main       = 'Damage Tissue';
        p(i).legend     = {'total','Th1','Th17','Th2','Neut','Mpro'};
        
        i = i+1;
        p(i)            = default;
        p(i).rates      = x+(45:47);
        p(i).main       = 'Tissue remodelling';
        p(i).legend     = {'total','Th2','Meff'};
        
        
        % reaction rates:
        % a(x+2,:)  	= cyto_RecNeut;
        % a(x+3,:)   	= wcyto_RecNeut_Th1*cyto_Th1;
        % a(x+4,:) 	= wcyto_RecNeut_Th17*cyto_Th17;
        % a(x+5,:)   	= wcyto_RecNeut_Neut*Neut_LP;
        % a(x+6,:) 	= wcyto_RecNeut_M*Mpro;
        % a(x+7,:)  	= cyto_RecM;
        % a(x+8,:)  	= wcyto_RecM_Th1*cyto_Th1;
        % a(x+9,:)  	= wcyto_RecM_Th17*cyto_Th17;
        % a(x+10,:) 	= wcyto_RecM_Neut*Neut_LP;
        % a(x+11,:) 	= wcyto_RecM_M*Mpro;
        % a(x+12,:) 	= cyto_ActM;
        % a(x+13,:) 	= wcyto_ActM_Th1*cyto_Th1;
        % a(x+14,:) 	= wcyto_ActM_Th17*cyto_Th17;
        % a(x+15,:)  	= wcyto_ActM_Neut*Neut_LP;
        % a(x+16,:) 	= wcyto_ActM_M*Mpro;
        % a(x+17,:)  	= cyto_ActDC;
        % a(x+18,:)  	= wcyto_ActDC_Th1*cyto_Th1;
        % a(x+19,:) 	= wcyto_ActDC_Th17*cyto_Th17;
        % a(x+20,:)  	= wcyto_ActDC_Neut*Neut_LP;
        % a(x+21,:) 	= wcyto_ActDC_M*Mpro;
        % a(x+22,:)	= cyto_DeactM;
        % a(x+23,:)  	= wcyto_DeactM_Treg*sum(iTreg_LP);
        % a(x+24,:)  	= wcyto_DeactM_Th2*cyto_Th2;
        % a(x+25,:) 	= wcyto_DeactM_M*Manti;
        % a(x+26,:) 	= cyto_DeactDC;
        % a(x+27,:)  	= wcyto_DeactDC_Treg*sum(iTreg_LP);
        % a(x+28,:)  	= wcyto_DeactDC_Th2*cyto_Th2;
        % a(x+29,:)  	= wcyto_DeactDC_M*Manti;
        % a(x+30,:) 	= cyto_DamageEpi;
        % a(x+31,:) 	= wcyto_DamageEpi_Th1*cyto_Th1;
        % a(x+32,:)	= wcyto_DamageEpi_Th17*cyto_Th17;
        % a(x+33,:)	= wcyto_DamageEpi_Th2*cyto_Th2;
        % a(x+34,:)  	= wcyto_DamageEpi_Neut*Neut_LP;
        % a(x+35,:) 	= wcyto_DamageEpi_M*Mpro;
        % a(x+36,:) 	= cyto_DamageTis;
        % a(x+37,:) 	= wcyto_DamageTis_Th1*cyto_Th1;
        % a(x+38,:)	= wcyto_DamageTis_Th17*cyto_Th17;
        % a(x+39,:)	= wcyto_DamageTis_Th2*cyto_Th2;
        % a(x+40,:)  	= wcyto_DamageTis_Neut*Neut_LP;
        % a(x+41,:) 	= wcyto_DamageTis_M*Mpro;
        % a(x+42,:) 	= SPM_LP;
        % a(x+43,:)  	= apoNeut_LP*wSPMLPNeut;
        % a(x+44,:)  	= Meffero_LP*wSPMLPMeffero + sum(Mefferoa_LP)*wSPMLPMeffero;
        % a(x+45,:)   = cyto_TisRemod;
        % a(x+46,:)   = wcyto_TisRemod_Th2*cyto_Th2;
        % a(x+47,:)   = wcyto_TisRemod_M*Meff;
    
   
%--------------------------------------------------------------------------

end




%--------------------------------------------------------------------------

end