function [f,responseRate] = IBD_plotResponseRate(etas,CDEIS,options,ax)
%==========================================================================
% [f,responseRate] = IBD_plotResponseRate(etas,CDEIS,options,ax)
%==========================================================================
% Plot response rate over treatment effect extent
%--------------------------------------------------------------------------
%-- input
% etas:         treatment effect extent values
% CDEIS:      	CDEIS values (nr of etas x nr of patients)
% options:      additional options
%                   tikz (true/false)
%                   plot0:     	add 0/0 as additional point (default: true)
%                   colour:     colour vector
% ax:           (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output
% f:            figure
%==========================================================================

if ~exist('options','var') || isempty(options)
    options = struct;
end

if isfield(options,'colour') && ~isempty(options.colour)
    colour = options.colour;
else
    colour = IBD_myColours('responseRates');
end

fprintf('Plotting response rate over eta...\n')
if ~exist('ax','var') || isempty(ax)
    f = figure;
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

xValues	= etas(1,:);    % better: avoid to give more etas as input
yValues	= sum(CDEIS<4,2)'/size(CDEIS,2)*100;
responseRate = yValues;
if ~isfield(options,'plot0') || options.plot0
    xValues = [0,xValues];
    yValues = [0,yValues];
end
[~,idx]     = sort(xValues);

plot(ax,xValues(idx),yValues(idx),'-x','Color',colour)
hold on
%h = yline(ax,30);
%set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
%h = yline(ax,50);
%set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
if isfield(options,'tikz') && options.tikz
    xlabel(ax,'$\eta$','interpreter','latex')
    ylabel(ax,'Response rate [%]')
else
    xlabel(ax,'eta')
    ylabel(ax,'Response rate [%]')
end
ylim(ax,[0 100])

if isfield(options,'title')
    if isfield(options,'tikz') && options.tikz
        yl = ylim;
        xl = xlim;
        t = title(options.title,'Interpreter','latex','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
        text(xl(1),(yl(2)-yl(1))*1.22+yl(1),t.String,'HorizontalAlignment',t.HorizontalAlignment,'FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('')
    else
        title(options.title,'interpreter','latex')
    end
end

if makeFigure
    f = IBD_nicePlot(f);
else
    f = nan;
end

%--------------------------------------------------------------------------
end

