function [] = IBD_saveFigure(f,plotName,format,extraCode,lwd)
%==========================================================================
% [] = IBD_saveFigure(f,plotName,format,extraCode,lwd)
%==========================================================================
% Save figure to specified format (incl. tikzpicture)
%--------------------------------------------------------------------------
%-- input
% f:            figure
% plotName:  	name of the plot
% format:     	tikz | pdf | jpg | png
%               default: pdf
% extraCode:    optional: struct with additional code for tikzpicture
% lwd:          line width for tikzpicture (default: 1.5)
%==========================================================================

if ~exist('format','var')
    format = 'pdf';
end

if ~exist('extraCode','var') || isempty(extraCode)
    extraCode = struct;
end
if ~isfield(extraCode,'AtEnd')
    extraCode.AtEnd = {};
end
if ~isfield(extraCode,'AtEndOfAxis')
    extraCode.AtEndOfAxis = {};
end
if ~isfield(extraCode,'AtStart')
    extraCode.AtStart = {};
end
if ~isfield(extraCode,'Axis')
    extraCode.Axis = {};
end

plotName_full = ['Figures/',plotName,'_',date];

set(f,'Units','Inches');
pos = get(f,'Position');
set(f,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])

switch format
    case 'tikz'
        % Tikz settings
        if ~exist('lwd','var')
            lwd = 1.5;
        end
        f = tikzSettings(f,lwd);
        figure(f)
        matlab2tikz([plotName_full,'.tikz'],'showInfo',false,'width','\figW','height','\figH',...
            'extraCodeAtEnd',extraCode.AtEnd,'extraCode',extraCode.AtStart,...
            'extraCodeAtEndOfAxis',extraCode.AtEndOfAxis,...
            'extraAxisOptions','xticklabel style={/pgf/number format/fixed}',...
            'extraAxisOptions',extraCode.Axis)
        fprintf('Saved figure as %s.tikz\n',plotName_full)
    
    case 'pdf'        % Save as .pdf
        print(f,plotName_full,'-dpdf','-r0')
        fprintf('Saved figure as %s.pdf\n',plotName_full)
        
    case 'jpg'
        print(f,plotName_full,'-djpeg','-r0')
        fprintf('Saved figure as %s.jpg\n',plotName_full)
        
    case 'png'
        print(f,plotName_full,'-dpng','-r0')
        fprintf('Saved figure as %s.png\n',plotName_full)
end

end

%--------------------------------------------------------------------------

function f = tikzSettings(f,lwd)
    if ~exist('lwd','var')
        lwd = 1.5;
    end
%     if ~isempty(findobj(f,'Type','Legend'))
%         legend boxoff
%     end
    set(findobj(f,'Type','Line'),'LineWidth',lwd);
    set(findobj(f,'Type','ErrorBar'),'LineWidth',lwd);
    set(findobj(f,'Type','ConstantLine'),'LineWidth',lwd);
    set(findobj(f,'Type','Rectangle'),'LineWidth',lwd);
    set(findobj(f,'Type','Patch'),'LineWidth',lwd);
    
    % Constantline (not known by matlab2tikz)
    % --> transform to line object
    h = get(f,'children');   % subplots
    for i = 1:length(h)
        if strcmp(get(h(i),'Type'),'axes')
            cl = findobj(h(i),'Type','ConstantLine');
            hold(h(i),'on')
            for j = 1:length(cl)
                switch cl(j).InterceptAxis
                    case 'y'
                        l = plot(h(i),h(i).XLim,[cl(j).Value,cl(j).Value],'Color',cl(j).Color,'LineStyle',cl(j).LineStyle,'LineWidth',cl(j).LineWidth);
                    case 'x'
                        l = plot(h(i),[cl(j).Value,cl(j).Value],h(i).YLim,'Color',cl(j).Color,'LineStyle',cl(j).LineStyle,'LineWidth',cl(j).LineWidth);
                end
                % Put the line behind the other lines
                chH = get(h(i),'Children');
                set(h(i),'Children',[chH(1:end);chH(1)]);
                % Don't display in legend
                lAnnotation = get(l,'Annotation');
              	lLegendEntry = get(lAnnotation','LegendInformation');
             	set(lLegendEntry,'IconDisplayStyle','off')
            end
            delete(cl)
        end
    end
    
end
