%==========================================================================
% IBD_AnalyseIRindices
%==========================================================================
% (Visual) analysis of the input-response indices
% 25 June 2019
%--------------------------------------------------------------------------
%-- sources:
% Knöchel, J., Kloft, C., & Huisinga, W. (2018):
% Understanding and reducing complex systems pharmacology models based on a
% novel input–response index
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.IR)

%--------------------------------------------------------------------------

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------

if save2tikz
    printName   = IBD_translateToLatexCommands(individual_ref.I.stateName,true,true);
else
    printName   = individual_ref.assignPrintName(individual_ref.I);
end

%--------------------------------------------------------------------------
% Single
f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*2, 0.3*3]);
for o = 3:length(output_idx)
    output = individual_ref.I.stateName{output_idx(o)};
    fprintf('Plotting IR indices for output %s\n',output)
    
    s(o-2) = subplot(3,1,o-2);
    ax = gca;
    
    inset       = [];    % start and end of inset | [] --> no inset
    
    IBD_plotIRindices(IR{o},tstarValues,individual_ref,10,inset,save2tikz,ax);
    
    
    if save2tikz
        t(o-2) = title(ax,printName{output_idx(o)});
        xl = xlim;
        yl = ylim;
        t2(o-2) = text(xl(1),(yl(2)-yl(1))*1.22+yl(1),t(o-2).String,'HorizontalAlignment','left','FontSize',t(o-2).FontSize,'FontWeight',t(o-2).FontWeight,'Interpreter','latex');
        title('');
    else
        title(ax,printName{output_idx(o)})
    end
    l(o-2) = ax.Legend;
end

f = IBD_nicePlot(f);

% Make plots/legend same size for all subplots
for o = 2:length(s)
    s(o).Position(3) = s(1).Position(3);
    l(o).Position(1) = l(1).Position(1);
    if save2tikz
        xl = s(o).XLim;
        yl = s(o).YLim;
        t2(o).Position = [xl(1),(yl(2)-yl(1))*1.22+yl(1),0];
    end
end

% Save figure
if save2pdf
    IBD_saveFigure(f,['IR'],'pdf')
end
if save2tikz
    IBD_saveFigure(f,['IR'],'tikz')
end

%--------------------------------------------------------------------------



