%==========================================================================
% IBD_PlotCriticalNEC
%==========================================================================
% Visualisation of conditions of bacterial growth vs elimination
% 23 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual_ref  = IBD_referenceIndividual();
par             = individual_ref.par;
I               = individual_ref.I;

%--------------------------------------------------------------------------
% Critical NEC over Bact (commensal bacteria)
Bact = 10.^(0:0.1:9.9)';
b = 1;  % commensal
cNEC = par(I.pBact(b))*(1-Bact/par(I.NmaxBact))...
            .*(par(I.KmPhago)/par(I.phagoRec(b))+Bact)/par(I.VmaxPhago);

%--------------------------------------------------------------------------

f = figure;

% Plot critical NEC
loglog(Bact,cNEC,'Color',IBD_myColours('NEC'))
hold on

% Axis limits
xlim([Bact(1) Bact(end)])
ylim([10^5 10^8])
ax = gca;

% Fill area of bacterial growth
h = fill([Bact' Bact(end) Bact(1)],[cNEC' ax.YLim(1) ax.YLim(1)],IBD_myColours('NEC_growth'),'FaceAlpha',0.3,'EdgeColor','none');
hAnnotation = get(h,'Annotation');
hLegendEntry = get(hAnnotation','LegendInformation');
set(hLegendEntry,'IconDisplayStyle','off');
text(10^1,10^(log10(cNEC(1))-0.5),'bacterial growth','Color',IBD_myColours('NEC_growth'))

% Fill area of elimination
h = fill([Bact' Bact(end) Bact(1)],[cNEC' ax.YLim(end) ax.YLim(end)],IBD_myColours('NEC_elimination'),'FaceAlpha',0.3,'EdgeColor','none');
hAnnotation = get(h,'Annotation');
hLegendEntry = get(hAnnotation','LegendInformation');
set(hLegendEntry,'IconDisplayStyle','off');
text(10^1,10^(log10(cNEC(1))+0.5),'elimination','Color',IBD_myColours('NEC_elimination'))

% Add steady state of reference individual
plot(individual_ref.ssTable{'Bact_LP',1},individual_ref.ssTable{'Phago_LP',1},'Color',IBD_myColours('crosses3'),'Marker','x','MarkerSize',10)

xlabel('Bacterial concentration [1/mL]')
ylabel('NEC [1/mL]')
ax.XMinorTick = 'off';
ax.YMinorTick = 'off';

% Legend
legend('critical NEC','Location','north')

f = IBD_nicePlot(f);

extraCode.Axis = 'minor tick style={draw=none}';
if save2tikz
    IBD_saveFigure(f,'criticalNEC','tikz',extraCode)
end
if save2pdf
    IBD_saveFigure(f,'criticalNEC','pdf')
end

%--------------------------------------------------------------------------