%==========================================================================
% IBD_PlotSteadyState
%==========================================================================
% Barplot of steady state concentrations in comparison to literature values
% 10 March 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual_ref  = IBD_referenceIndividual();
par             = individual_ref.par;
I               = individual_ref.I;

%--------------------------------------------------------------------------
% Steady state table
ssTable = individual_ref.ssTable;
ssTable = ssTable(~isnan(ssTable.literature),:);
ssTable.tikzLabel = {'$\Tn$';'$\Tcm$';'$\BactLP$';'$\Neut$';'$\DCtot$';'$\Tem$';...
    '$\Monetot$';'$\Mtwotot$';'$\Mthreetot$';'$\Mfourtot$';'$\Mtot$';...
    '$\iTregeffLN$';'$\iTregeffLP$'};
ssTable.whichPlot = [1 1 4 3 2 1 2 2 2 2 2 1 1]';
stateOrder = {[5 4 3 2 1],[5 4 3 2 6 1],1,1};

% Plot as barplot
f = figure;
m = size(ssTable,1)+1*(max(ssTable.whichPlot)-1)+1;
n = 1;
lx = 0;
for i = 1:max(ssTable.whichPlot)
    ssX = ssTable(ssTable.whichPlot==i,:);
    ssX = ssX(stateOrder{i},:);
    l = size(ssX,1);
    subplot(m,n,(lx+1):lx+l);
    lx = lx+l+1;
    Y = ssX{:,[1 2]};
    if isrow(Y)
        Y = vertcat(Y,nan(size(Y)));
    end
    b = barh(Y,'grouped');
    b(2).FaceColor = [0 0.4 0];
    b(1).FaceColor = [0.6 0 0.4];
    if any(isnan(Y(:,1)))
        set(gca,'ylim',[0.5 1.5])
    end
    ax = gca;
    if save2tikz
        ax.YTickLabel = ssX.tikzLabel;
        ax.TickLabelInterpreter = 'latex';
        ax.YAxis.TickLength = [0 0];
    else
        ax.YTickLabel = ssX.Properties.RowNames;
    end
end
f = IBD_nicePlot(f);

if save2tikz
    IBD_saveFigure(f,'healthySteadyState','tikz')
end
if save2pdf
    fprintf('No pdf version for this plot available - only to be used in thesis.\n')
end

%--------------------------------------------------------------------------