%==========================================================================
% IBD_RunIRindices
%==========================================================================
% Calculation of the input-response indices
% 25 June 2019
% ! takes ~ 5 days to run !
%--------------------------------------------------------------------------
%-- sources:
% Knöchel, J., Kloft, C., & Huisinga, W. (2018):
% Understanding and reducing complex systems pharmacology models based on a
% novel input–response index
%==========================================================================

clear all

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

tic_IR      = tic;

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual_ref = IBD_referenceIndividual();
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual_ref.infection.epiDamage               = 0.5;
individual_ref.infection.tisDamage               = 0.5;

%--------------------------------------------------------------------------
% IR options
input       = 'injury';
output_idx  = [individual_ref.I.tissue,individual_ref.I.epi,individual_ref.I.Th_tot_LP,individual_ref.I.M_tot_LP,individual_ref.I.Neut_LP];
perturbFac  = [0.5 0.8 1.2 1.5];

% First 7 days: every hour
% Day 7 to 100: twice per day
tstarValues = unique([0:1:(7*24),(7*24):12:(100*24)]);

% Run IR indices
IR          = IBD_IR(input,output_idx,tstarValues,perturbFac,individual_ref(1));

% Save output data
fullFileName = ['Data/IR_',date];
save(fullFileName,'IR','tstarValues','input','output_idx','individual_ref')
fprintf('\nIR finished; saved as %s.mat; took %.2f h.\n',fullFileName,toc(tic_IR)/60/60);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.IR = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
