%==========================================================================
% IBD_RunLSA
%==========================================================================
% Local sensitivity analysis, time-resolved
% 23 March 2021
%--------------------------------------------------------------------------
%-- sources:
% Zi, Z. (2011):
% Sensitivity analysis approaches applied to systems biology mode
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.LSA,'LSA')

individual_ref = IBD_referenceIndividual();
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual_ref.infection.epiDamage               = 1;
individual_ref.infection.tisDamage               = 1;

%--------------------------------------------------------------------------
% Parameters to analyse
% Omit integers
omitPars    = [I.egressThreshold,I.egressThresholdm,I.nTn,I.nTm,I.ssEpi,...                     % integer parameters
    I.ssTis,I.ssMucus,I.wPhagoLPqDC,I.wPhagoLPrDC,I.wPhagoLPtDC,I.wPhagoLPsDC,I.wPhagoLPNeut];  % = 1
parIdx      = setdiff(I.allPar,omitPars);

%--------------------------------------------------------------------------
% LSA options
output  = {'Thtot','Mtot','Neut'};
LSA     = IBD_LSAoverTime(output,individual_ref,parIdx);

% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'LSA','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
