%==========================================================================
% IBD_SimExtracellular
%==========================================================================
% Simulation of infections with extracellular bacteria
% 8 July 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','extracellular'};
individual(1) = IBD_referenceIndividual(options);
I = individual(1).I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1).infection.Bact                    = {'extracellular'};
individual(1).infection.initial                 = 0;
individual(1).title                             = 'initial = 0';

individual(2) = individual(1);
individual(2).infection.initial                 = 0.001;
individual(2).title                             = 'initial = 0.001';

individual(3) = individual(1);
individual(3).infection.initial                 = 0.01;
individual(3).title                             = 'initial = 0.01';

individual(4) = individual(1);
individual(4).infection.initial                 = 0.1;
individual(4).title                             = 'initial = 0.1';

% individual(5) = individual(1);
% individual(5).infection.initial                 = 0.1;
% individual(5).title                             = 'Th KO';
% individual(5).ko.type                           = {'Th'};
% individual(5).ko.extent                         = 1;
% individual(5).ko.ss                             = true;

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)                 = IBD_runInfection(individual(ind));
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview_woBarrier',individual(1));
f = IBD_plotIndAndSave(individual,p,'extracellular_initialLoads',save2pdf,save2tikz);

%--------------------------------------------------------------------------