%==========================================================================
% IBD_SimInjury
%==========================================================================
% Simulation of mucosal injury (difrerent extents)
% 20 June 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual(1) = IBD_referenceIndividual();
I = individual(1).I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1).infection.epiDamage               = 0;
individual(1).infection.tisDamage               = 0;
individual(1).title                             = '0/0';

individual(2) = individual(1);
individual(2).infection.epiDamage               = 1;
individual(2).infection.tisDamage               = 0;
individual(2).title                             = '1/0';

individual(3) = individual(1);
individual(3).infection.epiDamage               = 0;
individual(3).infection.tisDamage               = 1;
individual(3).title                             = '0/1';

individual(4) = individual(1);
individual(4).infection.epiDamage               = 1;
individual(4).infection.tisDamage               = 1;
individual(4).title                             = '1/1';

individual(5) = individual(1);
individual(5).infection.epiDamage               = 0.5;
individual(5).infection.tisDamage               = 0.5;
individual(5).title                             = '0.5/0.5';

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)                 = IBD_runInfection(individual(ind));
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview',individual(1));
p(1).titleUp = 1.5;
p(2).titleUp = 1.5;
p(2).legendPos = 'northeast';
p(3).titleUp = 1.5;
f = IBD_plotIndAndSave(individual,p,'injury_extents',save2pdf,save2tikz);

%--------------------------------------------------------------------------