%==========================================================================
% IBD_SimNeutKO
%==========================================================================
% Simulation of salmonella infection and mucosal injury for neutrophil 
% knockout
% 26 March 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

KOtype = {'Neut_rec'};

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
i = 1;
individual(i)                                   = individual_ref;
individual(i).infection.Bact                    = {'STm'};
individual(i).infection.initial                 = 0.01;
individual(i).title                             = {'salmonellae',''};

i = 2;
individual(i)                                   = individual(1);
individual(i).ko.type                           = KOtype;
individual(i).ko.extent                         = 1;
individual(i).ko.ss                             = true;
individual(i).title                             = {'salmonellae','100\,% KO'};

i = 3;
individual(i)                                   = individual_ref;
individual(i).infection.epiDamage               = 1;
individual(i).infection.tisDamage               = 1;
individual(i).title                             = {'injury',''};

i = 4;
individual(i)                                   = individual(3);
individual(i).ko.type                           = KOtype;
individual(i).ko.extent                         = 1;
individual(i).ko.ss                             = true;
individual(i).title                             = {'injury','100\,% KO'};

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)         = IBD_runInfection(individual(ind));
    idx = find(individual(ind).T/24<1);
    for t = 1:150
        idx = [idx;find(individual(ind).T/24>=t,1)];
    end
    idx = unique(idx);
    individual(ind).T       = individual(ind).T(idx);
    individual(ind).X       = individual(ind).X(idx,:);
    individual(ind).Xadd    = individual(ind).Xadd(idx,:);
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview_woBarrier',individual_ref);
f = IBD_plotIndAndSave(individual,p,'KO_Neut',save2pdf,save2tikz);

%--------------------------------------------------------------------------