%==========================================================================
% IBD_SimOverview
%==========================================================================
% Simulation of salmonella infection and mucosal injury with overview plot
% 4 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm','extracellular'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).infection.Bact                    = {'STm'};
individual(1).infection.initial                 = 0.01;
individual(1).title                             = 'salmonellae';

individual(2)                                   = individual_ref;
individual(2).infection.epiDamage               = 1;
individual(2).infection.tisDamage               = 1;
individual(2).title                             = 'injury';

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind));
end

%==========================================================================
%% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview',individual_ref);
f = IBD_plotIndAndSave(individual,p,'overview',save2pdf,save2tikz);

%--------------------------------------------------------------------------