%==========================================================================
% IBD_SimSalmonella
%==========================================================================
% Simulation of salmonella infections
% 7 June 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm'};
individual(1) = IBD_referenceIndividual(options);
I = individual(1).I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1).infection.Bact                    = {'STm'};
individual(1).infection.initial                 = 0;
individual(1).title                             = 'initial = 0';

individual(2) = individual(1);
individual(2).infection.initial                 = 0.0001;
individual(2).title                             = 'initial = 0.0001';

individual(3) = individual(1);
individual(3).infection.initial                 = 0.001;
individual(3).title                             = 'initial = 0.001';

individual(4) = individual(1);
individual(4).infection.initial                 = 0.01;
individual(4).title                             = 'initial = 0.01';

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)                 = IBD_runInfection(individual(ind));
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

% Overview
p = IBD_plotDatabase('overview_woBarrier',individual(1));
f = IBD_plotIndAndSave(individual,p,'STm_initialLoads',save2pdf,save2tikz);
clear p

% Infected macrophages
default         = IBD_plotSpecReference(individual(1));
default.xunit   = 'd';
default.ylabel  = 'Conc. [1/mL]';
default.titlePos= 'left';
default.grid    = false;

p(1)          	= default;
p(1).states     = {{'MP1_LP','MP1a_LP','MP1ai_LP',...
                    'MP2_LP','MP2a_LP','MP2ai_LP',...
                    'MP3_LP','MP3a_LP','MP3ai_LP',...
                    'MP4_LP','MP4a_LP','MP4ai_LP',...
                    'Meffero_LP','Mefferoa_LP','Mefferoai_LP'},...
                    {'MP1inf_LP','MP2inf_LP','MP3inf_LP','MP4inf_LP','Mefferoinf_LP'}};
p(1).legend     = {'uninfected','infected'};
p(1).main       = 'Infected macrophages';
p(1).legendPos  = 'northeast';
p(2)            = default;
p(2).states     = {{'MP1inf_LP','MP2inf_LP','MP3inf_LP','MP4inf_LP','Mefferoinf_LP'},'Th1_eff_LP','Tem1_LP'};
p(2).legend     = {'infected','Th1_eff (salm)','Tem1 (salm)'};
p(2).tikzLegend = {'infected','$\Thoneeffx{salm.}$','$\Temonex{salm.}$'};
p(2).main       = 'Control by Th1';
p(2).legendPos  = 'northeast';
p(2).Bact       = {'STm'};
f = IBD_plotIndAndSave(individual(4),p,'STm_infectedM',save2pdf,save2tikz);

%--------------------------------------------------------------------------