%==========================================================================
% IBD_SimThFractions
%==========================================================================
% Simulation of different fractions of Th1/2/17
% 21 June 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual(1) = IBD_referenceIndividual();
I = individual(1).I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1).infection.epiDamage               = 1;
individual(1).infection.tisDamage               = 1;
individual(1).title                             = '1/3 - 1/3 - 1/3';

individual(2) = individual(1);
individual(2).par(I.theta1host)                 = 1;
individual(2).par(I.theta2host)                 = 0;
individual(2).par(I.theta17host)                = 0;
individual(2).par(I.theta1bact(I.commensal))  	= 1;
individual(2).par(I.theta2bact(I.commensal))   	= 0;
individual(2).par(I.theta17bact(I.commensal))   = 0;
individual(2).title                             = '1 - 0 - 0';

individual(3) = individual(1);
individual(3).par(I.theta1host)                 = 0;
individual(3).par(I.theta2host)                 = 1;
individual(3).par(I.theta17host)                = 0;
individual(3).par(I.theta1bact(I.commensal))  	= 0;
individual(3).par(I.theta2bact(I.commensal))   	= 1;
individual(3).par(I.theta17bact(I.commensal))  	= 0;
individual(3).title                             = '0 - 1 - 0';

individual(4) = individual(1);
individual(4).par(I.theta1host)                 = 0;
individual(4).par(I.theta2host)                 = 0;
individual(4).par(I.theta17host)                = 1;
individual(4).par(I.theta1bact(I.commensal))  	= 0;
individual(4).par(I.theta2bact(I.commensal))   	= 0;
individual(4).par(I.theta17bact(I.commensal)) 	= 1;
individual(4).title                             = '0 - 0 - 1';

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)                 = IBD_runInfection(individual(ind));
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview',individual(1));
f = IBD_plotIndAndSave(individual,p,'KO_ThFractions',save2pdf,save2tikz);

%--------------------------------------------------------------------------