%==========================================================================
% IBD_SimThKO
%==========================================================================
% Simulation of salmonella infection and mucosal injury for Th function 
% knockout
% 26 June 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

KOtype = {'Th'};

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).infection.Bact                    = {'STm'};
individual(1).infection.initial                 = 0.01;
individual(1).title                             = {'salmonellae',''};

individual(2)                                   = individual(1);
individual(2).ko.type                           = KOtype;
individual(2).ko.extent                         = 0.7;
individual(2).ko.ss                             = true;
individual(2).title                             = {'salmonellae','70\,% KO'};

individual(3)                                   = individual(1);
individual(3).ko.type                           = KOtype;
individual(3).ko.extent                         = 1;
individual(3).ko.ss                             = true;
individual(3).title                             = {'salmonellae','100\,% KO'};

individual(4)                                   = individual_ref;
individual(4).infection.epiDamage               = 1;
individual(4).infection.tisDamage               = 1;
individual(4).title                             = {'injury',''};

individual(5)                                   = individual(4);
individual(5).ko.type                           = KOtype;
individual(5).ko.extent                         = 1;
individual(5).ko.ss                             = true;
individual(5).title                             = {'injury','100\,% KO'};

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)                 = IBD_runInfection(individual(ind));
    idx = find(individual(ind).T/24<1);
    for t = 1:150
        idx = [idx;find(individual(ind).T/24>=t,1)];
    end
    idx = unique(idx);
    individual(ind).T       = individual(ind).T(idx);
    individual(ind).X       = individual(ind).X(idx,:);
    individual(ind).Xadd    = individual(ind).Xadd(idx,:);
end
    
%--------------------------------------------------------------------------
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

p = IBD_plotDatabase('overview_woBarrier',individual_ref);
f = IBD_plotIndAndSave(individual,p,'KO_Th',save2pdf,save2tikz);

%--------------------------------------------------------------------------