%==========================================================================
% VarConstraints_MAIN
%==========================================================================
% Variability & constraints: estimate and visualise a logistic-normal
% distribution (to use for the fractions of Th1/2/17)
% 24 June 2019
%--------------------------------------------------------------------------
%-- sources:
% Tsamandouras et al., 2015: Incorporation of stochastic variability in
% mechanistic population pharmacokinetic models: handling the physiological
% constraints using normal transformations
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

clear all

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

save2tikz   = false;
save2pdf    = true;

%--------------------------------------------------------------------------
% Parameter estimation
% Parameters to estimate: Mu, Sigma

% Target:
mean = [1/3 1/3 1/3];
var  = [0.1 0.1 0.1].^2;

[MuEst,SigmaEst] = VarConstraints_parEstimation(mean,var);

[MeanFinal,VarFinal,CovFinal] = VarConstraints_meanVarCov(MuEst,SigmaEst);
fprintf('Estimation results:\n')
for i = 1:length(MeanFinal)
    fprintf('theta %i: mu = %.3f, sd = %.3f\n',i,MeanFinal(i),sqrt(VarFinal(i)))
end

[f1,~] = VarConstraints_plotPDF(MuEst,SigmaEst);
[g1,parLogistic] = VarConstraints_histLogistic(MuEst,SigmaEst);

%--------------------------------------------------------------------------

% Results of parameter estimation using
% target.mean = [1/3 1/3 1/3];
% target.var  = [0.1 0.1 0.1].^2
% for host
% and
% target.mean = [1/3 1/3 1/3];
% target.var  = [0.2 0.2 0.2].^2
% for bacteria
% are saved in VarConstraints_referenceParameters

