function [f,par] = VarConstraints_histLogistic(Mu,Sigma)
%==========================================================================
% [f,par] = VarConstraints_HistLogistic(Mu,Sigma)
%==========================================================================
% Sample from the logistic-normal distribution and plot histograms for 
% all parameters
%--------------------------------------------------------------------------
%-- input:
% Mu:       mean of normal distribution
% Sigma:    sigma of normal distribution
%--------------------------------------------------------------------------
%-- output:
% f:        figure
% par:      parameter samples
%==========================================================================

N       = 100000;
par     = nan(N,length(Mu)+1);
fprintf('Logistic-normal distribution (sampling):\n')

for individual = 1:N
    theta = VarConstraints_sampleLogistic(Mu,Sigma);
    par(individual,:) = theta;
end

f = figure;
for i = 1:size(par,2)
    ax(i) = subplot(2,2,i);
    ksdensity(par(:,i),'BandWidth',0.05)
    title(['\theta_',int2str(i)])
    lwd         = 3;
    fontsize    = 18;
    xlim([0 1])
    set(findobj(gcf,'Type','Line'),'LineWidth',lwd);
    %xlabel(['\theta_',int2str(i)])
    set(gca,'FontSize',fontsize)
    set(gca,'LineWidth',lwd-1)

    fprintf('theta %i: mu = %.3f, sd = %.3f\n',i,mean(par(:,i)),std(par(:,i)))
end
linkaxes(ax(:),'y')

end
