function [Mean,Var,Cov] = VarConstraints_meanVarCov(Mu,Sigma)
%==========================================================================
% [Mean,Var,Cov] = MeanVarCov(Mu,Sigma)
%==========================================================================
% Calculation of mean, variance and covariance of logistic-normal
% distribution based on parameter of normal distribution
%--------------------------------------------------------------------------
%-- input:
% Mu:       mean of normal distribution
% Sigma:    sigma of normal distribution
%--------------------------------------------------------------------------
%-- output:
% Mean:  	mean
% Var:      variance
% Cov:      variance-covariance matrix
%==========================================================================

k           = length(Mu);
Mean        = nan(1,k+1);
Var         = nan(1,k+1);
Cov         = nan(k+1,k+1);
for i = 1:k
    Mean(i) = VarConstraints_trapezoidal(@(theta) VarConstraints_pdfFunction(theta,Mu,Sigma)*theta(i) ,2,[0 1; 0 1]');
    Var(i)  = VarConstraints_trapezoidal(@(theta) VarConstraints_pdfFunction(theta,Mu,Sigma)*(theta(i)-Mean(i))^2 ,2,[0 1; 0 1]');
end
for i = 1:k
    for j = 1:k
        Cov(i,j) = VarConstraints_trapezoidal(@(theta) VarConstraints_pdfFunction(theta,Mu,Sigma)*(theta(i)-Mean(i))*(theta(j)-Mean(j)) ,2,[0 1; 0 1]');
    end
end
Mean(k+1) = 1-sum(Mean(1:k));
Var(k+1)  = sum(Var(1:k))+2*sum(sum(triu(Cov(1:k,1:k),1)));
for i = 1:k
    Cov(i,k+1) = -Var(i)-sum(Cov(i,[1:i-1,i+1:k]));
    Cov(k+1,i) = Cov(i,k+1);
end
Cov(k+1,k+1) = Var(k+1);

end

