function [Mu,Sigma] = VarConstraints_parEstimation(mean,var)
%==========================================================================
% [Mu,Sigma] = VarConstraints_parEstimation(mean,var)
%==========================================================================
% Sample from the logistic-normal distribution
%--------------------------------------------------------------------------
%-- input:
% mean:     target mean
% var:      target variance
%--------------------------------------------------------------------------
%-- output:
% Mu:       mean of normal distribution
% Sigma:    sigma of normal distribution
%==========================================================================

mean    = reshape(mean,1,[]);
var     = reshape(var,1,[]);

fprintf('Parameter estimation... ')
tic_start   = tic;
x0          = [0 0 1 1 0];    % mu1, mu2, sigma1, sigma2, cov
lb          = [-Inf -Inf 0 0 -Inf];
ub          = [Inf Inf Inf Inf Inf];
target.mean = mean;
target.var  = var;
x           = lsqnonlin(@(x) VarConstraints_objFct(x,target),x0,lb,ub);
Mu          = x(1:2)';
Sigma       = [x(3),x(5);x(5),x(4)];
fprintf('took %.1f seconds.\n',toc(tic_start))

% Check if Sigma is positive definite:
[~,p] = chol(Sigma);
if p
    warning('Estimated Sigma matrix is not positive definite.')
end

end

