function f = VarConstraints_pdfFunction(theta,Mu,Sigma)
%==========================================================================
% f = VarConstraints_pdfFunction(theta,Mu,Sigma)
%==========================================================================
% Probability density function of logistic-normal distribution
%--------------------------------------------------------------------------
%-- input:
% theta:    values at which pdf shall be evaluated (length(theta) = k)
% Mu:       mean of normal distribution
% Sigma:    sigma of normal distribution
%--------------------------------------------------------------------------
%-- output:
% f:        function value
%==========================================================================

% Probability density function of the logistic-normal generalisation

if sum(theta)>=1 || any(theta==0)
    f = 0;
else
    k           = length(theta);
    theta(k+1)  = 1-sum(theta);
    
    Z = log(theta(1:k)./theta(k+1))';
    f = 1/sqrt(det(2*pi*Sigma)) * 1/prod(theta) * exp(-1/2*(Z-Mu)'*(Sigma\(Z-Mu)));
end

end

