function [f,heat] = VarConstraints_plotPDF(Mu,Sigma)
%==========================================================================
% [f,heat] = plotPDF(Mu,Sigma)
%==========================================================================
% Plot of probability density function of logistic-normal distribution (2d)
%--------------------------------------------------------------------------
%-- input:
% Mu:       mean of normal distribution
% Sigma:    sigma of normal distribution
%--------------------------------------------------------------------------
%-- output:
% f:        figure
% heat:     heatmap matrix
%=========================================================================

thetaValues = 0:0.01:1;
heat = nan(length(thetaValues),length(thetaValues));
for i = 1:length(thetaValues)
    for j = 1:length(thetaValues)
        if thetaValues(i) + thetaValues(j) >1
            heat(i,j) = 0;
        else
            heat(i,j) = VarConstraints_pdfFunction([thetaValues(i),thetaValues(j)],Mu,Sigma);
        end
    end
end
f           = figure;
lwd         = 3;
fontsize    = 18;
contour(thetaValues,thetaValues,heat,'LineWidth',lwd)
hold on
plot([0 1],[1 0],'k')       % diagonal line defining the possible space
set(findobj(gcf,'Type','Line'),'LineWidth',lwd);
set(gca,'FontSize',fontsize)
set(gca,'LineWidth',lwd-1)
xlabel('\theta_1')
ylabel('\theta_2')
box off
%surf(heat)

end

