function Thfractions = VarConstraints_referenceParameters()
%==========================================================================
% Thfractions = VarConstraints_referenceParameters()
%==========================================================================
% Mu and Sigma for Th fractions by host and bacteria
% for theta = [1/3 1/3 1/3] (both) and
% var = [0.1 0.1 0.1].^2 (host) / var = [0.2 0.2 0.2].^2 (bacteria)
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% primPar:   	primary parameter vector
%==========================================================================

Thfractions.MuHost      = [ 0.950725485857453;  0.950747407442757]*1e-5;
Thfractions.SigmaHost   = [ 0.289895074009276,  0.144976616514470;  0.144976616514470,  0.289895072428163];
Thfractions.MuBact      = [-0.255507766276628; -0.255507766276628]*1e-3;
Thfractions.SigmaBact   = [ 1.482925629742981,  0.741304261310860;  0.741304261310860,  1.482925631345487];

Thfractions.assignThetaHost = @(model) assignThetaHost(model);
Thfractions.assignThetaBact = @(model) assignThetaBact(model);

%--------------------------------------------------------------------------

end

%==========================================================================
% LOCAL FUNCTIONS

% Sampling and assigning Th fractions parameters for host
function [model,thetaHost] = assignThetaHost(model)
I                       = model.I;
thetaHost               = VarConstraints_sampleLogistic(model.Thfractions.MuHost,model.Thfractions.SigmaHost);
model.par(I.theta1host)	= thetaHost(1);
model.par(I.theta2host)	= thetaHost(2);
model.par(I.theta17host)= thetaHost(3);
model.Thfractions.thetaHost = thetaHost;
end

% Sampling and assigning Th fractions parameters for bacteria
function [model,thetaBact] = assignThetaBact(model)
I                       = model.I;
thetaBact               = VarConstraints_sampleLogistic(model.Thfractions.MuBact,model.Thfractions.SigmaBact);
model.par(I.theta1bact)	= thetaBact(1);
model.par(I.theta2bact)	= thetaBact(2);
model.par(I.theta17bact)= thetaBact(3);
model.Thfractions.thetaBact = thetaBact;
end
