function int = VarConstraints_trapezoidal(f,d,limits)
%==========================================================================
% int = VarConstraints_trapezoidal(f,d,limits)
%==========================================================================
% Trapezoidal rule as integration approximation in 1d and 2d
%--------------------------------------------------------------------------
%-- input:
% f:        Probability density function (takes d arguments)
% d:        Dimension: 1 | 2
% limits:   2xd matrix of limits of integrals, out to in
%--------------------------------------------------------------------------
%-- output:
% int:   	result of integration
%==========================================================================

if numel(limits)==2
    limits = reshape(limits,2,1);
end
assert(all(size(limits)==[2,d]),'Number of limits does not fit the dimension.\n');

N = 100;

switch d
    
    case 1
        xk      = linspace(limits(1,1),limits(2,1),N);
        deltax  = (limits(2,1)-limits(1,1))/(N-1);
        int     = deltax/2*( f(xk(1)) + 2*sum(arrayfun(f,xk(2:(end-1)))) + f(xk(end)) );
        
    case 2
        xk      = linspace(limits(1,1),limits(2,1),N);
        yk      = linspace(limits(1,2),limits(2,2),N);
        deltax  = (limits(2,1)-limits(1,1))/(N-1);
        deltay  = (limits(2,2)-limits(1,2))/(N-1);       
        int     = deltax*deltay/4*(...
            f([xk(1),yk(1)])+f([xk(1),yk(end)])+f([xk(end),yk(1)])+f([xk(end),yk(end)])...
            + 2*sum(arrayfun(@(x) f([x,yk(1)]),xk(2:(end-1))))...
            + 2*sum(arrayfun(@(x) f([x,yk(end)]),xk(2:(end-1))))...
            + 2*sum(arrayfun(@(y) f([xk(1),y]),xk(2:(end-1))))...
            + 2*sum(arrayfun(@(y) f([xk(end),y]),xk(2:(end-1))))...
            + 4*sum(arrayfun(@(y) sum(arrayfun(@(x) f([x,y]),xk(2:(end-1)))),yk(2:(end-1))))...
            );
        
    otherwise
        error('Dimension >= 3 currently not implemented.\n')
end

end
