%==========================================================================
% IBD_AnalyseCombinationTherapies
%==========================================================================
% Analyse combination therapies
% 10 February 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load IBD population data
load(fileNameList.CombinePatientPopulation)

% Only consider patients with CDEIS>6 in IBD - included in study
IBDpop = IBDpop(IBDpop.included,:);

% Load correlations between responsiveness
load(fileNameList.CorrelationsOfResponsiveness)

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
response = table('Size',[length(treatments_combi),2],'VariableTypes',repmat({'double'},[1,2]),...
        'VariableNames',{'union','combi'},'RowNames',treatments_combi);

% Translate combination treatment to corresponding single treatments
for i = 1:length(treatments_combi)
    x = regexp(treatments_combi{i},'x[A-Z]');
    single = {treatments_combi{i}(1:x-1),treatments_combi{i}(x+1:end)};
    for j = 1:length(single)
        if sum(strcmp(single{j},treatments_single))
            % ok
        elseif sum(strcmp(lower(single{j}),treatments_single))
            single{j} = lower(single{j});
        elseif strcmp(single{j},'JAK')
            single{j} = 'TNF';
        else
            warning('Combination treatment could not be translated to single treatments.')
        end
    end
    singleTreatments.(treatments_combi{i}) = single;
end

% Expected response rate based on correlations between single treatments
for i = 1:length(treatments_combi)
    response{treatments_combi{i},'union'} = union.r30{singleTreatments.(treatments_combi{i}){1},singleTreatments.(treatments_combi{i}){2}};
end

% Combination treatment response rate
for i = 1:length(treatments_combi)
    response{treatments_combi{i},'combi'} = responseRates.(treatments_combi{i}){1,1};
end

response = sortrows(response,'combi','descend');

%--------------------------------------------------------------------------
% Check which patients
for i = 1:length(treatments_combi)
    AB  = ['response_',treatments_combi{i},'_ssEOT_',etaNames.(treatments_combi{i}){1}];
    A   = ['response_',singleTreatments.(treatments_combi{i}){1},'_ssEOT_',selectedEtaName.r30.(singleTreatments.(treatments_combi{i}){1})];
    B   = ['response_',singleTreatments.(treatments_combi{i}){2},'_ssEOT_',selectedEtaName.r30.(singleTreatments.(treatments_combi{i}){2})];
    
    Pstring = dec2bin(0:(2^3)-1);
    P = Pstring-'0';     % all combinations of true/false for A, B and AB
    patTab = table('Size',[size(P,1),6],'VariableTypes',repmat({'double'},[1,6]),...
        'VariableNames',{'code','A','B','AB','sum','fraction'});
    patTab.code = Pstring;
    patTab.A  = P(:,1);
    patTab.B  = P(:,2);
    patTab.AB = P(:,3);
    for j = 1:size(patTab,1)
        patTab.sum(j) = sum(IBDpop.(A)==patTab.A(j) & IBDpop.(B)==patTab.B(j) & IBDpop.(AB)==patTab.AB(j));
    end
    patTab.fraction = patTab.sum/size(IBDpop,1);
    patientCategories.(treatments_combi{i}) = patTab;
end

%--------------------------------------------------------------------------
% Stacked barplots of responders and non-responders to the combination treatments
for i = 1:length(treatments_combi)
    f = figure;
    patTab = patientCategories.(treatments_combi{i});
    y = [patTab.fraction(patTab.AB==1)'; patTab.fraction(patTab.AB==0)'];
    y = y(:,end:-1:1);
    bar(categorical({'responders','nonresponders'},{'responders','nonresponders'}),y,'stacked')
    title(treatments_combi{i})
    legendCode = patTab.code(patTab.AB==1,1:2);
    l = legend(legendCode(end:-1:1,:));
    ylim([0 1])
    f = IBD_nicePlot(f);
    if save2tikz || save2pdf
        IBD_saveFigure(f1,['combination_',treatments_combi{i}],save2tikz)
    end
end

%--------------------------------------------------------------------------