%==========================================================================
% IBD_AnalyseStateComparisonResponders
%==========================================================================
% Print results of comparison of pre-treatment steady state distributions 
% between responders and non-responders to single treatments
% 10 January 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CompareStatesResponders)

N = 5;

%--------------------------------------------------------------------------
% Response rate 30 %
scenarios = t_cor_30.Properties.VariableNames;

par30 = table;
ppar30 = table;

for i = 1:length(scenarios)
    scenario = scenarios{i};
    if all(isnan(t_cor_30.(scenario)))
        continue
    end
    
    parList_cor = t_cor_30(1:individual_ref.I.nrOfStates,scenario);     % no summed states
    parList_cor.absCor = abs(parList_cor.(scenario));
    parList_cor = sortrows(parList_cor,'absCor','descend','MissingPlacement','last');
    
    par30.(scenario) = parList_cor(1:N,1);
    par30.(scenario){:,1} = round(par30.(scenario){:,1},2);
    
    pparList_cor = p_cor_30(1:individual_ref.I.nrOfStates,scenario);     % no summed states
    pparList_cor = sortrows(pparList_cor,1,'ascend','MissingPlacement','last');
    
    ppar30.(scenario) = pparList_cor(1:N,1);
    ppar30.(scenario){:,1} = round(ppar30.(scenario){:,1},4);
    
    parList_KS = t_KS_30(:,scenario);
    parList_KS = sortrows(parList_KS,scenario,'descend','MissingPlacement','last');
end

%--------------------------------------------------------------------------
% Response rate 50 %
scenarios = t_cor_50.Properties.VariableNames;

par50 = table;
ppar50 = table;

for i = 1:length(scenarios)
    scenario = scenarios{i};
    if all(isnan(t_cor_50.(scenario)))
        continue
    end
    
    parList_cor = t_cor_50(1:individual_ref.I.nrOfStates,scenario);     % no summed states
    parList_cor.absCor = abs(parList_cor.(scenario));
    parList_cor = sortrows(parList_cor,'absCor','descend','MissingPlacement','last');
    
    par50.(scenario) = parList_cor(1:N,1);
    par50.(scenario){:,1} = round(par50.(scenario){:,1},2);
    
    pparList_cor = p_cor_50(1:individual_ref.I.nrOfStates,scenario);     % no summed states
    pparList_cor = sortrows(pparList_cor,1,'ascend','MissingPlacement','last');
    
    ppar50.(scenario) = pparList_cor(1:N,1);
    ppar50.(scenario){:,1} = round(ppar50.(scenario){:,1},4);
    
    parList_KS = t_KS_50(:,scenario);
    parList_KS = sortrows(parList_KS,scenario,'descend','MissingPlacement','last');
end

% Result: par30, par50, ppar30, ppar50
