%==========================================================================
% IBD_ClinicalIBDpopulation
%==========================================================================
% Exlude IBD patients with CDEIS<6 from the population
% Adjust FCP parameter
% 13 November 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','ss0','ssMI','IBDtype','individual_ref');

N_IBD = size(par,2);

%--------------------------------------------------------------------------
% Exclude patients with CDEIS lower than threshold (at post-trigger ss)
CDEISthreshold = 6;

CDEIS = IBD_CDEIS(ssMI,individual_ref.I);
include = CDEIS>=CDEISthreshold;

fprintf('Including %i/%i patients (%.2f%%) into the clinical study population (CDEIS higher than %.0f)\n',sum(include),N_IBD,sum(include)/N_IBD*100,CDEISthreshold)

par     = par(:,include);
ss0     = ss0(:,include);
ssMI    = ssMI(:,include);
IBDtype = IBDtype(include);

% Adjust FCP parameter so that the median FCP equals 250
FCP = IBD_calcFCPss(ssMI,par,individual_ref.I);
par(individual_ref.I.epsilonFCP,:) = par(individual_ref.I.epsilonFCP,:)/median(FCP)*250;
individual_ref.par(individual_ref.I.epsilonFCP) = individual_ref.par(individual_ref.I.epsilonFCP)/median(FCP)*250;

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'par','ss0','ssMI','IBDtype','individual_ref','include')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------