%==========================================================================
% IBD_CombinePatientPopulation
%==========================================================================
% Combine information on patients
% 4 December 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
% Parameters, ss before trigger, ss after trigger, IBD type
S       = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','ss0','ssMI','IBDtype','individual_ref');
par     = S.par;
ss0     = S.ss0;
ssMI    = S.ssMI;
N_IBD   = size(S.par,2);
individual_ref = S.individual_ref;
I       = individual_ref.I;

IBDpop          = table('Size',[N_IBD 0]);
IBDpop.IBDtype  = S.IBDtype';

% Necessary parameter changes
S                       = load(fileNameList.CombineNecessaryParChanges);
minimalPar              = S.minimalPar;
IBDpop.minimalParIdx    = S.minimalParIdx';
IBDpop.nrOfMinimalPar   = cellfun(@length,IBDpop.minimalParIdx);

% Treatment and responsiveness
responseIdx                     = struct;
responseIdx.exclude             = 0;
responseIdx.nonresponder        = 1;
responseIdx.responder_relapse   = 2;
responseIdx.responder_longTerm	= 3;
inclusionCDEIS = 6;
mucosalHealing = 4;

treatments = fieldnames(fileNameList.constantTreatment)';

% Single vs combination treatments
combi               = cellfun(@(x) length(x),regexp(treatments,'x[A-Z]'));
treatments_single   = treatments(~combi);
treatments_combi    = treatments(~~combi);

for i = 1:length(treatments)
    
    S = load(fileNameList.constantTreatment.(treatments{i}),'ssT1','ssT2','ssEOT','ssPT','options','effects','individual_ref');
    ssT1.(treatments{i}) 	= S.ssT1;
    ssT2.(treatments{i})    = S.ssT2;
    ssEOT.(treatments{i})   = S.ssEOT;
    ssPT.(treatments{i})    = S.ssPT;
    
  	eta = S.options.etas;
    nrOfEtas = size(eta,2);
    etas.(treatments{i}) = eta;
    theseEtaNames = {};
    for e = 1:nrOfEtas
        theseEtaNames{e} = ['eta_',strrep(strrep(strrep(char(join(strrep(cellstr(num2str(eta(:,e)))',' ',''),'/')),'-','m'),'.','o'),'/','_')];
    end
    etaNames.(treatments{i}) = theseEtaNames;
    
    options.(treatments{i})  = S.options;
     
    % Calculation of CDEIS score
    CDEIS = struct;
    CDEIS.ss0           = IBD_CDEIS(ss0,I)';
    CDEIS.ssMI          = IBD_CDEIS(ssMI,I)';
    for e = 1:nrOfEtas
        CDEIS.ssT1(e,:)     = IBD_CDEIS(squeeze(S.ssT1(:,e,:)),I);
        CDEIS.ssT2(e,:)     = IBD_CDEIS(squeeze(S.ssT2(:,e,:)),I);
        CDEIS.ssEOT(e,:)  	= IBD_CDEIS(squeeze(S.ssEOT(:,e,:)),I);
        CDEIS.ssPT(e,:)     = IBD_CDEIS(squeeze(S.ssPT(:,e,:)),I);
    end
    
    % CDEIS before treatment, inclusion in study
    if i == 1       % same for all treatments (before start of treatment)
        IBDpop.CDEIS_ss0 	= CDEIS.ss0';
        IBDpop.CDEIS_ssMI	= CDEIS.ssMI';
        IBDpop.included     = IBDpop.CDEIS_ssMI>inclusionCDEIS;
    end
    
    for e = 1:nrOfEtas
        % CDEIS and response (mucosal healing) at different time points (obs timepoints 1 and 2, end of treatment, post-treatment)
        IBDpop.(['CDEIS_',treatments{i},'_ssT1_',theseEtaNames{e}])      = CDEIS.ssT1(e,:)';
        IBDpop.(['response_',treatments{i},'_ssT1_',theseEtaNames{e}]) 	= ...
            IBDpop.(['CDEIS_',treatments{i},'_ssT1_',theseEtaNames{e}])<mucosalHealing;
        IBDpop.(['CDEIS_',treatments{i},'_ssT2_',theseEtaNames{e}])     = CDEIS.ssT2(e,:)';
        IBDpop.(['response_',treatments{i},'_ssT2_',theseEtaNames{e}])  = ...
            IBDpop.(['CDEIS_',treatments{i},'_ssT2_',theseEtaNames{e}])<mucosalHealing;
        IBDpop.(['CDEIS_',treatments{i},'_ssEOT_',theseEtaNames{e}])     = CDEIS.ssEOT(e,:)';
        IBDpop.(['response_',treatments{i},'_ssEOT_',theseEtaNames{e}])  = ...
            IBDpop.(['CDEIS_',treatments{i},'_ssEOT_',theseEtaNames{e}])<mucosalHealing;
        IBDpop.(['CDEIS_',treatments{i},'_ssPT_',theseEtaNames{e}])      = CDEIS.ssPT(e,:)';
        IBDpop.(['response_',treatments{i},'_ssPT_',theseEtaNames{e}])   = ...
            IBDpop.(['CDEIS_',treatments{i},'_ssPT_',theseEtaNames{e}])<mucosalHealing;
        
        % Classification of response (responders vs non-responders)
        colName = ['responseIdx_',treatments{i},'_',theseEtaNames{e}];
        IBDpop.(colName)     = nan(N_IBD,1);
        idx = IBDpop.included;                                                      % response before treatment
        IBDpop{idx,colName} = repmat(responseIdx.exclude,[sum(idx),1]);                             % --> exclude from study                                                   
        idx = ~IBDpop.included...                                                   % no response before treatment
            & ~IBDpop.(['response_',treatments{i},'_ssEOT_',theseEtaNames{e}]);   	% no response at end of treatment
        IBDpop{idx,colName} = repmat(responseIdx.nonresponder,[sum(idx),1]);                     	% --> non-responders (EOT)
        idx = ~IBDpop.included...                                                   % no response before treatment
            & IBDpop.(['response_',treatments{i},'_ssEOT_',theseEtaNames{e}])...  	% response at end of treatment
            & IBDpop.(['response_',treatments{i},'_ssPT_',theseEtaNames{e}]);      	% response post-treatment
       	IBDpop{idx,colName} = repmat(responseIdx.responder_longTerm,[sum(idx),1]);                	% --> responders (EOT), long term
        idx = ~IBDpop.included...                                                   % no response before treatment
            & IBDpop.(['response_',treatments{i},'_ssEOT_',theseEtaNames{e}])...  	% response at end of treatment
            & ~IBDpop.(['response_',treatments{i},'_ssPT_',theseEtaNames{e}]);    	% no response post-treatment
      	IBDpop{idx,colName} = repmat(responseIdx.responder_relapse,[sum(idx),1]);                 	% --> responders (EOT), relapse
    end
    
end

%--------------------------------------------------------------------------
% Response rates per treatment and eta
N_patients = sum(IBDpop.included,1);
responseRates = struct;
for i = 1:length(treatments)
    responseRates.(treatments{i}) = array2table(zeros(length(etaNames.(treatments{i})),1),'VariableNames',{treatments{i}},'RowNames',etaNames.(treatments{i}));
    for j = 1:length(etaNames.(treatments{i}))
        responseRates.(treatments{i}){j,1} = sum(IBDpop.(['response_',treatments{i},'_ssEOT_',etaNames.(treatments{i}){j}]) & IBDpop.included)/N_patients*100;
    end
end

%--------------------------------------------------------------------------
% Save data
fullFileName = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'par','ss0','ssMI','N_IBD','minimalPar','ssT1','ssT2','ssEOT','ssPT','etas','etaNames','options','treatments','treatments_single','treatments_combi','responseRates','IBDpop','individual_ref')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------