%==========================================================================
% IBD_CombinePopulation
%==========================================================================
% Combine sampled populations and average the time course
% 21 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')
finishedRuns = fileNameList.SamplePopulation(cellfun(@(x) isempty(x),strfind(fileNameList.SamplePopulation,'in_progress')));

classDefinition = IBD_centroids();
Xaverage        = struct;
Xpre            = struct;
Xpost           = struct;
N_ind           = struct;
Xaverage_IBDtype= struct;

% Load and combine data
for i = classDefinition.I.allClasses
    thisClass 	= classDefinition.I.className{i};
    fprintf('Combining data for class %s:\n',thisClass)
    par         = [];
    ss0         = [];
    ssMI        = [];
    X_full   	= [];
    IBDtype     = [];
    for j = 1:length(finishedRuns)
        fprintf('\tLoading %i/%i...\n',j,length(finishedRuns))
        S       = load(strrep(finishedRuns{j},'xxx',thisClass));
        par     = cat(2,par,S.par);
        ss0     = cat(2,ss0,S.ss0);
        ssMI	= cat(2,ssMI,S.ssMI);
        X_full 	= cat(3,X_full,S.X);
        IBDtype = [IBDtype,S.IBDtype];
        if ~exist('individual_ref','var')
            individual_ref  = S.individual_ref;
        else
            assert(all(individual_ref.par==S.individual_ref.par),'Reference individuals are not the same!');
        end
    end
    
    % Average time course: q5, q50, q95
    fprintf('\tAveraging...\n')
    X                       = quantile(X_full,[0.05,0.5,0.95],3);
    N_indPerClass           = size(X_full,3);
    Xaverage.(thisClass)    = X;
    Xpre.(thisClass)        = X_full(1,:,:);
    Xpost.(thisClass)    	= X_full(end,:,:);
    N_ind.(thisClass)       = N_indPerClass;
    
    fullFileName    = ['Data/',thisFile,'_',date,'_',thisClass,'.mat'];
    
    if strcmp(thisClass,'IBD') && length(unique(IBDtype))>1
        
        % Average time course per IBD type
        XperIBDtype = cell([1 length(unique(IBDtype))]);
        for t = unique(IBDtype)
            XperIBDtype{t} = quantile(X_full(:,:,IBDtype==t),[0.05,0.5,0.95],3);
        end
        
        % Average time course per group of IBD types
        IBDtypeGroups = {[1 2 3],[4 5 6],[7 8 9 10]};
        XperIBDtypeGroup = cell([1 length(IBDtypeGroups)]);
        for t = 1:length(IBDtypeGroups)
            XperIBDtypeGroup{t} = quantile(X_full(:,:,ismember(IBDtype,IBDtypeGroups{t})),[0.05,0.5,0.95],3);
        end
        
        % Save data
        fprintf('\tSaving...\n')
        save(fullFileName,'par','ss0','ssMI','IBDtype','X','XperIBDtype','XperIBDtypeGroup','N_indPerClass','individual_ref')
        averageFileName = ['Data/',thisFile,'_averageIBD_',date,'.mat'];
        save(averageFileName,'par','IBDtype','XperIBDtype','XperIBDtypeGroup','individual_ref')
        fprintf('Saved as %s\n',averageFileName);
        
    else
    
        % Save data
        fprintf('\tSaving...\n')
        save(fullFileName,'par','ss0','ssMI','IBDtype','X','N_indPerClass','individual_ref')
        
    end
    fprintf('Saved as %s\n',fullFileName);
end

averageFileName = ['Data/',thisFile,'_average_',date,'.mat'];
save(averageFileName,'Xaverage','N_ind','individual_ref')
fprintf('Saved as %s\n',averageFileName);

ssFileName      = ['Data/',thisFile,'_ss_',date,'.mat'];
save(ssFileName,'Xpre','Xpost','individual_ref')
fprintf('Saved as %s\n',ssFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = strrep(fullFileName,thisClass,'xxx');
fileNameList.([thisFile,'_average'])    = averageFileName;
fileNameList.([thisFile,'_averageIBD']) = ['Data/',thisFile,'_averageIBD_',date,'.mat'];
fileNameList.([thisFile,'_ss'])         = ssFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------


