%==========================================================================
% IBD_CompareClasses
%==========================================================================
% Compare parameter and steady state distributions between classes
% 11 September 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
par     = struct;
ss0     = struct;
ssMI    = struct;
for i = classDefinition.I.allClasses
    thisClass           = classDefinition.I.className{i};
    S                   = load(strrep(fileNameList.CombinePopulation,'xxx',thisClass));
    par.(thisClass)     = S.par;
	ss0.(thisClass)     = S.ss0;
	ssMI.(thisClass)	= S.ssMI;
end
individual_ref          = S.individual_ref;

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Compare parameter distributions between classes (vs healthy)
parComparison = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1),'VariableNames',classDefinition.I.className(2:end),'RowNames',IBD_uniqueParName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing parameter distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfPar
        [~,~,parComparison{p,thisClass}] = kstest2(par.healthy(p,:),par.(thisClass)(p,:));
    end
end

% Plot most different between healthy and IBD as histogram...
[~,parIdx] = sortrows(parComparison,'IBD','descend');
N = 25;
f1a = IBD_plotParDist(par,individual_ref,{'healthy','IBD'},parIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f1a,'ParHist_IBD',save2tikz)
end
% ... and as cumulative probability distribution plot
f1b = IBD_plotCumulativeDist(par,individual_ref,{'healthy','IBD'},parIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f1b,'ParCumDist_IBD',save2tikz)
end

%--------------------------------------------------------------------------
% Compare steady state distributions between classes (vs healthy)
stateComparison = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1),'VariableNames',classDefinition.I.className(2:end),'RowNames',IBD_uniqueStateName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing steady state distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfStatesAdd
        [~,~,stateComparison{p,thisClass}] = kstest2(ss0.healthy(p,:),ss0.(thisClass)(p,:));
    end
end

% Plot most different between healthy and IBD as histogram...
[~,stateIdx] = sortrows(stateComparison,'IBD','descend');
N = 25;
% make nice!
plotIdx = stateIdx([1 2 9 10 11 15 16 21 22 24 25 27 28 29 32 33 36 39 47 54 70 71 72 73 76]);
f2a = IBD_plotParDist(ss0,individual_ref,{'healthy','IBD'},plotIdx,classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f2a,'ssHist_IBD',save2tikz)
end
% ... and as cumulative probability distribution plot
f2b = IBD_plotCumulativeDist(ss0,individual_ref,{'healthy','IBD'},plotIdx,classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f2b,'ssCumDist_IBD',save2tikz)
end

%--------------------------------------------------------------------------
% Median steady state values per class
medianSS0 = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses+1),'VariableNames',[{'reference'},classDefinition.I.className],'RowNames',IBD_uniqueStateName(individual_ref.I));
medianSS0.reference = individual_ref.Xadd_ss';
for i = classDefinition.I.allClasses
    thisClass = classDefinition.I.className{i};
    for p = 1:individual_ref.I.nrOfStatesAdd
        medianSS0{p,thisClass} = median(ss0.(thisClass)(p,:));
    end
end

%--------------------------------------------------------------------------