%==========================================================================
% IBD_CompareIBDtypes
%==========================================================================
% Compare parameter distributions between IBD types
% Return: measure of difference for each parameter between healthy and
% other classes, par values for 20 most different parameters
% 28 September 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(strrep(fileNameList.CombinePopulation,'xxx','IBD'));

%--------------------------------------------------------------------------
% Compare parameter distributions between types (Pearson's correlation)
parCor                  = array2table(nan(individual_ref.I.nrOfPar,2),'VariableNames',{'t','p'},'RowNames',IBD_uniqueParName(individual_ref.I));
[parCor.t,parCor.p]     = corr(par',IBDtype');
parCor.absCor           = abs(parCor.t);
parCor.idx              = (1:size(parCor,1))';
[parCor,idx]            = sortrows(parCor,'absCor','descend','MissingPlacement','last');

N = 20;                 % return all parameters that are among the lowest N p-values
idx_rest                = setdiff(1:individual_ref.I.nrOfPar,idx(1:N));
par(idx_rest,:)         = zeros(length(idx_rest),size(par,2));
par                     = sparse(par);

%--------------------------------------------------------------------------
% Compare pre-trigger steady state distributions between types (Pearson's correlation)
ss0Cor                  = array2table(nan(individual_ref.I.nrOfStatesAdd,2),'VariableNames',{'t','p'},'RowNames',IBD_uniqueStateName(individual_ref.I));
[ss0Cor.t,ss0Cor.p]     = corr(ss0',IBDtype');
ss0Cor.absCor           = abs(ss0Cor.t);
ss0Cor.idx              = (1:size(ss0Cor,1))';
[ss0Cor,idx]            = sortrows(ss0Cor,'absCor','descend','MissingPlacement','last');

N = 20;                 % return all parameters that are among the lowest N p-values
idx_rest                = setdiff(1:individual_ref.I.nrOfStatesAdd,idx(1:N));
ss0(idx_rest,:)         = zeros(length(idx_rest),size(ss0,2));
ss0                     = sparse(ss0);

%--------------------------------------------------------------------------
% Compare post-trigger steady state distributions between types (Pearson's correlation)
ssMICor                 = array2table(nan(individual_ref.I.nrOfStatesAdd,2),'VariableNames',{'t','p'},'RowNames',IBD_uniqueStateName(individual_ref.I));
[ssMICor.t,ssMICor.p]   = corr(ssMI',IBDtype');
ssMICor.absCor          = abs(ssMICor.t);
ssMICor.idx             = (1:size(ssMICor,1))';
[ssMICor,idx]           = sortrows(ssMICor,'absCor','descend','MissingPlacement','last');

N = 20;                 % return all parameters that are among the lowest N p-values
idx_rest                = setdiff(1:individual_ref.I.nrOfStatesAdd,idx(1:N));
ssMI(idx_rest,:)        = zeros(length(idx_rest),size(ssMI,2));
ssMI                    = sparse(ssMI);

%--------------------------------------------------------------------------
% CDEIS
CDEIS = IBD_CDEIS(ssMI,individual_ref.I);

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'parCor','ss0Cor','ssMICor','par','ss0','ssMI','CDEIS','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------