%==========================================================================
% IBD_CompareParameters
%==========================================================================
% Compare parameter distributions between classes
% Return: measure of difference for each parameter between healthy and
% other classes, par values for 20 most different parameters
% 11 September 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
for i = classDefinition.I.allClasses
    thisClass     	= classDefinition.I.className{i};
    S           	= load(strrep(fileNameList.CombinePopulation,'xxx',thisClass),'par','individual_ref');
    par.(thisClass) = S.par;
end
individual_ref      = S.individual_ref;

%--------------------------------------------------------------------------
% Compare parameter distributions between classes (vs healthy)
t_KS    = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueParName(individual_ref.I));
p_KS    = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueParName(individual_ref.I));
t_cor   = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueParName(individual_ref.I));
p_cor   = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueParName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing parameter distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfPar
        [~,p_KS{p,thisClass},t_KS{p,thisClass}]    = kstest2(par.healthy(p,:),par.(thisClass)(p,:));
    end
    [t_cor.(thisClass),p_cor.(thisClass)] = corr([par.(thisClass)';par.healthy'],[ones(size(par.(thisClass),2),1);zeros(size(par.healthy,2),1)]);
end

% IBD vs chronic inflammation/infection
[t_cor.IBDvs_chronic_inflammation,p_cor.IBDvs_chronic_inflammation] = corr([par.IBD';par.chronic_inflammation'],[ones(size(par.IBD,2),1);zeros(size(par.chronic_inflammation,2),1)]);
[t_cor.IBDvs_chronic_infection,   p_cor.IBDvs_chronic_infection]    = corr([par.IBD';par.chronic_infection'   ],[ones(size(par.IBD,2),1);zeros(size(par.chronic_infection,   2),1)]);

% IBD vs healthy
p_table                          	= p_cor(:,'IBD');
p_table.Properties.VariableNames	= {'p_cor'};
p_table.p_KS                        = p_KS.IBD;
p_table.t_cor                       = t_cor.IBD;
p_table.t_KS                        = t_KS.IBD;
p_table.absCor                      = abs(p_table.t_cor);
[p_table_sortedCor,idx_cor]         = sortrows(p_table,'absCor','descend','MissingPlacement','last');
[p_table_sortedKS, idx_KS]          = sortrows(p_table,'t_KS','descend','MissingPlacement','last');

N = 20;     % return all parameters that are among the lowest N p values in either measure
idx_all = union(idx_cor(1:N),idx_KS(1:N));

returnPar.healthy               = par.healthy;
returnPar.IBD                   = par.IBD;
idx_rest                        = setdiff(1:individual_ref.I.nrOfPar,idx_all);
returnPar.healthy(idx_rest,:)   = zeros(length(idx_rest),size(par.healthy,2));
returnPar.IBD(idx_rest,:)       = zeros(length(idx_rest),size(par.IBD,2));
returnPar.healthy               = sparse(returnPar.healthy);
returnPar.IBD                   = sparse(returnPar.IBD);
par                             = returnPar;

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'p_cor','t_cor','p_KS','t_KS','p_table','par','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------