%==========================================================================
% IBD_IBDsteadyStates
%==========================================================================
% Check if the steady states are different for different extents of mucosal
% injury
% 11 September 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','ss0','ssMI','X','IBDtype','individual_ref');

N_IBD = size(par,2);

MI = [1:-0.1:0.1;...    % epiDamage
      1:-0.1:0.1];      % tisDamage

%--------------------------------------------------------------------------
% Calculate steady states after all mucosal injury scenarios (dependent on IBD type)
ssSame = nan(length(individual_ref.Xadd_ss_after),size(MI,2),N_IBD);

for ind = 1:N_IBD
    fprintf('Individual %i/%i:\t\n',ind,N_IBD)
    
    for j = 1:(11-IBDtype(ind))
        individual_ind              = individual_ref;
        individual_ind.epiDamage    = MI(1,j);
        individual_ind.tisDamage    = MI(2,j);
        individual_ind.par          = par(:,ind)';
        individual_ind.X_ss       	= ss0(1:individual_ref.I.nrOfStates,ind)';
        
        individual_ind              = IBD_runSteadyState(individual_ind);
        individual_ind              = IBD_runInfection(individual_ind,true);
        
        ssSame(:,j,ind)             = individual_ind.Xadd_ss_after'./ssMI(:,ind);
    end
end

ssSame(individual_ref.I.MP1inf_LP:individual_ref.I.Mefferoinf_LP,:,:) = nan;        % irrelevant

%--------------------------------------------------------------------------
% Check if all steady states are the same for each individual
allssSame = nan(1,N_IBD);
for ind = 1:N_IBD
    allssSame(ind) = all(all((ssSame(:,:,ind)>0.95 & ssSame(:,:,ind)<1.05) | isnan(ssSame(:,:,ind))));
end

% Command line output
fprintf('In %.2f %% of the patients, all steady states are the same.\n',sum(allssSame)/length(allssSame)*100)

% Per IBD types (as type 10 only has a single steady state...)
load(fileNameList.CombinePopulation_averageIBD)
fprintf('Per IBD type:\n')
for i = 1:max(IBDtype)
    allssSame_x = allssSame(IBDtype==i);
    fprintf('\tIBD type %i: %.2f%% of patients\n',i,sum(~allssSame_x))
end


%--------------------------------------------------------------------------












