%==========================================================================
% IBD_IBDtypeAnalysis
%==========================================================================
% Analyse distribution of and differences between IBD types
% 28 September 2019

% ALT

%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombinePopulation_average)

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Distribution of IBD types
f1 = figure;
histogram(IBDtype,0.5:1:10.5)
f1 = IBD_nicePlot(f1);
tabulate(IBDtype)
if save2tikz || save2pdf
    IBD_saveFigure(f1,'IBDtypeDist',save2tikz)
end

%--------------------------------------------------------------------------
% Differences in time course between IBD types

% Save q5, q50, q95 as individuals as input for plot function
individual(1:3*length(XperIBDtypeGroup)) = individual_ref;
split = nan(1,3*length(XperIBDtypeGroup));
for i = 1:length(XperIBDtypeGroup)
    individual((i-1)*3+1).Xadd  = XperIBDtypeGroup{i}(:,:,2);
    individual((i-1)*3+2).Xadd  = XperIBDtypeGroup{i}(:,:,1);
    individual((i-1)*3+3).Xadd  = XperIBDtypeGroup{i}(:,:,3);
    split((i-1)*3+(1:3))        = i;
end

p   = IBD_plotDatabase('overview_classes',individual_ref,struct('tikz',save2tikz));
f1	= IBD_plotIndividuals(individual,p,split,true);
if save2tikz || save2pdf
    IBD_saveFigure(f1,'Overview_IBDtypeGroups',save2tikz)
end

%--------------------------------------------------------------------------
% Differences in parameters between IBD types 1 and 10
parComparison = array2table(nan([size(par,1),1]),'RowNames',IBD_uniqueParName(individual_ref.I));
for p = 1:individual_ref.I.nrOfPar
    [~,parComparison{p,1}] = kstest2(par(p,IBDtype==1),par(p,IBDtype==10));
end

% Plot most different as histogram
[~,parIdx] = sortrows(parComparison,'Var1');
N = 25;
newPar                      = struct;
whichClasses                = cell([1 length(unique(IBDtype))]);
classDefinition             = struct;
classDefinition.I           = struct;
classDefinition.I.className = cell([1 length(unique(IBDtype))]);
for t = unique(IBDtype)
    newPar.(['type',int2str(t)]) = par(:,IBDtype==t);
    whichClasses{t} = ['type',int2str(t)];
    classDefinition.I.className{t} = ['type',int2str(t)];
end

f2 = IBD_plotParDist(newPar,individual_ref,whichClasses,parIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f2,'ParHist_IBDtypes',save2tikz)
end

%--------------------------------------------------------------------------
% Differences in pre-IBD steady state between IBD types 1 and 10
stateComparison = array2table(nan([individual_ref.I.nrOfStatesAdd,1]),'RowNames',IBD_uniqueStateName(individual_ref.I));
for p = 1:individual_ref.I.nrOfStatesAdd
    [~,stateComparison{p,1}] = kstest2(ss0(p,IBDtype==1),ss0(p,IBDtype==10));
end

% Plot most different as histogram
[~,stateIdx] = sortrows(stateComparison,'Var1');
newss0                      = struct;
for t = unique(IBDtype)
    newss0.(['type',int2str(t)]) = ss0(:,IBDtype==t);
end

f3 = IBD_plotParDist(newss0,individual_ref,whichClasses,stateIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f3,'ss0Hist_IBDtypes',save2tikz)
end

%--------------------------------------------------------------------------
