%==========================================================================
% IBD_InfluenceOfHillProActM
%==========================================================================
% Analysis of the influence of the parameter HillProActM (the only 
% parameter that can on its own result in IBD)
% 13 September 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
tic_start = tic;

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual_ref = IBD_referenceIndividual();
I = individual_ref.I;

%--------------------------------------------------------------------------
% Mucosal injury
MI = [1:-0.1:0.1;...    % epiDamage
      1:-0.1:0.1];      % tisDamage

% Reference individual
individual_ref.infection.epiDamage      = MI(1,1);
individual_ref.infection.tisDamage      = MI(2,1);
individual_ref.timespan                 = unique([0:1:24,24:12:7*24,7*24:24:individual_ref.timespan(end)]);
individual_ref                          = IBD_runSteadyState(individual_ref);
individual_ref                          = IBD_runInfection(individual_ref,true);

% Index for saved states of time course
inflIdx                                 = [I.Neut_LP,I.M_tot_LP,I.Th_tot_LP,I.Bact_LP,I.epi,I.tissue,I.mucus];
individual_ref.Ired.inflIdx             = inflIdx;
individual_ref.Ired.stateName           = individual_ref.I.stateName(inflIdx);
for i = 1:length(individual_ref.Ired.stateName)
    individual_ref.Ired.(individual_ref.Ired.stateName{i}) = i;
end
individual_ref.Ired.nrOfStates          = i;
individual_ref.Ired.allStates           = 1:individual_ref.Ired.nrOfStates;

classDefinition                         = IBD_centroids(individual_ref);

Hill = 1:10;

N = length(Hill);

%--------------------------------------------------------------------------
% Characteristics to save
class   = nan(1,N);                                             % class
IBDtype = nan(1,N);                                             % IBD type (only for class IBD)

%--------------------------------------------------------------------------
% Simulation
for ind = 1:N
    
    fprintf('Individual %i/%i:\t',ind,N)
    individual_tmp = individual_ref;
    
    % Sample parameters
    individual_tmp.par(I.HillProActM) = Hill(ind);
    
    % Rerun steady state
    individual_tmp      = IBD_runSteadyState(individual_tmp);
    if individual_tmp.problems
        
    else
        
        % Run infection scenario
        individual_tmp  = IBD_runInfection(individual_tmp,true);
        
        % Classify
        class(ind)      = IBD_classifyInflammation(individual_tmp.Xadd_ss',individual_tmp.Xadd_ss_after',classDefinition,individual_ref);

        % Determine IBD type/the extent of mucosal injury needed as stimulus
        isIBDpatient  	= class(ind) == classDefinition.I.IBD;
        IBDtype(ind) 	= size(MI,2);       % start with least severe type, i.e. highest stimulus resulting in IBD
        while isIBDpatient && IBDtype(ind) > 1
            individual_tmp.infection.epiDamage  = MI(1,end-IBDtype(ind)+2);
            individual_tmp.infection.tisDamage  = MI(2,end-IBDtype(ind)+2);
            individual_tmp                      = IBD_runInfection(individual_tmp,true);
            class_tmp                           = IBD_classifyInflammation(individual_tmp.Xadd_ss',individual_tmp.Xadd_ss_after',classDefinition,individual_ref);
            isIBDpatient                        = class_tmp == classDefinition.I.IBD;
            if isIBDpatient
                IBDtype(ind)                    = IBDtype(ind) - 1;
            end
        end
        
    end
end

%--------------------------------------------------------------------------
% Results
table(Hill',class',IBDtype','VariableNames',{'HillProActM','class','IBDtype'})


%--------------------------------------------------------------------------
% Compare to parameters in IBD types
% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
S = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','IBDtype');

for i = unique(S.IBDtype)
    fprintf('IBD type %i: median = %.2f\n',i,median(S.par(I.HillProActM,S.IBDtype==i)))
end





%--------------------------------------------------------------------------

