%==========================================================================
% IBD_NecessaryParChangesForIBD
%==========================================================================
% Identify necessary parameter changes for IBD
% This analysis has to be run for all files of SamplePopulation
% 27 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

if ~isfield(fileNameList,thisFile)
    fileNameList.(thisFile) = repmat({'empty'},size(fileNameList.SamplePopulation));
end

% This analysis has to be run for all files of SamplePopulation
% This script analyses the first one that is still empty
n = find(strcmp(fileNameList.(thisFile),'empty'),1);
thisFileName = [thisFile,int2str(n)];

% Adapt file name list
fileNameList.(thisFile){n} = [thisFileName,'_in_progress'];
save('Data/fileNameList.mat','fileNameList')

fprintf('Necessary parameter changes for sample population nr %i...\n',n)

% Load data
load(strrep(fileNameList.SamplePopulation{n},'xxx','IBD'),'par','individual_ref');
classDefinition = IBD_centroids(individual_ref);
N_IBD           = size(par,2);

%--------------------------------------------------------------------------
% Order of parameter changes

% Correlation between parameters and IBD --> to sort parameters
healthy = load(strrep(fileNameList.SamplePopulation{n},'xxx','healthy'),'par');
a = [par';healthy.par'];
b = [ones(size(par,2),1);zeros(size(healthy.par,2),1)];
correlation = abs(corr([par';healthy.par'],[ones(size(par,2),1);zeros(size(healthy.par,2),1)]));
[~,idx_order] = sort(correlation,'descend','MissingPlacement','last');

%--------------------------------------------------------------------------
% Back-elimination
minimalPar              = nan(size(par));            % minimally changed parameters for all IBD individuals
minimalParIdx           = cell(1,size(par,2));       % indices of changed parameters for all IBD individuals
classWhenSetBack        = nan(size(par));
rounds                  = nan(1,N_IBD);
idx_start               = find(isnan(correlation) | correlation==0);

parfor ind = 1:N_IBD
    
    classWhenSetBack_ind= nan(size(par,1),1);
    
    idx_left            = idx_order;
    par_ind             = par(:,ind)';
    
    % Step 1:
    % Parameters with correlation = 0 or nan
    idx_delete          = idx_start;
    [~,class_ind,par_ind,idx_left] = tryToDelete(par_ind,idx_delete,idx_left,individual_ref,classDefinition);
    classWhenSetBack_ind(idx_delete) = class_ind;
    
    % Step 2:
    % In the order of lowest correlation to highest correlation, try to set back parameters to reference values
    % Repeat until no more parameter can be changed back
    z = 0;
    deletedInThisRound = true;
    while deletedInThisRound
        z = z+1;
        deletedInThisRound = false;
        for i = length(idx_left):-1:1
            idx_delete      = idx_left(i);
            [deleted,class_ind,par_ind,idx_left] = tryToDelete(par_ind,idx_delete,idx_left,individual_ref,classDefinition);
            fprintf('Individual %i, round %i: Try to change back %s: class = %i, deleted: %i\n',ind,z,individual_ref.I.parName{idx_delete},class_ind,deleted)
            classWhenSetBack_ind(idx_delete) = class_ind;
            deletedInThisRound = max(deletedInThisRound,deleted);
        end
    end
    
    minimalPar(:,ind)   = par_ind';
    minimalParIdx{ind}  = idx_left;
    rounds(ind)       	= z;
    classWhenSetBack(:,ind) = classWhenSetBack_ind;
    
end

% Save
fullFileName    = ['Data/',thisFileName,'_',date,'.mat'];
save(fullFileName,'minimalPar','minimalParIdx','classWhenSetBack','rounds','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile){n} = fullFileName;
save('Data/fileNameList.mat','fileNameList')


%==========================================================================
% LOCAL FUNCTIONS

% Change parameter back, run, classify, based on result change parameter or keep it
function [deleted,class,par_ind,idx_left] = tryToDelete(par_ind,idx_delete,idx_left,individual_ref,classDefinition)

individual_tmp                  = individual_ref;
individual_tmp.par              = par_ind;
individual_tmp.par(idx_delete)  = individual_ref.par(idx_delete);

% Rerun steady state
individual_tmp = IBD_runSteadyState(individual_tmp);
if individual_tmp.problems
    class       = 0;
else
    % Run infection scenario
    individual_tmp = IBD_runInfection(individual_tmp,true);
    
    % Classify
    class    	= IBD_classifyInflammation(individual_tmp.Xadd_ss',individual_tmp.Xadd_ss_after',classDefinition,individual_ref);
end

if class == classDefinition.I.IBD
    par_ind                     = individual_tmp.par;
    deleted                     = true;
	idx_left                    = setdiff(idx_left,idx_delete,'stable');
else
    deleted                     = false;
end

end

%--------------------------------------------------------------------------