%==========================================================================
% IBD_PlotPopulationSteadyStateRespondersCytoS1PR
%==========================================================================
% Plot steady state concentration distributions for responders to cytokine
% inhibitor and S1PR modulator
% 19 April 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombinePopulation_ss)
load(fileNameList.CompareStatesCytoS1PRResponders)
load(fileNameList.ClinicalIBDpopulation,'include')

Xpre.IBD    = Xpre.IBD(:,:,include);
Xpost.IBD   = Xpost.IBD(:,:,include);

classDefinition = IBD_centroids();
Ired = individual_ref.Ired;

%--------------------------------------------------------------------------
% Plot
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

f = figure;
states = {'Th_tot_LP','M_tot_LP','Neut_LP','epi'};
labels = {'cytokine','S1PR'};
colours = [IBD_myColours('cytokineInhibitor');IBD_myColours('S1PRmodulator')];
printName = individual_ref.assignPrintName(individual_ref.I);

s = [];

for i = 1:length(states)
    % Pre-trigger steady state
    s(1,i) = subplot(2,4,i);
    h = boxplot([squeeze(Xpre.IBD(1,Ired.(states{i}),respondersCyto));squeeze(Xpre.IBD(1,Ired.(states{i}),respondersS1PR))]',[zeros(1,sum(respondersCyto)),ones(1,sum(respondersS1PR))],...
        'Labels',labels,...
        'Colors',colours,...
        'MedianStyle','line',...
        'OutlierSize',0.1,...
        'Symbol','',...
        'Widths',0.7);
    xtickangle(45)
    h1 = handle(h);
    h1(1,1).LineStyle = '-';
    h1(1,2).LineStyle = '-';
    h1(2,1).LineStyle = '-';
    h1(2,2).LineStyle = '-';
    ylim([0 max([h1(1,1).YData(2),h1(1,2).YData(2)])*1.1])
    if save2tikz
        t = title(IBD_translateToLatexCommands(states{i},true,true,false),'Interpreter','latex');
        xl = xlim;
        yl = ylim;
        text(xl(1),(yl(2)-yl(1))*1.4+yl(1),t.String,'HorizontalAlignment','left','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('');
    else
        title(states{i})
    end
    if i==1
        text(-0.5,max([h1(1,1).YData(2),h1(1,2).YData(2)])/2,{'Pre-','trigger'},'HorizontalAlignment','right','FontWeight','bold')
    end
    
    % Post-trigger steady state
    s(2,i) = subplot(2,4,i+4);
    h = boxplot([squeeze(Xpost.IBD(1,Ired.(states{i}),respondersCyto));squeeze(Xpost.IBD(1,Ired.(states{i}),respondersS1PR))]',[zeros(1,sum(respondersCyto)),ones(1,sum(respondersS1PR))],...
        'Labels',labels,...
        'Colors',colours,...
        'MedianStyle','line',...
        'OutlierSize',0.1,...
        'Symbol','',...
        'Widths',0.7);
    xtickangle(45)
    h1 = handle(h);
    h1(1,1).LineStyle = '-';
    h1(1,2).LineStyle = '-';
    h1(2,1).LineStyle = '-';
    h1(2,2).LineStyle = '-';
    ylim([0 max([h1(1,1).YData(2),h1(1,2).YData(2)])*1.1])
    if save2tikz
        t = title(IBD_translateToLatexCommands(states{i},true,true,false),'Interpreter','latex');
        xl = xlim;
        xl
        yl = ylim;
        text(xl(1),(yl(2)-yl(1))*1.4+yl(1),t.String,'HorizontalAlignment','left','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('')
    else
        title(states{i})
    end
    if i==1
        text(-0.5,max([h1(1,1).YData(2),h1(1,2).YData(2)])/2,{'Post-','trigger'},'HorizontalAlignment','right','FontWeight','bold')
    end
end

f = IBD_nicePlot(f);

plotName = 'populationSteadyState';
if save2pdf
    IBD_saveFigure(f,plotName,'pdf')
end
if save2tikz
    IBD_saveFigure(f,plotName,'tikz')
end


%--------------------------------------------------------------------------