%==========================================================================
% IBD_PlotPopulationTimeCourse
%==========================================================================
% Plot median and 5th and 95th quantiles of the time course after trigger
% per class
% 8 July 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombinePopulation_average)

classDefinition = IBD_centroids();

%--------------------------------------------------------------------------
% Plot
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

% Save q5, q50, q95 as individuals as input for plot function
individual(1:3*classDefinition.I.nrOfClasses) = individual_ref;
split = nan(1,3*classDefinition.I.nrOfClasses);
for i = 1:classDefinition.I.nrOfClasses
    thisClass                   = classDefinition.I.className{i};
    individual((i-1)*3+1).Xadd  = Xaverage.(thisClass)(:,:,2);
    individual((i-1)*3+2).Xadd  = Xaverage.(thisClass)(:,:,1);
    individual((i-1)*3+3).Xadd  = Xaverage.(thisClass)(:,:,3);
    split((i-1)*3+(1:3))        = i;
    switch thisClass
        case {'IBD','healthy'}
            labelClass = thisClass;
        case 'chronic_infection'
            labelClass = 'chronic infec.';
        case 'chronic_inflammation'
            labelClass = 'chronic infl.';
    end
    individual((i-1)*3+1).title = {strrep(labelClass,'_',' '),['N = ',int2str(N_ind.(thisClass))]};
end

p   = IBD_plotDatabase('overview_classes',individual_ref);
[p.alpha]       = deal(0.1);
[p.q5q95line]   = deal(false);
p(3).ylim       = [0 4e8];
p(2).tikzLegend = {'tissue','epithelium'};
p(2).ylineCol   = [0.6 0.6 0.6];
p(2).ylineLineStyle = '--';
if save2tikz
    [p.tikz]        = deal(true);
end

f   = IBD_plotIndividuals(individual,p,split,true);

if save2pdf
    IBD_saveFigure(f,'Overview_classes','pdf')
end

if save2tikz
    [p.tikz] = deal(true);
    for i = 1:length(individual)
        % Reduce number of plotted time points (otherwise tex capacity exceeded)
        individual(i).T     = individual(i).T(1:3:end);
        individual(i).Xadd  = individual(i).Xadd(1:3:end,:);
    end
    
    f_tikz   = IBD_plotIndividuals(individual,p,split,true);
    extraCode = struct;
    extraCode.Axis = 'clip=true';
    IBD_saveFigure(f_tikz,'Overview_classes','tikz',extraCode)
end

%--------------------------------------------------------------------------