%==========================================================================
% IBD_PlotresponderCytoS1PRComparison
%==========================================================================
% Plot comparison of pre-treatment steady state distributions between
% responders to cytokine inhibitor and S1PR modulator
% 19 April 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
load(fileNameList.CompareStatesCytoS1PRResponders)

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end


%--------------------------------------------------------------------------
scenario = 'S1PRmodulator';
p_table = t_cor_30(:,scenario);
p_table.absCor = abs(p_table.(scenario));

ssMIStruct                  = struct;
ssMIStruct.respondersCyto	= ssMI(:,respondersCyto);
ssMIStruct.respondersS1PR   = ssMI(:,respondersS1PR);

%--------------------------------------------------------------------------
% Remove additional states, sort by correlation
%p_table = p_table(1:individual_ref.I.nrOfStates,:);
[p_table_sortedCor] = sortrows(p_table,'absCor','descend','MissingPlacement','last');
stateOrder = p_table_sortedCor.Properties.RowNames;
p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);
% Remove mucus
p_table(p_table.idx==individual_ref.I.mucus,:) = [];

%--------------------------------------------------------------------------
% Plot most different between healthy and IBD as histogram...
N = 12;
options.colours         = [IBD_myColours('cytokineInhibitor');IBD_myColours('S1PRmodulator')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = save2tikz;
options.removeLegend    = true;
if save2tikz
    options.addText         = {};
    for i = 1:N
        options.addText{i} = sprintf('$\\rho=%.2g$',p_table{i,scenario});
    end
end
f = IBD_plotParDist(ssMIStruct,individual_ref,{'respondersCyto','respondersS1PR'},[p_table.idx(1:(N-1));271],options);

