%==========================================================================
% IBD_PlotStateComparison
%==========================================================================
% Plot comparison of pre-trigger steady state distributions between classes
% 17 September 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
load(fileNameList.CompareStates)

%--------------------------------------------------------------------------
% Remove additional states
p_table = p_table(1:individual_ref.I.nrOfStates,:);
[p_table_sortedCor, idx_cor] = sortrows(p_table,'absCor','descend','MissingPlacement','last');
[p_table_sortedKS, idx_KS]  = sortrows(p_table,'t_KS','descend','MissingPlacement','last');

% Sort by correlation AND KS test
stateOrder = cell(size(p_table_sortedCor.Properties.RowNames,1)*2,1);
stateOrder(1:2:end) = p_table_sortedCor.Properties.RowNames;
stateOrder(2:2:end) = p_table_sortedKS.Properties.RowNames;
stateOrder = unique(stateOrder,'stable');

p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);

%--------------------------------------------------------------------------
%% Plot most different between healthy and IBD as histogram...
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

N = 6;

options.colours         = [IBD_myColours('healthy');IBD_myColours('IBD')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = false;
options.removeLegend    = false;
f1 = IBD_plotParDist(ss0,individual_ref,{'healthy','IBD'},p_table.idx(1:N),options);
plotName = 'stateComparison';
if save2pdf
    IBD_saveFigure(f1,plotName,'pdf')
end
if save2tikz
    options.tikz            = save2tikz;
    options.removeLegend    = true;
    options.addText         = {};
    for i = 1:N
        options.addText{i} = sprintf('$\\rho=%.2g$\n$D=%.2g$',p_table{i,'t_cor'},p_table{i,'t_KS'});
    end
    f1a = IBD_plotParDist(ss0,individual_ref,{'healthy','IBD'},p_table.idx(1:N),options);
    IBD_saveFigure(f1a,plotName,'tikz')
    close(f1a)
end

%% ... and as cumulative probability distribution plot
f2 = IBD_plotCumulativeDist(ss0,individual_ref,{'healthy','IBD'},p_table.idx(1:N),options);
plotName = 'stateComparison_cumDis';
if save2pdf
    IBD_saveFigure(f2,plotName,'pdf')
end
% Not saved as tikzpicture