%==========================================================================
% IBD_ReferenceParsInIBDss
%==========================================================================
% Set reference individual in IBD steady state to see if inflammation can 
% be controlled
% 27 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ssMI','individual_ref');
classDefinition = IBD_centroids(individual_ref);

%--------------------------------------------------------------------------
N       = size(ssMI,2);
class   = nan(1,N);

% Set reference individual into IBD steady state
for ind = 1:size(ssMI,2)
    fprintf('Individual %i/%i:\t',ind,N)
    individual_tmp      = individual_ref;
    individual_tmp.X_ss = ssMI(1:individual_ref.I.nrOfStates,ind)';
    individual_tmp      = IBD_runSteadyState(individual_tmp);
    class(ind)          = IBD_classifyInflammation(individual_ref.Xadd_ss',individual_tmp.Xadd_ss',classDefinition,individual_ref);
end

%--------------------------------------------------------------------------
fprintf('Reference individual stays in IBD steady state:       %.0f/%.0f\n',sum(class==classDefinition.I.IBD),    N);
fprintf('Reference individual returns to healthy steady state: %.0f/%.0f\n',sum(class==classDefinition.I.healthy),N);

%--------------------------------------------------------------------------
% Set reference individual into chronic inflammation steady state
clear ssMI
load(strrep(fileNameList.CombinePopulation,'xxx','chronic_inflammation'),'ssMI','individual_ref');
N = 50;
class = nan(1,N);

for ind = 1:N
    fprintf('Individual %i/%i:\t',ind,N)
    individual_tmp      = individual_ref;
    individual_tmp.X_ss = ssMI(1:individual_ref.I.nrOfStates,ind)';
    individual_tmp      = IBD_runSteadyState(individual_tmp);
    class(ind)          = IBD_classifyInflammation(individual_ref.Xadd_ss',individual_tmp.Xadd_ss',classDefinition,individual_ref);
end

%--------------------------------------------------------------------------
fprintf('Reference individual stays in chronic inflammation steady state: %.0f/%.0f\n',sum(class==classDefinition.I.IBD),    N);
fprintf('Reference individual returns to healthy steady state:            %.0f/%.0f\n',sum(class==classDefinition.I.healthy),N);

%--------------------------------------------------------------------------