%==========================================================================
% IBD_RelativeSteadyState
%==========================================================================
% Calculate relative post-trigger steady-state concentrations for different
% cell types from all LP cells, for healthy and IBD
% 30 November 2022
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')
S_healthy = load(strrep(fileNameList.CombinePopulation,'xxx','healthy'),'ssMI','individual_ref');
S_IBD = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ssMI','individual_ref');
individual_ref = S_healthy.individual_ref;
I = individual_ref.I;

idx.T_cells_CD4_memory_resting = [I.Temreg_LP I.Tem1_LP I.Tem2_LP I.Tem17_LP];
idx.T_cells_CD4_memory_activated = [I.Tem2Th1_LP I.Tem2Th2_LP I.Tem2Th17_LP I.Th1_LP I.Th2_LP I.Th17_LP];
idx.T_cells_regulatory = [I.Tem2Treg_LP I.iTreg_LP];
idx.Macrophages_M1 = [I.MP1_tot_LP I.MP2_tot_LP I.MP3_tot_LP];
idx.Macrophages_M2 = [I.MP4_tot_LP I.Meffero_tot_LP];
idx.Dendritic_cells_resting = [I.qDC_LP I.rDC_LP I.tDC_LP I.tDCi_LP];
idx.Dendritic_cells_activated = [I.sDC_LP I.sDCi_LP];
idx.Neutrophils = [I.Neut_LP];
idx.allCells = [...
    idx.T_cells_CD4_memory_resting,...
    idx.T_cells_CD4_memory_activated,...
    idx.T_cells_regulatory,...
    idx.Macrophages_M1,...
    idx.Macrophages_M2,...
    idx.Dendritic_cells_resting,...
    idx.Dendritic_cells_activated,...
    idx.Neutrophils];

fractions = struct;
fractions.healthy = struct;
fractions.IBD = struct;

% Sum states
cellTypes = fieldnames(idx)';
for i = 1:length(cellTypes)
    fractions.healthy.(cellTypes{i}) = sum(S_healthy.ssMI(idx.(cellTypes{i}),:),1);
    fractions.IBD.(cellTypes{i}) = sum(S_IBD.ssMI(idx.(cellTypes{i}),:),1);
end
for i = 1:length(cellTypes)
    fractions.healthy.(cellTypes{i}) = fractions.healthy.(cellTypes{i})./fractions.healthy.allCells;
    fractions.IBD.(cellTypes{i}) = fractions.IBD.(cellTypes{i})./fractions.IBD.allCells;
end

fractions.healthy = rmfield(fractions.healthy,'allCells');
fractions.IBD = rmfield(fractions.IBD,'allCells');

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'fractions','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------