function [e,etaName,response] = IBD_bestEtaPerTreatment(treatment,responseRates,targetResponse)
%==========================================================================
% etaName = IBD_bestEtaPerTreatment(responseRates,targetResponse)
%==========================================================================
% Define the best eta per treatment
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% treatment:        treatment
% responseRates: 	response rates per treatment per eta
% targetResponse:   target response rate [%]
%--------------------------------------------------------------------------
%-- output
% etaName:        	name of effect extent
%==========================================================================

% Find the eta with the response rate closest to the target response rate
[~,e]       = min(abs(targetResponse - responseRates.(treatment){:,1}));
etaName     = responseRates.(treatment).Properties.RowNames{e};
response   	= responseRates.(treatment){e,1};

% Special case S1P: use eta1 = 0.9
if strcmp(treatment,'S1P')
    idx = cellfun(@(x) length(x),strfind(responseRates.S1P.Properties.RowNames,'eta_0o9'))==1;
    responseRates.(treatment){~idx,1} = inf;
    [~,e]       = min(abs(targetResponse - responseRates.(treatment){:,1}));
    etaName     = responseRates.(treatment).Properties.RowNames{e};
    response   	= responseRates.(treatment){e,1};
end

fprintf('For treatment %s, eta=%s is used, resulting in %.1f %% response.\n',treatment,strrep(strrep(strrep(etaName(5:end),'m','-'),'o','.'),'_','/'),responseRates.(treatment){etaName,1})

end

