%==========================================================================
% Paper_PlotPopulationTimeCourse
%==========================================================================
% Plot median and 5th and 95th quantiles of the time course after trigger
% per class
% 9 July 2020
%==========================================================================

clearvars

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombinePopulation_average)

classDefinition = IBD_centroids();

%--------------------------------------------------------------------------
%% Plot

% Save q5, q50, q95 as individuals as input for plot function
individual(1:3*2) = individual_ref;
split = nan(1,3*2);
for i = 1:2     % only healthy and IBD
    thisClass                   = classDefinition.I.className{i};
    individual((i-1)*3+1).Xadd  = Xaverage.(thisClass)(:,:,2);
    individual((i-1)*3+2).Xadd  = Xaverage.(thisClass)(:,:,1);
    individual((i-1)*3+3).Xadd  = Xaverage.(thisClass)(:,:,3);
    split((i-1)*3+(1:3))        = i;
    switch thisClass
        case {'IBD','healthy'}
            labelClass = thisClass;
        case 'chronic_infection'
            labelClass = 'chronic infec.';
        case 'chronic_inflammation'
            labelClass = 'chronic infl.';
    end
    individual((i-1)*3+1).title = strrep(labelClass,'_',' ');
end

p   = IBD_plotDatabase('overview_classes_withInset',individual_ref);
[p.ylabel]      = deal('Conc. [1/mL] / value');
[p.tikz]        = deal(true);
[p.legendRow]   = deal(3);
[p.legendPos]   = deal('northwest');
[p.noLink]      = deal(3);
[p.alpha]       = deal(0.1);
[p.q5q95line]   = deal(false);
p(3).ylim       = [0 4e8];
p(4).ylim       = [0 1e8];
p(2).tikzLegend = {'tissue','epithelium'};
p(2).ylineCol   = [0.6 0.6 0.6];
p(2).ylineLineStyle = '--';

for i = 1:length(individual)
    % Reduce number of plotted time points (otherwise tex capacity exceeded)
    idx = find(individual(i).T<=7*24)';
    idx = [idx,(idx(end)+1):3:length(individual(i).T),length(individual(i).T)];
    individual(i).T     = individual(i).T(idx);
    individual(i).Xadd  = individual(i).Xadd(idx,:);
end

f   = IBD_plotIndividuals(individual([1:6,1:3]),p,[split(1:6),3,3,3],true);

for i = 1:12
    s(i) = subplot(3,4,i);
end

for i = 5:8
    s(i).XLabel.String = s(9).XLabel.String;
end

for i = 9:12
    s(i).YLim           = [1e11 2e11];
    s(i).Visible        = 'off';
    s(i).YLabel.String  = '';
    s(i).XLabel.String  = '';
    if ~isempty(s(i).Legend)
        s(i).Legend.Box     = 'off';
    end
end

delete(s(12).Children)

% Adapt subplot positions
for i = 9:12
    s(i).Position(2) = s(i).Position(2)+0.1;
    s(i).Position(4) = s(i).Position(4)*0.5;
end

%delete(s(9).Children(1:3))
plot(s(9),1,1,'Color',[1 1 1])
plot(s(9),1,1,'Color',[1 1 1])
plot(s(9),1,1,'Color',[1 1 1])
new(1) = copyobj(s(1).Children(3),s(9)); 	% solid line
%new(2) = copyobj(s(1).Children(2),s(9));  	% dashed line
new(3) = copyobj(s(1).Children(2),s(9));  	% patch line
%new(2).Annotation.LegendInformation.IconDisplayStyle = 'on';
new(3).Annotation.LegendInformation.IconDisplayStyle = 'on';
new(1).Color        = [0 0 0];
%new(2).Color        = [0 0 0];
new(3).FaceColor    = [0 0 0];
new(3).EdgeAlpha    = new(3).FaceAlpha;
new(3).LineWidth    = 0.1;
new(3).LineStyle    = 'none';
legend(s(9),{'bacteria','\textcolor{white}{.}','\textcolor{white}{.}','\textcolor{white}{.}','median','90\,\% variability in virtual population'},'box','off','Location',s(11).Legend.Location,'Interpreter','latex')

% Change y limits of third column, top row
linkaxes([s(3),s(7)], 'off');
s(7).YLim(2) = 10e8;

%% Save figure
extraCode = struct;
extraCode.Axis = 'clip=true';
IBD_saveFigure(f,'Paper_Overview_classes','tikz',extraCode)

% Add code at line 3414 (column 3, line 2): scaled y ticks=base 10:-8,

%--------------------------------------------------------------------------