%==========================================================================
% Paper_SimOverview
%==========================================================================
% Simulation of salmonella infection and mucosal injury with overview plot
% 6 April 2021
%==========================================================================

clearvars

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm','extracellular'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).infection.Bact                    = {'STm'};
individual(1).infection.initial                 = 0.01;
individual(1).title                             = 'salmonellae';

individual(2)                                   = individual_ref;
individual(2).infection.epiDamage               = 1;
individual(2).infection.tisDamage               = 1;
individual(2).title                             = 'injury';

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind));
end

%==========================================================================
%% Plot
p = IBD_plotDatabase('overview',individual_ref);
[p.ylabel]      = deal('Conc. [1/mL] / value');
[p.legendRow]   = deal(3);
[p.legendPos]   = deal('northwest');
[p.tikz]        = deal(true);
[p.noLink]      = deal(3);
p(2).tikzLegend = {'tissue','epithelium'};
p(2).ylineCol   = [0.6 0.6 0.6];
p(2).ylineLineStyle = '--';
f = IBD_plotIndividuals(individual([1 2 1]),p);

for i = 1:9
    s(i) = subplot(3,3,i);
end

for i = 4:6
    s(i).XLabel.String = s(9).XLabel.String;
end

for i = 7:9
    s(i).YLim           = [1e11 2e11];
    s(i).Visible        = 'off';
    s(i).YLabel.String  = '';
    s(i).XLabel.String  = '';
    if ~isempty(s(i).Legend)
        s(i).Legend.Box     = 'off';
    end
end

delete(s(9).Children(1))

% Adapt subplot positions
for i = 7:9
    s(i).Position(2) = s(i).Position(2)+0.1;
    s(i).Position(4) = s(i).Position(4)*0.5;
end


%% Save figure
IBD_saveFigure(f,'Paper_overview','tikz')



%--------------------------------------------------------------------------